@@ -40,6 +40,7 @@ extern "C"
 
 #include <mtcr.h>
 #include <common/compatibility.h>
+#include <tools_layouts/icmd_hca_layouts.h>
 #ifdef MST_UL
 #include <tools_layouts/icmd_layouts.h>
 #else
@@ -76,9 +77,9 @@ extern "C"
 
     int get_icmd_query_cap(mfile* mf, struct icmd_hca_icmd_query_cap_general* icmd_query_caps);
 
-    int gcif_mh_sync(mfile* mf, struct connectx4_icmd_mh_sync* mh_sync);
+    int gcif_mh_sync(mfile* mf, struct icmd_hca_icmd_mh_sync_in* mh_sync_in, struct icmd_hca_icmd_mh_sync_out* mh_sync_out);
 
-    int gcif_mh_sync_status(mfile* mf, struct connectx4_icmd_mh_sync* mh_sync);
+    int gcif_mh_sync_status(mfile* mf, struct icmd_hca_icmd_mh_sync_in* mh_sync_in, struct icmd_hca_icmd_mh_sync_out* mh_sync_out);
 
     int gcif_set_port_sniffer(mfile* mf, struct connectib_icmd_set_port_sniffer* set_port_sniffer);
 
