@@ -52,6 +52,26 @@ extern "C"
 #include <common/compatibility.h>
 #include "include/mtcr_ul/mtcr.h"
 
+typedef enum get_dev_id_error_t {
+    GET_DEV_ID_SUCCESS,
+    GET_DEV_ID_ERROR,
+    CRSPACE_READ_ERROR,
+    CHECK_PTR_DEV_ID,
+} dev_id_error;
+
+enum dm_dev_type {
+    DM_UNKNOWN = -1,
+    DM_HCA,
+    DM_SWITCH,
+    DM_BRIDGE,
+    DM_QSFP_CABLE,
+    DM_CMIS_CABLE,
+    DM_SFP_CABLE,
+    DM_LINKX, /* linkx chip */
+    DM_GEARBOX,
+    DM_RETIMER
+};
+
 enum dm_dev_id {
     DeviceUnknown     = -1,    /* Dummy Device - Marker for indicating error. */
     DeviceStartMarker = 0,     /* Dummy Device - Marker for first device */
@@ -89,6 +109,7 @@ enum dm_dev_id {
     DeviceConnectX6LX,
     DeviceConnectX7,
     DeviceConnectX8,
+    DeviceConnectX8PurePcieSwitch,
     DeviceConnectX9,
     DeviceSpectrum3,     /* Firebird */
     DeviceSpectrum4,     /* Albatross */
@@ -125,7 +146,8 @@ enum hw_dev_id {
     DeviceConnectX6LX_HwId      = 0x216,
     DeviceConnectX7_HwId        = 0x218,
     DeviceConnectX8_HwId        = 0x21e,
-    DeviceConnectX9_HwId        = 0x225,
+    DeviceConnectX8PurePcieSwitch_HwId = 0x222,
+    DeviceConnectX9_HwId        = 0x224,
     DeviceBlueField_HwId        = 0x211,
     DeviceBlueField2_HwId       = 0x214,
     DeviceBlueField3_HwId       = 0x21c,
@@ -198,6 +220,16 @@ const char* dm_dev_hw_id2str(unsigned int hw_dev_id);
  */
 dm_dev_id_t dm_dev_str2type(const char* str);
 
+/**
+ * Returns dev type
+*/
+dm_dev_id_t dm_dev_sw_id2type(int sw_dev_id);
+
+/**
+ * Returns the HW device id of the given SW device id.
+ */
+u_int16_t dm_dev_sw_id2hw_dev_id(u_int16_t sw_dev_id);
+
 /**
  * A predicate returning if the device is an hca
  */
@@ -305,6 +337,8 @@ int dm_dev_is_eth_switch(dm_dev_id_t type);
 int dm_is_livefish_mode(mfile* mf);
 
 int dm_is_ib_access(mfile* mf);
+
+int dm_is_bluefield(dm_dev_id_t type);
 #ifdef __cplusplus
 } /* end of 'extern "C"' */
 #endif
