@@ -12,8 +12,8 @@
 #include "iniparser.h"
 
 /*---------------------------- Defines -------------------------------------*/
-#define ASCIILINESZ         (1024)
-#define INI_INVALID_KEY     ((char*)-1)
+#define ASCIILINESZ (1024)
+#define INI_INVALID_KEY ((char*)-1)
 
 /*---------------------------------------------------------------------------
                         Private to this module
@@ -21,14 +21,15 @@
 /**
  * This enum stores the status for each parsed line (internal use only).
  */
-typedef enum _line_status_ {
+typedef enum _line_status_
+{
     LINE_UNPROCESSED,
     LINE_ERROR,
     LINE_EMPTY,
     LINE_COMMENT,
     LINE_SECTION,
     LINE_VALUE
-} line_status ;
+} line_status;
 
 /*-------------------------------------------------------------------------*/
 /**
@@ -36,24 +37,26 @@ typedef enum _line_status_ {
   @param    in   String to convert.
   @param    out Output buffer.
   @param    len Size of the out buffer.
-  @return   ptr to the out buffer or NULL if an error occured.
+  @return   ptr to the out buffer or NULL if an error occurred.
 
   This function convert a string into lowercase.
   At most len - 1 elements of the input string will be converted.
  */
 /*--------------------------------------------------------------------------*/
-static const char * strlwc(const char * in, char *out, unsigned len)
+static const char* strlwc(const char* in, char* out, unsigned len)
 {
-    unsigned i ;
+    unsigned i;
 
-    if (in==NULL || out == NULL || len==0) return NULL ;
-    i=0 ;
-    while (in[i] != '\0' && i < len-1) {
+    if (in == NULL || out == NULL || len == 0)
+        return NULL;
+    i = 0;
+    while (in[i] != '\0' && i < len - 1)
+    {
         out[i] = (char)tolower((int)in[i]);
-        i++ ;
+        i++;
     }
     out[i] = '\0';
-    return out ;
+    return out;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -66,19 +69,20 @@ static const char * strlwc(const char * in, char *out, unsigned len)
   for systems that do not have it.
  */
 /*--------------------------------------------------------------------------*/
-static char * xstrdup(const char * s)
+static char* xstrdup(const char* s)
 {
-    char * t ;
-    size_t len ;
+    char* t;
+    size_t len;
     if (!s)
-        return NULL ;
+        return NULL;
 
-    len = strlen(s) + 1 ;
-    t = (char*) malloc(len) ;
-    if (t) {
-        memcpy(t, s, len) ;
+    len = strlen(s) + 1;
+    t = (char*)malloc(len);
+    if (t)
+    {
+        memcpy(t, s, len);
     }
-    return t ;
+    return t;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -88,23 +92,26 @@ static char * xstrdup(const char * s)
   @return   unsigned New size of the string.
  */
 /*--------------------------------------------------------------------------*/
-static unsigned strstrip(char * s)
+static unsigned strstrip(char* s)
 {
-    char *last = NULL ;
-    char *dest = s;
+    char* last = NULL;
+    char* dest = s;
 
-    if (s==NULL) return 0;
+    if (s == NULL)
+        return 0;
 
     last = s + strlen(s);
-    while (isspace((int)*s) && *s) s++;
-    while (last > s) {
-        if (!isspace((int)*(last-1)))
-            break ;
-        last -- ;
+    while (isspace((int)*s) && *s)
+        s++;
+    while (last > s)
+    {
+        if (!isspace((int)*(last - 1)))
+            break;
+        last--;
     }
     *last = (char)0;
 
-    memmove(dest,s,last - s + 1);
+    memmove(dest, s, last - s + 1);
     return last - s;
 }
 
@@ -113,14 +120,14 @@ static unsigned strstrip(char * s)
   @brief    Default error callback for iniparser: wraps `fprintf(stderr, ...)`.
  */
 /*--------------------------------------------------------------------------*/
-static int default_error_callback(const char *format, ...)
+static int default_error_callback(const char* format, ...)
 {
-  int ret;
-  va_list argptr;
-  va_start(argptr, format);
-  ret = vfprintf(stderr, format, argptr);
-  va_end(argptr);
-  return ret;
+    int ret;
+    va_list argptr;
+    va_start(argptr, format);
+    ret = vfprintf(stderr, format, argptr);
+    va_end(argptr);
+    return ret;
 }
 
 static int (*iniparser_error_callback)(const char*, ...) = default_error_callback;
@@ -134,13 +141,16 @@ static int (*iniparser_error_callback)(const char*, ...) = default_error_callbac
   as errback the error callback will be switched back to default.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_set_error_callback(int (*errback)(const char *, ...))
+void iniparser_set_error_callback(int (*errback)(const char*, ...))
 {
-  if (errback) {
-    iniparser_error_callback = errback;
-  } else {
-    iniparser_error_callback = default_error_callback;
-  }
+    if (errback)
+    {
+        iniparser_error_callback = errback;
+    }
+    else
+    {
+        iniparser_error_callback = default_error_callback;
+    }
 }
 
 /*-------------------------------------------------------------------------*/
@@ -161,21 +171,24 @@ void iniparser_set_error_callback(int (*errback)(const char *, ...))
   This function returns -1 in case of error.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getnsec(const dictionary * d)
+int iniparser_getnsec(const dictionary* d)
 {
-    int i ;
-    int nsec ;
+    int i;
+    int nsec;
 
-    if (d==NULL) return -1 ;
-    nsec=0 ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (strchr(d->key[i], ':')==NULL) {
-            nsec ++ ;
+    if (d == NULL)
+        return -1;
+    nsec = 0;
+    for (i = 0; i < d->size; i++)
+    {
+        if (d->key[i] == NULL)
+            continue;
+        if (strchr(d->key[i], ':') == NULL)
+        {
+            nsec++;
         }
     }
-    return nsec ;
+    return nsec;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -192,26 +205,30 @@ int iniparser_getnsec(const dictionary * d)
   This function returns NULL in case of error.
  */
 /*--------------------------------------------------------------------------*/
-const char * iniparser_getsecname(const dictionary * d, int n)
+const char* iniparser_getsecname(const dictionary* d, int n)
 {
-    int i ;
-    int foundsec ;
+    int i;
+    int foundsec;
 
-    if (d==NULL || n<0) return NULL ;
-    foundsec=0 ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (strchr(d->key[i], ':')==NULL) {
-            foundsec++ ;
-            if (foundsec>n)
-                break ;
+    if (d == NULL || n < 0)
+        return NULL;
+    foundsec = 0;
+    for (i = 0; i < d->size; i++)
+    {
+        if (d->key[i] == NULL)
+            continue;
+        if (strchr(d->key[i], ':') == NULL)
+        {
+            foundsec++;
+            if (foundsec > n)
+                break;
         }
     }
-    if (foundsec<=n) {
-        return NULL ;
+    if (foundsec <= n)
+    {
+        return NULL;
     }
-    return d->key[i] ;
+    return d->key[i];
 }
 
 /*-------------------------------------------------------------------------*/
@@ -227,21 +244,26 @@ const char * iniparser_getsecname(const dictionary * d, int n)
   purposes mostly.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_dump(const dictionary * d, FILE * f)
+void iniparser_dump(const dictionary* d, FILE* f)
 {
-    int     i ;
+    int i;
 
-    if (d==NULL || f==NULL) return ;
-    for (i=0 ; i<d->size ; i++) {
-        if (d->key[i]==NULL)
-            continue ;
-        if (d->val[i]!=NULL) {
+    if (d == NULL || f == NULL)
+        return;
+    for (i = 0; i < d->size; i++)
+    {
+        if (d->key[i] == NULL)
+            continue;
+        if (d->val[i] != NULL)
+        {
             fprintf(f, "[%s]=[%s]\n", d->key[i], d->val[i]);
-        } else {
+        }
+        else
+        {
             fprintf(f, "[%s]=UNDEF\n", d->key[i]);
         }
     }
-    return ;
+    return;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -255,30 +277,34 @@ void iniparser_dump(const dictionary * d, FILE * f)
   It is Ok to specify @c stderr or @c stdout as output files.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_dump_ini(const dictionary * d, FILE * f)
+void iniparser_dump_ini(const dictionary* d, FILE* f)
 {
-    int          i ;
-    int          nsec ;
-    const char * secname ;
+    int i;
+    int nsec;
+    const char* secname;
 
-    if (d==NULL || f==NULL) return ;
+    if (d == NULL || f == NULL)
+        return;
 
     nsec = iniparser_getnsec(d);
-    if (nsec<1) {
+    if (nsec < 1)
+    {
         /* No section in file: dump all keys as they are */
-        for (i=0 ; i<d->size ; i++) {
-            if (d->key[i]==NULL)
-                continue ;
+        for (i = 0; i < d->size; i++)
+        {
+            if (d->key[i] == NULL)
+                continue;
             fprintf(f, "%s = %s\n", d->key[i], d->val[i]);
         }
-        return ;
+        return;
     }
-    for (i=0 ; i<nsec ; i++) {
-        secname = iniparser_getsecname(d, i) ;
+    for (i = 0; i < nsec; i++)
+    {
+        secname = iniparser_getsecname(d, i);
         iniparser_dumpsection_ini(d, secname, f);
     }
     fprintf(f, "\n");
-    return ;
+    return;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -293,30 +319,31 @@ void iniparser_dump_ini(const dictionary * d, FILE * f)
   file.  It is Ok to specify @c stderr or @c stdout as output files.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_dumpsection_ini(const dictionary * d, const char * s, FILE * f)
+void iniparser_dumpsection_ini(const dictionary* d, const char* s, FILE* f)
 {
-    int     j ;
-    char    keym[ASCIILINESZ+1];
-    int     seclen ;
+    int j;
+    char keym[ASCIILINESZ + 1];
+    int seclen;
 
-    if (d==NULL || f==NULL) return ;
-    if (! iniparser_find_entry(d, s)) return ;
+    if (d == NULL || f == NULL)
+        return;
+    if (!iniparser_find_entry(d, s))
+        return;
 
-    seclen  = (int)strlen(s);
+    seclen = (int)strlen(s);
     fprintf(f, "\n[%s]\n", s);
     sprintf(keym, "%s:", s);
-    for (j=0 ; j<d->size ; j++) {
-        if (d->key[j]==NULL)
-            continue ;
-        if (!strncmp(d->key[j], keym, seclen+1)) {
-            fprintf(f,
-                    "%-30s = %s\n",
-                    d->key[j]+seclen+1,
-                    d->val[j] ? d->val[j] : "");
+    for (j = 0; j < d->size; j++)
+    {
+        if (d->key[j] == NULL)
+            continue;
+        if (!strncmp(d->key[j], keym, seclen + 1))
+        {
+            fprintf(f, "%-30s = %s\n", d->key[j] + seclen + 1, d->val[j] ? d->val[j] : "");
         }
     }
     fprintf(f, "\n");
-    return ;
+    return;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -327,30 +354,32 @@ void iniparser_dumpsection_ini(const dictionary * d, const char * s, FILE * f)
   @return   Number of keys in section
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getsecnkeys(const dictionary * d, const char * s)
+int iniparser_getsecnkeys(const dictionary* d, const char* s)
 {
-    int     seclen, nkeys ;
-    char    keym[ASCIILINESZ+1];
-    int j ;
+    int seclen, nkeys;
+    char keym[ASCIILINESZ + 1];
+    int j;
 
     nkeys = 0;
 
-    if (d==NULL) return nkeys;
-    if (! iniparser_find_entry(d, s)) return nkeys;
+    if (d == NULL)
+        return nkeys;
+    if (!iniparser_find_entry(d, s))
+        return nkeys;
 
-    seclen  = (int)strlen(s);
+    seclen = (int)strlen(s);
     strlwc(s, keym, sizeof(keym));
     keym[seclen] = ':';
 
-    for (j=0 ; j<d->size ; j++) {
-        if (d->key[j]==NULL)
-            continue ;
-        if (!strncmp(d->key[j], keym, seclen+1))
+    for (j = 0; j < d->size; j++)
+    {
+        if (d->key[j] == NULL)
+            continue;
+        if (!strncmp(d->key[j], keym, seclen + 1))
             nkeys++;
     }
 
     return nkeys;
-
 }
 
 /*-------------------------------------------------------------------------*/
@@ -369,24 +398,28 @@ int iniparser_getsecnkeys(const dictionary * d, const char * s)
   a string allocated in the dictionary; do not free or modify them.
  */
 /*--------------------------------------------------------------------------*/
-const char ** iniparser_getseckeys(const dictionary * d, const char * s, const char ** keys)
+const char** iniparser_getseckeys(const dictionary* d, const char* s, const char** keys)
 {
-    int i, j, seclen ;
-    char keym[ASCIILINESZ+1];
+    int i, j, seclen;
+    char keym[ASCIILINESZ + 1];
 
-    if (d==NULL || keys==NULL) return NULL;
-    if (! iniparser_find_entry(d, s)) return NULL;
+    if (d == NULL || keys == NULL)
+        return NULL;
+    if (!iniparser_find_entry(d, s))
+        return NULL;
 
-    seclen  = (int)strlen(s);
+    seclen = (int)strlen(s);
     strlwc(s, keym, sizeof(keym));
     keym[seclen] = ':';
 
     i = 0;
 
-    for (j=0 ; j<d->size ; j++) {
-        if (d->key[j]==NULL)
-            continue ;
-        if (!strncmp(d->key[j], keym, seclen+1)) {
+    for (j = 0; j < d->size; j++)
+    {
+        if (d->key[j] == NULL)
+            continue;
+        if (!strncmp(d->key[j], keym, seclen + 1))
+        {
             keys[i] = d->key[j];
             i++;
         }
@@ -410,18 +443,18 @@ const char ** iniparser_getseckeys(const dictionary * d, const char * s, const c
   the dictionary, do not free or modify it.
  */
 /*--------------------------------------------------------------------------*/
-const char * iniparser_getstring(const dictionary * d, const char * key, const char * def)
+const char* iniparser_getstring(const dictionary* d, const char* key, const char* def)
 {
-    const char * lc_key ;
-    const char * sval ;
-    char tmp_str[ASCIILINESZ+1];
+    const char* lc_key;
+    const char* sval;
+    char tmp_str[ASCIILINESZ + 1];
 
-    if (d==NULL || key==NULL)
-        return def ;
+    if (d == NULL || key == NULL)
+        return def;
 
     lc_key = strlwc(key, tmp_str, sizeof(tmp_str));
     sval = dictionary_get(d, lc_key, def);
-    return sval ;
+    return sval;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -451,16 +484,16 @@ const char * iniparser_getstring(const dictionary * d, const char * key, const c
   Credits: Thanks to A. Becker for suggesting strtol()
  */
 /*--------------------------------------------------------------------------*/
-long int iniparser_getlongint(const dictionary * d, const char * key, long int notfound)
+long int iniparser_getlongint(const dictionary* d, const char* key, long int notfound)
 {
-    const char * str ;
+    const char* str;
 
     str = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (str==INI_INVALID_KEY) return notfound ;
+    if (str == INI_INVALID_KEY)
+        return notfound;
     return strtol(str, NULL, 0);
 }
 
-
 /*-------------------------------------------------------------------------*/
 /**
   @brief    Get the string associated to a key, convert to an int
@@ -488,7 +521,7 @@ long int iniparser_getlongint(const dictionary * d, const char * key, long int n
   Credits: Thanks to A. Becker for suggesting strtol()
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getint(const dictionary * d, const char * key, int notfound)
+int iniparser_getint(const dictionary* d, const char* key, int notfound)
 {
     return (int)iniparser_getlongint(d, key, notfound);
 }
@@ -506,12 +539,13 @@ int iniparser_getint(const dictionary * d, const char * key, int notfound)
   the notfound value is returned.
  */
 /*--------------------------------------------------------------------------*/
-double iniparser_getdouble(const dictionary * d, const char * key, double notfound)
+double iniparser_getdouble(const dictionary* d, const char* key, double notfound)
 {
-    const char * str ;
+    const char* str;
 
     str = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (str==INI_INVALID_KEY) return notfound ;
+    if (str == INI_INVALID_KEY)
+        return notfound;
     return atof(str);
 }
 
@@ -547,19 +581,25 @@ double iniparser_getdouble(const dictionary * d, const char * key, double notfou
   necessarily have to be 0 or 1.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_getboolean(const dictionary * d, const char * key, int notfound)
+int iniparser_getboolean(const dictionary* d, const char* key, int notfound)
 {
-    int          ret ;
-    const char * c ;
+    int ret;
+    const char* c;
 
     c = iniparser_getstring(d, key, INI_INVALID_KEY);
-    if (c==INI_INVALID_KEY) return notfound ;
-    if (c[0]=='y' || c[0]=='Y' || c[0]=='1' || c[0]=='t' || c[0]=='T') {
-        ret = 1 ;
-    } else if (c[0]=='n' || c[0]=='N' || c[0]=='0' || c[0]=='f' || c[0]=='F') {
-        ret = 0 ;
-    } else {
-        ret = notfound ;
+    if (c == INI_INVALID_KEY)
+        return notfound;
+    if (c[0] == 'y' || c[0] == 'Y' || c[0] == '1' || c[0] == 't' || c[0] == 'T')
+    {
+        ret = 1;
+    }
+    else if (c[0] == 'n' || c[0] == 'N' || c[0] == '0' || c[0] == 'f' || c[0] == 'F')
+    {
+        ret = 0;
+    }
+    else
+    {
+        ret = notfound;
     }
     return ret;
 }
@@ -576,13 +616,14 @@ int iniparser_getboolean(const dictionary * d, const char * key, int notfound)
   of querying for the presence of sections in a dictionary.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_find_entry(const dictionary * ini, const char * entry)
+int iniparser_find_entry(const dictionary* ini, const char* entry)
 {
-    int found=0 ;
-    if (iniparser_getstring(ini, entry, INI_INVALID_KEY)!=INI_INVALID_KEY) {
-        found = 1 ;
+    int found = 0;
+    if (iniparser_getstring(ini, entry, INI_INVALID_KEY) != INI_INVALID_KEY)
+    {
+        found = 1;
     }
-    return found ;
+    return found;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -598,10 +639,10 @@ int iniparser_find_entry(const dictionary * ini, const char * entry)
   It is Ok to set val to NULL.
  */
 /*--------------------------------------------------------------------------*/
-int iniparser_set(dictionary * ini, const char * entry, const char * val)
+int iniparser_set(dictionary* ini, const char* entry, const char* val)
 {
-    char tmp_str[ASCIILINESZ+1];
-    return dictionary_set(ini, strlwc(entry, tmp_str, sizeof(tmp_str)), val) ;
+    char tmp_str[ASCIILINESZ + 1];
+    return dictionary_set(ini, strlwc(entry, tmp_str, sizeof(tmp_str)), val);
 }
 
 /*-------------------------------------------------------------------------*/
@@ -614,9 +655,9 @@ int iniparser_set(dictionary * ini, const char * entry, const char * val)
   If the given entry can be found, it is deleted from the dictionary.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_unset(dictionary * ini, const char * entry)
+void iniparser_unset(dictionary* ini, const char* entry)
 {
-    char tmp_str[ASCIILINESZ+1];
+    char tmp_str[ASCIILINESZ + 1];
     dictionary_unset(ini, strlwc(entry, tmp_str, sizeof(tmp_str)));
 }
 
@@ -630,40 +671,44 @@ void iniparser_unset(dictionary * ini, const char * entry)
   @return   line_status value
  */
 /*--------------------------------------------------------------------------*/
-static line_status iniparser_line(
-    const char * input_line,
-    char * section,
-    char * key,
-    char * value)
+static line_status iniparser_line(const char* input_line, char* section, char* key, char* value)
 {
-    line_status sta ;
-    char * line = NULL;
-    size_t      len ;
+    line_status sta;
+    char* line = NULL;
+    size_t len;
 
     line = xstrdup(input_line);
     len = strstrip(line);
 
-    sta = LINE_UNPROCESSED ;
-    if (len<1) {
+    sta = LINE_UNPROCESSED;
+    if (len < 1)
+    {
         /* Empty line */
-        sta = LINE_EMPTY ;
-    } else if (line[0]=='#' || line[0]==';') {
+        sta = LINE_EMPTY;
+    }
+    else if (line[0] == '#' || line[0] == ';')
+    {
         /* Comment line */
-        sta = LINE_COMMENT ;
-    } else if (line[0]=='[' && line[len-1]==']') {
+        sta = LINE_COMMENT;
+    }
+    else if (line[0] == '[' && line[len - 1] == ']')
+    {
         /* Section name */
         sscanf(line, "[%[^]]", section);
         strstrip(section);
         strlwc(section, section, len);
-        sta = LINE_SECTION ;
-    } else if (sscanf (line, "%[^=] = \"%[^\"]\"", key, value) == 2
-           ||  sscanf (line, "%[^=] = '%[^\']'",   key, value) == 2) {
+        sta = LINE_SECTION;
+    }
+    else if (sscanf(line, "%[^=] = \"%[^\"]\"", key, value) == 2 || sscanf(line, "%[^=] = '%[^\']'", key, value) == 2)
+    {
         /* Usual key=value with quotes, with or without comments */
         strstrip(key);
         strlwc(key, key, len);
         /* Don't strip spaces from values surrounded with quotes */
-        sta = LINE_VALUE ;
-    } else if (sscanf (line, "%[^=] = %[^;#]", key, value) == 2) {
+        sta = LINE_VALUE;
+    }
+    else if (sscanf(line, "%[^=] = %[^;#]", key, value) == 2)
+    {
         /* Usual key=value without quotes, with or without comments */
         strstrip(key);
         strlwc(key, key, len);
@@ -672,12 +717,14 @@ static line_status iniparser_line(
          * sscanf cannot handle '' or "" as empty values
          * this is done here
          */
-        if (!strcmp(value, "\"\"") || (!strcmp(value, "''"))) {
-            value[0]=0 ;
+        if (!strcmp(value, "\"\"") || (!strcmp(value, "''")))
+        {
+            value[0] = 0;
         }
-        sta = LINE_VALUE ;
-    } else if (sscanf(line, "%[^=] = %[;#]", key, value)==2
-           ||  sscanf(line, "%[^=] %[=]", key, value) == 2) {
+        sta = LINE_VALUE;
+    }
+    else if (sscanf(line, "%[^=] = %[;#]", key, value) == 2 || sscanf(line, "%[^=] %[=]", key, value) == 2)
+    {
         /*
          * Special cases:
          * key=
@@ -686,15 +733,17 @@ static line_status iniparser_line(
          */
         strstrip(key);
         strlwc(key, key, len);
-        value[0]=0 ;
-        sta = LINE_VALUE ;
-    } else {
+        value[0] = 0;
+        sta = LINE_VALUE;
+    }
+    else
+    {
         /* Generate syntax error */
-        sta = LINE_ERROR ;
+        sta = LINE_ERROR;
     }
 
     free(line);
-    return sta ;
+    return sta;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -711,112 +760,116 @@ static line_status iniparser_line(
   The returned dictionary must be freed using iniparser_freedict().
  */
 /*--------------------------------------------------------------------------*/
-dictionary * iniparser_load(const char * ininame)
+dictionary* iniparser_load(const char* ininame)
 {
-    FILE * in ;
+    FILE* in;
 
-    char line    [ASCIILINESZ+1] ;
-    char section [ASCIILINESZ+1] ;
-    char key     [ASCIILINESZ+1] ;
-    char tmp     [(ASCIILINESZ * 2) + 2] ;
-    char val     [ASCIILINESZ+1] ;
+    char line[ASCIILINESZ + 1];
+    char section[ASCIILINESZ + 1];
+    char key[ASCIILINESZ + 1];
+    char tmp[(ASCIILINESZ * 2) + 2];
+    char val[ASCIILINESZ + 1];
 
-    int  last=0 ;
-    int  len ;
-    int  lineno=0 ;
-    int  errs=0;
-    int  mem_err=0;
+    int last = 0;
+    int len;
+    int lineno = 0;
+    int errs = 0;
+    int mem_err = 0;
 
-    dictionary * dict ;
+    dictionary* dict;
 
-    if ((in=fopen(ininame, "r"))==NULL) {
+    if ((in = fopen(ininame, "r")) == NULL)
+    {
         iniparser_error_callback("iniparser: cannot open %s\n", ininame);
-        return NULL ;
+        return NULL;
     }
 
-    dict = dictionary_new(0) ;
-    if (!dict) {
+    dict = dictionary_new(0);
+    if (!dict)
+    {
         fclose(in);
-        return NULL ;
+        return NULL;
     }
 
-    memset(line,    0, ASCIILINESZ);
+    memset(line, 0, ASCIILINESZ);
     memset(section, 0, ASCIILINESZ);
-    memset(key,     0, ASCIILINESZ);
-    memset(val,     0, ASCIILINESZ);
-    last=0 ;
+    memset(key, 0, ASCIILINESZ);
+    memset(val, 0, ASCIILINESZ);
+    last = 0;
 
-    while (fgets(line+last, ASCIILINESZ-last, in)!=NULL) {
-        lineno++ ;
-        len = (int)strlen(line)-1;
-        if (len<=0)
+    while (fgets(line + last, ASCIILINESZ - last, in) != NULL)
+    {
+        lineno++;
+        len = (int)strlen(line) - 1;
+        if (len <= 0)
             continue;
         /* Safety check against buffer overflows */
-        if (line[len]!='\n' && !feof(in)) {
-            iniparser_error_callback(
-              "iniparser: input line too long in %s (%d)\n",
-              ininame,
-              lineno);
+        if (line[len] != '\n' && !feof(in))
+        {
+            iniparser_error_callback("iniparser: input line too long in %s (%d)\n", ininame, lineno);
             dictionary_del(dict);
             fclose(in);
-            return NULL ;
+            return NULL;
         }
         /* Get rid of \n and spaces at end of line */
-        while ((len>=0) &&
-                ((line[len]=='\n') || (isspace(line[len])))) {
-            line[len]=0 ;
-            len-- ;
+        while ((len >= 0) && ((line[len] == '\n') || (isspace(line[len]))))
+        {
+            line[len] = 0;
+            len--;
         }
-        if (len < 0) { /* Line was entirely \n and/or spaces */
+        if (len < 0)
+        { /* Line was entirely \n and/or spaces */
             len = 0;
         }
         /* Detect multi-line */
-        if (line[len]=='\\') {
+        if (line[len] == '\\')
+        {
             /* Multi-line value */
-            last=len ;
-            continue ;
-        } else {
-            last=0 ;
+            last = len;
+            continue;
         }
-        switch (iniparser_line(line, section, key, val)) {
+        else
+        {
+            last = 0;
+        }
+        switch (iniparser_line(line, section, key, val))
+        {
             case LINE_EMPTY:
             case LINE_COMMENT:
-            break ;
+                break;
 
             case LINE_SECTION:
-            mem_err = dictionary_set(dict, section, NULL);
-            break ;
+                mem_err = dictionary_set(dict, section, NULL);
+                break;
 
             case LINE_VALUE:
-            sprintf(tmp, "%s:%s", section, key);
-            mem_err = dictionary_set(dict, tmp, val);
-            break ;
+                sprintf(tmp, "%s:%s", section, key);
+                mem_err = dictionary_set(dict, tmp, val);
+                break;
 
             case LINE_ERROR:
-            iniparser_error_callback(
-              "iniparser: syntax error in %s (%d):\n-> %s\n",
-              ininame,
-              lineno,
-              line);
-            errs++ ;
-            break;
+                iniparser_error_callback("iniparser: syntax error in %s (%d):\n-> %s\n", ininame, lineno, line);
+                errs++;
+                break;
 
             default:
-            break ;
+                break;
         }
         memset(line, 0, ASCIILINESZ);
-        last=0;
-        if (mem_err<0) {
+        last = 0;
+        if (mem_err < 0)
+        {
             iniparser_error_callback("iniparser: memory allocation failure\n");
-            break ;
+            break;
         }
     }
-    if (errs) {
+    if (errs)
+    {
         dictionary_del(dict);
-        dict = NULL ;
+        dict = NULL;
     }
     fclose(in);
-    return dict ;
+    return dict;
 }
 
 /*-------------------------------------------------------------------------*/
@@ -830,7 +883,7 @@ dictionary * iniparser_load(const char * ininame)
   gets out of the current context.
  */
 /*--------------------------------------------------------------------------*/
-void iniparser_freedict(dictionary * d)
+void iniparser_freedict(dictionary* d)
 {
     dictionary_del(d);
 }
