@@ -39,6 +39,7 @@
 #include <iostream>
 #include <stdio.h>
 #include <errno.h>
+#include <algorithm>
 // Flint includes
 #include "flint.h"
 #include <common/tools_version.h>
@@ -126,6 +127,7 @@ SubCmdMetaData::SubCmdMetaData()
     _sCmds.push_back(new SubCmd("", "rsa_sign", SC_RSA_Sign));
     _sCmds.push_back(new SubCmd("", "export_public_key", SC_Export_Public_Key));
     _sCmds.push_back(new SubCmd("qc", "query_components", SC_Query_Components));
+    _sCmds.push_back(new SubCmd("qbfb", "query_bfb_components", SC_Query_Bfb_Components));
 }
 
 SubCmdMetaData::~SubCmdMetaData()
@@ -226,13 +228,17 @@ FlagMetaData::FlagMetaData()
     _flags.push_back(new Flag("", "psid", 1));
     _flags.push_back(new Flag("", "cc", 1));
     _flags.push_back(new Flag("", "linkx", 0));
+    _flags.push_back(new Flag("", "linkx_els", 0));
     _flags.push_back(new Flag("", "downstream_device_id_start_index", 1));
     _flags.push_back(new Flag("", "num_of_downstream_devices", 1));
     _flags.push_back(new Flag("", "linkx_auto_update", 0));
     _flags.push_back(new Flag("", "activate", 0));
     _flags.push_back(new Flag("", "activate_delay_sec", 1));
+    _flags.push_back(new Flag("", "run_module_image", 0));
+    _flags.push_back(new Flag("", "commit_module_image", 0));
     _flags.push_back(new Flag("", "downstream_device_ids", 1));
     _flags.push_back(new Flag("", "download_transfer", 0));
+    _flags.push_back(new Flag("", "i2c_secondary", 1));
     _flags.push_back(new Flag("", "openssl_engine", 1));
     _flags.push_back(new Flag("", "openssl_key_id", 1));
     _flags.push_back(new Flag("", "cert_uuid", 1));
@@ -243,7 +249,8 @@ FlagMetaData::FlagMetaData()
     _flags.push_back(new Flag("", "user_password", 1));
     _flags.push_back(new Flag("", "cert_chain_index", 1));
     _flags.push_back(new Flag("", "component_type", 1));
-    _flags.push_back(new Flag("", "image_size_only", 0));
+    _flags.push_back(new Flag("", "pending", 0));
+    _flags.push_back(new Flag("", "skip_if_same", 0));
 }
 
 FlagMetaData::~FlagMetaData()
@@ -665,6 +672,12 @@ void Flint::initCmdParser()
                "When specified, only flashed fw version is fetched\n"
                "Commands affected: query");
 
+    AddOptions("pending",
+               ' ',
+               "",
+               "When specified, shows the versions of the pending BFB components\n"
+               "Commands affected: query_bfb_components");
+
     AddOptions("nofs", ' ', "", "Burn image in a non failsafe manner.");
 
     AddOptions("allow_psid_change", ' ', "",
@@ -733,6 +746,9 @@ void Flint::initCmdParser()
 
     AddOptions("no_fw_ctrl", ' ', "", "Do not attempt to work with the FW Ctrl update commands");
 
+    AddOptions("skip_if_same", ' ', "",
+               "Skip burning if the firmware version matches the current version on the device");
+
     AddOptions("use_dev_img_info",
                ' ',
                "",
@@ -801,6 +817,9 @@ void Flint::initCmdParser()
 
     AddOptions("linkx", ' ', "", "Use this flag while burning to device a LinkX Component");
 
+    AddOptions("linkx_els", ' ', "",
+               "Use this flag while burning to device a LinkX_ELS(High Power laser​) Component");
+
     AddOptions("downstream_device_id_start_index",
                ' ',
                "<downstream_device_id_start_index>",
@@ -829,6 +848,22 @@ void Flint::initCmdParser()
                false,
                1);
 
+    AddOptions("run_module_image",
+               ' ',
+               "",
+               "Use this flag to switch FW banks on the module. By default, the command is not performed.",
+               false,
+               false,
+               1);
+ 
+    AddOptions("commit_module_image",
+               ' ',
+               "",
+               "Use this flag to switch committed bank on the module. By default, the command is not performed.",
+               false,
+               false,
+               1);
+
     AddOptions(
       "activate_delay_sec",
       ' ',
@@ -856,6 +891,9 @@ void Flint::initCmdParser()
                false,
                false,
                1);
+    AddOptions("i2c_secondary", ' ', "<i2c secondary address>", "Use this flag to specify I2C secondary address", false,
+               false, 1);
+
     AddOptions("openssl_engine", ' ', "<string>", "deprecated");
     AddOptions("openssl_key_id", ' ', "<string>", "deprecated");
     AddOptions("output_file", ' ', "<string>", "output file name for exporting the public key from PEM/BIN");
@@ -1149,6 +1187,10 @@ ParseStatus Flint::HandleOption(string name, string value)
     {
         _flintParams.no_fw_ctrl = true;
     }
+    else if (name == "skip_if_same")
+    {
+        _flintParams.skip_if_same = true;
+    }
     else if (name == "dual_image")
     {
         _flintParams.dual_image = true;
@@ -1243,6 +1285,10 @@ ParseStatus Flint::HandleOption(string name, string value)
     {
         _flintParams.linkx_control = true;
     }
+    else if (name == "linkx_els")
+    {
+        _flintParams.linkx_els_control = true;
+    }
     else if (name == "cpu_util")
     {
         _flintParams.use_cpu_utilization = true;
@@ -1293,6 +1339,16 @@ ParseStatus Flint::HandleOption(string name, string value)
         _flintParams.activate = true;
     }
 
+    else if (name == "run_module_image")
+    {
+        _flintParams.run_module_image = true;
+    }
+
+    else if (name == "commit_module_image")
+    {
+        _flintParams.commit_module_image = true;
+    }
+
     else if (name == "activate_delay_sec")
     {
         u_int64_t activate_delay_sec = 0;
@@ -1349,6 +1405,20 @@ ParseStatus Flint::HandleOption(string name, string value)
         _flintParams.cableDeviceSize = cableDeviceSize;
         _flintParams.cable_device_size_specified = true;
     }
+    else if (name == "i2c_secondary")
+    {
+        int i2cSecondaryAddr = 0;
+        if (!strToInt(value, i2cSecondaryAddr))
+        {
+            return PARSE_ERROR;
+        }
+        if (i2cSecondaryAddr < 0)
+        {
+            printf("Invalid I2C secondary address.\n");
+            return PARSE_ERROR;
+        }
+        _flintParams.i2cSecondaryAddr = i2cSecondaryAddr;
+    }
     else if (name == "cert_chain_index")
     {
         int cert_chain_index = 0;
@@ -1363,6 +1433,43 @@ ParseStatus Flint::HandleOption(string name, string value)
         }
         _flintParams.cert_chain_index = cert_chain_index;
     }
+    else if (name == "module_password")
+    {
+        if (value[0] == '0' && tolower(value[1]) == 'x')
+        {
+            value = value.substr(2);
+        }
+        if (value.length() != 8)
+        {
+            printf("module password length must be 4 bytes in hex.\n");
+            return PARSE_ERROR;
+        }
+        if (!std::all_of(value.begin(), value.end(), [](unsigned char c) { return std::isxdigit(c); }))
+        {
+            printf("module password must be in hex.\n");
+            return PARSE_ERROR;
+        }
+        _flintParams.modulePassword = value;
+    }
+    else if (name == "module_command_timeout")
+    {
+        if (!std::all_of(value.begin(), value.end(), [](unsigned char c) { return std::isdigit(c); }))
+        {
+            printf("module command timeout must be decimal.\n");
+            return PARSE_ERROR;
+        }
+        if (value.length() > 5)
+        {
+            printf("module command timeout value range is 0-99999.\n");
+            return PARSE_ERROR;
+        }
+
+        _flintParams.moduleCommandTimeout = value;
+    }
+    else if (name == "module_vendor_data")
+    {
+        _flintParams.moduleVendorDataFile = value;
+    }
     else if (name == "component_type")
     {
         _flintParams.component_type = value;
@@ -1371,6 +1478,10 @@ ParseStatus Flint::HandleOption(string name, string value)
     {
         _flintParams.imageSizeOnly = true;
     }
+    else if (name == "pending")
+    {
+        _flintParams.pending = true;
+    }
     else
     {
         cout << "Unknown Flag: " << name;
