@@ -44,14 +44,15 @@
  * Flint Status Code
  *********************/
 
-typedef enum
-{
-    FLINT_SUCCESS = 0,
-    FLINT_FAILED = 1,
-    FLINT_QUERY_ERROR = 2,
-    FLINT_BURN_ABORTED = 7
-} FlintStatus;
-
+ typedef enum
+ {
+     FLINT_SUCCESS = 0,
+     FLINT_FAILED = 1,
+     FLINT_QUERY_ERROR = 2,
+     FLINT_BURN_ABORTED = 7,
+     FLINT_BURN_TO = 8,
+     FLINT_BURN_ERROR = 9
+ } FlintStatus;
 /***********************
  * Flint Error Messages
  **********************/
@@ -115,6 +116,7 @@ typedef enum
 #define FLINT_FS3_BB_ERROR \
     "bb command is not supported anymore in FS3/FS4 images, please use b for burning FS3/FS4 images.\n"
 #define FLINT_FSX_BURN_ERROR "Burning %s image failed: %s\n"
+#define FLINT_FSPLDM_BURN_ERROR "Burning %s pldm component failed: %s\n"
 #define FLINT_FS2_BURN_ERROR "Burning FS2 image failed: %s\n"
 #define FLINT_PSID_ERROR "PSID mismatch. The PSID on flash (%s) differs from the PSID in the given image (%s).\n"
 #define FLINT_FS2_STRIPED_ERROR "The -striped_image cannot be used with the burn command\n"
