@@ -92,7 +92,8 @@ typedef enum
     SC_RSA_Sign,
     SC_Binary_Compare,
     SC_Export_Public_Key,
-    SC_Query_Components
+    SC_Query_Components,
+    SC_Query_Bfb_Components
 } sub_cmd_t;
 
 class FlintParams
@@ -182,21 +183,30 @@ public:
     bool hsm_password_specified;
     string hsm_password;
     bool linkx_control;
+    bool linkx_els_control;
     int cableDeviceIndex;
     int cableDeviceSize;
     bool cable_device_index_specified;
     bool cable_device_size_specified;
     bool linkx_auto_update;
     bool activate;
+    bool run_module_image;
+    bool commit_module_image;
     bool download_downstream_specified;
     bool downstream_device_ids_specified;
     std::vector<int> downstream_device_ids;
     bool download_transfer;
+    int i2cSecondaryAddr;
     u_int8_t activate_delay_sec;
     u_int32_t cert_chain_index;
+    std::string modulePassword;
+    std::string moduleCommandTimeout;
+    std::string moduleVendorDataFile;
     string component_type;
     bool imageSizeOnly;
     string cert_uuid;
+    bool skip_if_same;
+    bool pending;
 };
 
 #endif
