@@ -44,6 +44,7 @@
 
 #include <string>
 #include <memory>
+#include <map>
 
 #include <tools_layouts/tools_open_layouts.h>
 #include "tools_layouts/image_layout_layouts.h"
@@ -51,6 +52,8 @@
 #include "mlxfwops/lib/fw_ops.h"
 #include "mlxfwops/lib/fs_checks.h"
 #include "err_msgs.h"
+#include "mlxfwops/lib/fs_pldm.h"
+
 using namespace std;
 
 #ifndef NO_MSTARCHIVE
@@ -134,7 +137,7 @@ protected:
     static int dromCbFunc(int completion);
     static int wbCbFunc(int completion);
     static int resetCfgCbFunc(int completion);
-
+    
     bool printGuidLine(guid_t* new_guids, guid_t* old_guids, int guid_index);
     bool printMacLine(guid_t* new_guids, guid_t* old_guids, int mac_index);
     bool printGUIDsFunc(guid_t guids[GUIDS],
@@ -178,7 +181,7 @@ protected:
     bool getFileSize(const string& filePath, long& fileSize);
     bool writeToFile(string filePath, const std::vector<u_int8_t>& buff);
     FlintStatus writeImageToFile(const char* file_name, u_int8_t* data, u_int32_t length);
-
+    
     bool dumpFile(const char* confFile, std::vector<u_int8_t>& data, const char* sectionName);
     bool unzipDataFile(std::vector<u_int8_t> data, std::vector<u_int8_t>& newData, const char* sectionName);
     const char* fwImgTypeToStr(u_int8_t fwImgType);
@@ -222,13 +225,22 @@ public:
 class BurnSubCommand : public SubCommand
 {
 private:
+
+    enum class CableBurnFlow
+    {
+        Burn3rdParty,
+        Unknown
+    };
+
     u_int8_t _fwType;
     fw_info_t _devInfo;
     fw_info_t _imgInfo;
     FwOperations::ExtBurnParams _burnParams;
     bool _devQueryRes;
+    bool _shouldSkip;
     int _unknownProgress; // used to trace the progress of unknown progress.
     FwCompsMgr* fwCompsAccess;
+    FlintStatus burnPldmComp(u_int8_t** buff, u_int32_t& buffSize, FsPldmOperations* pldmOps);
     FlintStatus burnFs3();
     FlintStatus burnFs2();
     bool checkFwVersion(bool CreateFromImgInfo = true,
@@ -253,7 +265,12 @@ private:
                           bool activationNeeded,
                           bool downloadTransferNeeded,
                           int activate_delay_sec,
-                          ProgressCallBackAdvSt* ProgressFuncAdv);
+                          ProgressCallBackAdvSt* ProgressFuncAdv,
+                          FwComponent::comps_ids_t fwComponent);
+    FlintStatus BurnCMISCable();
+    FlintStatus ResetModule(string device);
+    FlintStatus WaitForModuleInit(string device);
+    FlintStatus PerformBurn(std::vector<u_int8_t>& fwImage, std::vector<u_int8_t>& vendorData);
 
 public:
     BurnSubCommand();
@@ -293,7 +310,7 @@ private:
     string printSecurityAttrInfo(u_int32_t m);
     FlintStatus printInfo(const fw_info_t& fwInfo, bool fullQuery);
     bool displayFs4Uids(const fw_info_t& fwInfo);
-    bool displayFs3Uids(const fw_info_t& fwInfo);
+    bool displayFs3Uids(const fw_info_t& fwInfo, bool isStripedImage);
     bool displayFs2Uids(const fw_info_t& fwInfo);
     bool checkMac(u_int64_t mac, string& warrStr);
     FlintStatus queryMFA2();
@@ -306,6 +323,7 @@ private:
                          char* delimeter,
                          bool isCSV);
     FlintStatus QueryLinkX(string deviceName, string outputFile, std::vector<int> deviceIds);
+    FlintStatus QueryCableAttributes();
     void PrintLifeCycle(const life_cycle_t& lifeCycle);
 
 public:
@@ -328,6 +346,23 @@ private:
     FwComponent::comps_ids_t _comp;
 };
 
+
+class QueryBfbComponentsSubCommand : public SubCommand
+{
+public:
+    QueryBfbComponentsSubCommand();
+    ~QueryBfbComponentsSubCommand();
+    bool verifyParams() override;
+    FlintStatus executeCommand() override;
+
+private:
+    bool _pending;
+    std::map<std::string, std::string> _name_to_version;
+
+    bool isDeviceSupported();
+    void printComponents();
+};
+
 class Extract4MBImageSubCommand : public SubCommand
 {
 private:
@@ -590,6 +625,7 @@ class HwSubCommand : public SubCommand
 private:
     FlintStatus printAttr(const ext_flash_attr_t& attr);
     bool PrintWriteProtectedBits(const ext_flash_attr_t& attr);
+    bool FillAttrIfNeeded(ext_flash_attr_t& attr, char* param_val_str, char* param_name);
 
 public:
     HwSubCommand();
