@@ -282,7 +282,8 @@ FlintStatus BurnSubCommand::BurnLinkX(string deviceName,
                                       bool activationNeeded,
                                       bool downloadTransferNeeded,
                                       int activate_delay_sec,
-                                      ProgressCallBackAdvSt* funcAdv)
+                                      ProgressCallBackAdvSt* funcAdv,
+                                      FwComponent::comps_ids_t fwComponent)
 {
     if (preFwOps() == FLINT_FAILED)
     {
@@ -323,16 +324,19 @@ FlintStatus BurnSubCommand::BurnLinkX(string deviceName,
     FwCompsMgr fwCompsAccess(mfile, FwCompsMgr::DEVICE_HCA_SWITCH, 0);
     fwCompsAccess.GenerateHandle();
     bool isSecondary = false;
-    if (/*(mfile->flags & MDEVS_IB) && */ !fwCompsAccess.IsSecondaryHost(isSecondary)) // TODO - check if limitation
-                                                                                       // applicable to IB only
+    if (fwComponent != FwComponent::COMPID_LINKX_ELS)
     {
-        printf("-E- Failed to query if device is secondary\n");
-        return FLINT_FAILED;
-    }
-    if (isSecondary)
-    {
-        printf("-E- LinkX burn is not supported by secondary.\n");
-        return FLINT_FAILED;
+        if (/*(mfile->flags & MDEVS_IB) && */ !fwCompsAccess.IsSecondaryHost(isSecondary)) // TODO - check if limitation
+                                                                                        // applicable to IB only
+        {
+            printf("-E- Failed to query if device is secondary\n");
+            return FLINT_FAILED;
+        }
+        if (isSecondary)
+        {
+            printf("-E- LinkX burn is not supported by secondary.\n");
+            return FLINT_FAILED;
+        }
     }
     fwCompsAccess.SetIndexAndSize(deviceIndex + 1, deviceSize, linkx_auto_update, activationNeeded,
                                   downloadTransferNeeded, activate_delay_sec);
@@ -342,7 +346,7 @@ FlintStatus BurnSubCommand::BurnLinkX(string deviceName,
         return FLINT_FAILED;
     }
 
-    bootImageComponent.init(binaryData, binaryData.size(), FwComponent::COMPID_LINKX);
+    bootImageComponent.init(binaryData, binaryData.size(), fwComponent);
     compsToBurn.push_back(bootImageComponent);
     if (downloadTransferNeeded)
     {
