@@ -43,6 +43,7 @@
 
 #include <vector>
 #include <string>
+#include <map>
 #include "reg_access/reg_access.h"
 #include "mlxfwops/uefi_c/mft_uefi_common.h"
 #include "mlxfwops/lib/mlxfwops_com.h"
@@ -139,6 +140,9 @@ typedef struct
     u_int32_t ini_file_version;
     u_int8_t geo_address;
     bool geo_address_valid;
+    uint8_t independent_module;
+    uint8_t pci_switch_only_mode;
+    uint8_t pci_switch_only_mode_valid;
 
 } fwInfoT;
 
@@ -177,6 +181,7 @@ class FwComponent
 public:
     typedef enum
     {
+        COMPID_FIRST_IDX = 0x1,
         COMPID_BOOT_IMG = 0x1,
         COMPID_RUNTIME_IMG = 0x2,
         COMPID_USER_NVCONFIG = 0x3,
@@ -198,7 +203,10 @@ public:
         DIGITAL_CACERT_CHAIN = 0x16,
         DIGITAL_CACERT_REMOVAL = 0x17,
         DIGITAL_CACERT_CHAIN_REMOVAL = 0x18,
-        COMPID_UNKNOWN = 0xff,
+        COMPID_LINKX_ELS = 0x1a,
+        COMPID_BFB = 0x1b,
+        COMPID_LAST_IDX = 0x1b,
+        COMPID_UNKNOWN = 0xFFFF,
     } comps_ids_t;
 
     typedef enum
@@ -441,6 +449,10 @@ public:
                     u_int32_t local_port = 0,
                     u_int8_t pnat = 0,
                     u_int32_t lp_msb = 0);
+    u_int8_t GetSecureHostState() { return _secureHostState; }
+    bool IsDevicePresent(FwComponent::comps_ids_t compType);
+    bool queryMISOC(std::string& version, u_int32_t type, u_int32_t query_pending);
+    bool runMISOC(reg_access_hca_misoc_reg_ext* bfb_component, u_int32_t type, u_int32_t query_pending);
 
 private:
     typedef enum
@@ -575,7 +587,6 @@ private:
     void extractRomInfo(mgirReg* mgir, fwInfoT* fwQuery);
     bool isDMAAccess();
     bool fallbackToRegisterAccess();
-    bool IsDevicePresent(FwComponent::comps_ids_t compType);
 
     std::vector<comp_query_st> _compsQueryMap;
     bool _fwSupport;
@@ -611,5 +622,6 @@ private:
 #ifndef UEFI_BUILD
     trm_ctx _trm;
 #endif
+    u_int8_t _secureHostState;
 };
 #endif /* USER_MLXFWOPS_LIB_FW_COMPS_MGR_H_ */
