@@ -123,7 +123,7 @@ int mclose(mfile* mf);
 
 void get_pci_dev_rdma(mfile* mf, char* buf);
 
-unsigned char mset_i2c_slave(mfile* mf, unsigned char new_i2c_slave);
+unsigned char mset_i2c_secondary(mfile* mf, unsigned char new_i2c_secondary);
 
 int mget_mdevs_flags(mfile* mf, u_int32_t* devs_flags);
 
@@ -175,7 +175,7 @@ const char* m_err2str(MError status);
 int mread_buffer(mfile* mf, unsigned int offset, u_int8_t* data, int byte_len);
 int mwrite_buffer(mfile* mf, unsigned int offset, u_int8_t* data, int byte_len);
 
-int mget_vsec_supp(mfile* mf);
+int is_gw_access(mfile* mf);
 
 int mget_addr_space(mfile* mf);
 int mset_addr_space(mfile* mf, int space);
