@@ -100,9 +100,6 @@ typedef long long int64_t;
 #define SMP_SEMAPHOE_LOCK_CMD 0xff53
 #define ADDRESS_OUT_OF_RANGE  0x3 /* syndrome_code value */
 
-#define CX8_HW_ID 0x21e
-#define CX9_HW_ID 0x225
-
 /*
  * MST <--> MTCR API defines
  */
@@ -126,11 +123,22 @@ typedef struct mib_private_t {
 /*#include "mtcr_ib_private.h" */
 /*#endif */
 
+
+#define MTCR_I2C_secondary_ADDRESS 0x48
+#define SLV_ADDRS_NUM              128
+
+
 typedef enum {
     SEM_LOCK_GET = 0x0,
     SEM_LOCK_SET = 0x1
 } sem_lock_method_t;
 
+/* PCI operation enum(read or write)*/
+typedef enum {
+    READ_OP  = 0,
+    WRITE_OP = 1,
+} rw_op_t;
+
 typedef enum MError {
     ME_OK = 0,
     ME_ERROR,
@@ -178,6 +186,7 @@ typedef enum MError {
     ME_REG_ACCESS_ERASE_EXCEEDED,
     ME_REG_ACCESS_INTERNAL_ERROR,
     ME_REG_ACCESS_NOT_SUPPORTED_BY_SECONDARY,
+    ME_REG_ACCESS_INSUFFICIENT_PERMISSIONS,
     ME_REG_ACCESS_NOT_READY,
     ME_REG_ACCESS_EXCEED_LIM,
     ME_REG_ACCESS_BAD_RES_STATE,
@@ -203,6 +212,7 @@ typedef enum MError {
     ME_ICMD_ICM_NOT_AVAIL,
     ME_ICMD_WRITE_PROTECT,
     ME_ICMD_SIZE_EXCEEDS_LIMIT,
+    ME_ICMD_UNABLE_TO_TAKE_SEMAOHORE,
 
     /* errors regarding Tools CMDIF */
     ME_CMDIF_BUSY = 0x300,
@@ -267,7 +277,8 @@ typedef enum MType_t {
     MST_DRIVER_CR   = 0x80000,
     MST_LINKX_CHIP  = 0x100000,
     MST_BAR0_GW_PCI = 0x200000,
-    MST_GEARBOX     = 0x400000,
+    MST_NVML        = 0x400000,
+    MST_VFIO_DEVICE = 0x800000,
     MST_DEFAULT     = 0xffffffff & ~MST_CABLE & ~MST_FPGA & ~MST_FPGA_ICMD & ~MST_FPGA_DRIVER & ~MST_LINKX_CHIP
 } MType;
 
@@ -504,7 +515,7 @@ typedef struct gearbox_info_t {
     gearbox_connection_t gb_conn_type;
     char                 gb_mngr_full_name[DEV_NAME_SZ];
     char                 gearbox_full_name[DEV_NAME_SZ];
-    unsigned char        i2c_slave;
+    unsigned char        i2c_secondary;
     u_int8_t             addr_width;
     char                 device_orig_name[DEV_NAME_SZ];
     char                 device_real_name[DEV_NAME_SZ];
@@ -516,6 +527,9 @@ typedef struct cables_info_t {
     int slave_addr_additional_offset;
 } cables_info;
 
+#define HW_ID_ADDR 0xf0014
+
+
 #define VSEC_MIN_SUPPORT_UL(mf)                                     \
     (((mf)->vsec_cap_mask & (1 << VCC_INITIALIZED)) &&              \
      ((mf)->vsec_cap_mask & (1 << VCC_CRSPACE_SPACE_SUPPORTED)) &&  \
