@@ -54,7 +54,7 @@ struct page_list_fbsd {
 #endif
 
 /*  All fields in follow structure are not supposed to be used */
-/*  or modified by user programs. Except i2c_slave that may be */
+/*  or modified by user programs. Except i2c_secondary that may be */
 /*  modified before each access to target I2C slave address */
 struct mfile_t {
     u_int16_t     hw_dev_id;
@@ -69,7 +69,7 @@ struct mfile_t {
     int           is_vm;  /*  if the machine is VM    */
     int           cr_access; /* If cr access is allowed in MLNXOS devices */
     cables_info   ext_info; /*keeps info for calculate the correct slave address (0x50 + offset) */
-    unsigned char i2c_slave;
+    unsigned char i2c_secondary;
     int           gpio_en;
     io_region   * iorw_regions; /* For LPC devices */
     int           regions_num;
@@ -120,7 +120,8 @@ struct mfile_t {
     unsigned int pxir_vsec_supp;
     u_int8_t       vsec_type;
     mtcr_status_e  icmd_support;
-    unsigned int   vsec_addr;
+    u_int64_t   vsec_addr;
+    u_int64_t   address_region_addr;
     u_int32_t      vsec_cap_mask;
     int            address_space;
     int            multifunction;
@@ -161,6 +162,7 @@ struct mfile_t {
     int                     is_remote;
     int                     is_zombiefish;
     int                     vsc_recovery_space_flash_control_vld;
+    void*                   nvml_device; /* libnvml device object. */
 };
 
 #endif /* ifndef __MTCR_MF__ */
