@@ -56,36 +56,105 @@ static const char mst_driver_string[] = "Mellanox Technologies Software Tools Dr
 
 LIST_HEAD(mst_devices);
 
+// PCI Device IDs.
+#define CONNECTX3_PCI_ID 4099
+#define CONNECTX3PRO_PCI_ID 4103
+#define CONNECTIB_PCI_ID 4113
+#define CONNECTX4_PCI_ID 4115
+#define CONNECTX4LX_PCI_ID 4117
+#define CONNECTX5_PCI_ID 4119
+#define CONNECTX5EX_PCI_ID 4121
+#define CONNECTX6_PCI_ID 4123
+#define CONNECTX6DX_PCI_ID 4125
+#define CONNECTX6LX_PCI_ID 4127
+#define CONNECTX7_PCI_ID 4129
+#define CONNECTX7_RMA_PCI_ID 537
+#define CONNECTX8_PCI_ID 4131
+#define CONNECTX8_RMA_PCI_ID 543
+#define CONNECTX9_PCI_ID 4133
+#define CONNECTX10_PCI_ID 4135
+#define SCHRODINGER_PCI_ID 6518
+#define FREYSA_PCI_ID 6521
+#define CONNECTX8_BRIDGE_PCI_ID 6525
+#define BLUEFIELD_PCI_ID 41682
+#define BLUEFIELD2_PCI_ID 41686
+#define BLUEFIELD_DPU_AUX_PCI_ID 49873
+#define BLUEFIELD3_PCI_ID 41692
+#define BLUEFIELD3_RMA_PCI_ID 541
+#define BLUEFIELD4_PCI_ID 41694
+#define SWITCHIB_PCI_ID 52000
+#define SWITCHIB2_PCI_ID 53000
+#define QUANTUM_PCI_ID 54000
+#define QUANTUM2_PCI_ID 54002
+#define QUANTUM2_RMA_PCI_ID 600
+#define QUANTUM3_PCI_ID 54004
+#define QUANTUM3_RMA_PCI_ID 604
+#define QUANTUM4_PCI_ID 54008
+#define SPECTRUM_PCI_ID 52100
+#define SPECTRUM2_PCI_ID 53100
+#define SPECTRUM3_PCI_ID 53104
+#define SPECTRUM4_PCI_ID 53120
+#define SPECTRUM4_RMA_PCI_ID 597
+#define GB100_PCI_ID 10496
+#define GR100_PCI_ID 12288
+#define GR150_PCI_ID 13440
+
+
+#define LF_SPECTRUM_PCI_ID 0x249
+#define LF_SWITCHIB2_PCI_ID 0x24b
+#define LF_SWITCHIB_PCI_ID 0x247
+#define LF_CONNECTX4_PCI_ID 0x209
+#define LF_CONNECTX4LX_PCI_ID 0x20b
+#define LF_CONNECTX5_PCI_ID 0x20d
+#define LF_CONNECTX6_PCI_ID 0x20f
+#define LF_CONNECTX6DX_PCI_ID 0x212
+#define LF_CONNECTX6LX_PCI_ID 0x216
+#define LF_CONNECTX7_PCI_ID 0x218
+#define LF_CONNECTX8_PCI_ID 0x21e
+#define LF_CONNECTX9_PCI_ID 0x224
+#define LF_QUANTUM_PCI_ID 0x24d
+#define LF_QUANTUM2_PCI_ID 0x257
+#define LF_QUANTUM3_PCI_ID 0x25b
+#define LF_QUANTUM4_PCI_ID 0x278
+#define LF_SPECTRUM2_PCI_ID 0x24e
+#define LF_SPECTRUM3_PCI_ID 0x250
+#define LF_SPECTRUM4_PCI_ID 0x254
+#define LF_SPECTRUM5_PCI_ID 0x270
+#define LF_SPECTRUM6_PCI_ID 0x274
+#define LF_SPECTRUM6_IB_PCI_ID 0x276
+#define LF_BLUEFIELD_PCI_ID 0x211
+#define LF_BLUEFIELD2_PCI_ID 0x214
+#define LF_BLUEFIELD3_PCI_ID 0x21c
+#define LF_BLUEFIELD4_PCI_ID 0x220
+
 static struct pci_device_id mst_livefish_pci_table[] = {
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x01f6)}, /* MT27500 Family [ConnectX-3 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x01f8)}, /* MT27520 Family [ConnectX-3 Pro Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x01ff)}, /* MT27600 Family [Connect-IB Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0209)}, /* MT27700 Family [ConnectX-4 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x020b)}, /* MT27710 Family [ConnectX-4 Lx Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x020d)}, /* MT28800 Family [ConnectX-5 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x020f)}, /* MT28908A0 Family [ConnectX-6 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0210)}, /* MT28908A0 Family [ConnectX-6 Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0211)}, /* MT416842 Family [BlueField SoC Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0212)}, /* MT2892 Family [ConnectX-6 Dx Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0213)}, /* MT2892 Family [ConnectX-6 Dx Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0214)}, /* MT42822 Family [BlueField-2 SoC Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0215)}, /* MT42822 Family [BlueField-2 Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0216)}, /* MT2894 Family [ConnectX-6 Lx Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0217)}, /* MT2894 Family [ConnectX-6 Lx Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0218)}, /* MT2910 Family [ConnectX-7 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0219)}, /* MT2910 Family [ConnectX-7 Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021a)}, /* MT43162 Family [BlueField-3 Lx SoC Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021b)}, /* MT43162 Family [BlueField-3 Lx Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021c)}, /* MT43244 Family [BlueField-3 SoC Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021d)}, /* MT43244 Family [BlueField-3 Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021e)}, /* CX8 Family [ConnectX-8 Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021e)}, /* CX8 Family [ConnectX-8 Secure Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x0220)}, /* BF4 Family Flash Recovery [BlueField-4 SoC Flash Recovery] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 0x021e)}, /* BF4 Family Secure Flash Recovery [BlueField-4 Secure Flash Recovery]
-                                                    */
-    {
-        0,
-    }
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SWITCHIB2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SWITCHIB_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX4LX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX5_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX6_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX6DX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX6LX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX7_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX8_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_CONNECTX9_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_QUANTUM_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_QUANTUM2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_QUANTUM3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_QUANTUM4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM5_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM6_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_SPECTRUM6_IB_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_BLUEFIELD_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_BLUEFIELD2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_BLUEFIELD3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, LF_BLUEFIELD4_PCI_ID)},
+    {0}
 };
 
 static struct pci_device_id mst_bar_pci_table[] = {
@@ -97,25 +166,48 @@ static struct pci_device_id mst_bar_pci_table[] = {
 };
 
 static struct pci_device_id supported_pci_devices[] = {
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4099)}, /* MT27500 Family [ConnectX-3] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4103)}, /* MT27520 Family [ConnectX-3Pro] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4113)}, /* MT27600 Family [ConnectX-IB] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4115)}, /* MT27620 Family [ConnectX-4] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4117)}, /* MT2763.00.l0 Family [ConnectX-4Lx] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4119)}, /* MT27800 Family [ConnectX-5] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4121)}, /* MT28800 Family [ConnectX-5EX] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4123)}, /* MT28908 Family [ConnectX-6] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4125)}, /* MT2892 Family [ConnectX-6DX] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4127)}, /* MT2894 Family [ConnectX-6LX] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 4129)}, /* MT2910 Family [ConnectX-7] */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 41682)}, /* MT416842 Family BlueField integrated ConnectX-5 network controller */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 41686)}, /* MT42822 Family BlueField2 integrated ConnectX-6 DX network controller
-                                                   */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 41692)}, /* MT43244 Family BlueField3 integrated ConnectX-7 network controller */
-    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, 41694)}, /* BF4 Family integrated network controller */
-    {
-        0,
-    }
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX3PRO_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTIB_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX4LX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX5_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX5EX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX6_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX6DX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX6LX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX7_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX7_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX8_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX8_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX9_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX10_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SCHRODINGER_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, FREYSA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, CONNECTX8_BRIDGE_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD_DPU_AUX_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD3_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, BLUEFIELD4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SWITCHIB_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SWITCHIB2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM2_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM3_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, QUANTUM4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SPECTRUM_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SPECTRUM2_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SPECTRUM3_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SPECTRUM4_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, SPECTRUM4_RMA_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, GB100_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, GR100_PCI_ID)},
+    {PCI_DEVICE(MST_MELLANOX_PCI_VENDOR, GR150_PCI_ID)},
+    {0}
 };
 
 /****************** VSEC SUPPORT ********************/
@@ -212,15 +304,18 @@ enum {
 #define VSEC_FULLY_SUPPORTED(dev) \
     (((dev)->functional_vsc_offset) && ((dev)->spaces_support_status == SS_ALL_SPACES_SUPPORTED))
 
-void swap_pci_address_space(int* address_space)
+static void swap_pci_address_space(int* address_space)
 {
     switch (*address_space) {
     case AS_ICMD_EXT:
         *address_space = AS_PCI_ICMD;
+        fallthrough;
 
     case AS_ND_CRSPACE:
+        fallthrough;
     case AS_CR_SPACE:
         *address_space = AS_PCI_CRSPACE;
+        fallthrough;
 
     case AS_ICMD:
         *address_space = AS_PCI_ALL_ICMD;
@@ -263,7 +358,7 @@ void swap_pci_address_space(int* address_space)
 }
 
 
-int get_syndrome_code(struct mst_dev_data* dev, u_int8_t* syndrome_code)
+static int get_syndrome_code(struct mst_dev_data* dev, u_int8_t* syndrome_code)
 {
     /* In case syndrome is set, if syndrome_code is 0x3 (address_out_of_range), return the syndrome_code, so that the */
     /* ioctl will fail and then we'll retry with PCI space. */
@@ -618,7 +713,7 @@ static int read4_vsec(struct mst_dev_data* dev, int address_space, unsigned int
     return 0; /* OPERATIONAL and LOGICAL success (PCI VSC address_spaces not supported) */
 }
 
-int pciconf_read4_legacy(struct mst_dev_data* dev, unsigned int offset, unsigned int* data)
+static int pciconf_read4_legacy(struct mst_dev_data* dev, unsigned int offset, unsigned int* data)
 {
     int          res = 0;
     unsigned int new_offset = offset;
@@ -646,7 +741,7 @@ int pciconf_read4_legacy(struct mst_dev_data* dev, unsigned int offset, unsigned
     return 0;
 }
 
-int pciconf_write4_legacy(struct mst_dev_data* dev, unsigned int offset, unsigned int data)
+static int pciconf_write4_legacy(struct mst_dev_data* dev, unsigned int offset, unsigned int data)
 {
     int res = 0;
 
@@ -753,7 +848,7 @@ static int get_space_support_status(struct mst_dev_data* dev)
 
 #define WO_REG_ADDR_DATA 0xbadacce5
 #define DEVID_OFFSET     0xf0014
-int is_wo_gw(struct pci_dev* pcidev, unsigned int addr_reg)
+static int is_wo_gw(struct pci_dev* pcidev, unsigned int addr_reg)
 {
     int          ret;
     unsigned int data = 0;
@@ -1502,7 +1597,7 @@ static int mst_ioctl(struct inode* inode, struct file* file, unsigned int opcode
 
         dev->hw_addr = ioremap(resource_start, MST_MEMORY_SIZE);
 
-        if (dev->hw_addr <= 0) {
+        if (!dev->hw_addr) {
             mst_err("could not map device memory\n");
             res = -EFAULT;
             goto fin;
@@ -1780,7 +1875,7 @@ static struct mst_dev_data* mst_device_create(enum dev_type type, struct pci_dev
         dev->data_reg = 0;     /* invalid */
         dev->bar = 0;
         dev->hw_addr = ioremap(pci_resource_start(pdev, dev->bar), MST_MEMORY_SIZE);
-        if (dev->hw_addr <= 0) {
+        if (!dev->hw_addr) {
             mst_err("could not map device memory, BAR: %x\n", dev->bar);
             goto out;
         }
@@ -1867,7 +1962,8 @@ static int __init mst_init(void)
 
     mst_info("%s - version %s\n", mst_driver_string, mst_driver_version);
 
-    while ((pdev = pci_get_device(MST_MELLANOX_PCI_VENDOR, PCI_ANY_ID, pdev)) != NULL) {
+    while ((pdev = pci_get_device(MST_MELLANOX_PCI_VENDOR, PCI_ANY_ID, pdev)) != NULL)
+    {
         if (!pci_match_id(supported_pci_devices, pdev) && !pci_match_id(mst_livefish_pci_table, pdev)) {
             continue;
         }
