@@ -38,6 +38,7 @@
 #define WINBOND_NAME "W25QxxBV"
 #define WINBOND_W25X "W25Xxx"
 #define WINBOND_3V_NAME "W25Qxxx"
+#define WINBOND_1V8_NAME "W25QxxxNW"
 #define ATMEL_NAME "AT25DFxxx"
 #define S25FLXXXP_NAME "S25FLXXXP"
 #define S25FL116K_NAME "S25FL11xx"
@@ -46,9 +47,12 @@
 #define CYPRESS_3V_NAME "S25FLxxx"
 #define ISSI_3V_NAME "IS25LPxxx"
 #define MICRON_3V_NAME "MT25QLxxx"
+#define MICRON_1V8_NAME "MT25QUxxx"
 #define MACRONIX_1V8_NAME "MX25Uxxx"
 #define GIGA_3V_NAME "GD25LBxxx"
+#define GIGA_1V8_NAME "GD25LBxxxMF"
 #define ISSI_HUAWEY_NAME "IS25WPxxx"
+#define ISSI_NAME "IS25LPxxx"
 
 typedef enum flash_vendor
 {
@@ -69,17 +73,24 @@ typedef enum flash_memory_type
     FMT_MX25K16XXX = 0x20,
     FMT_ST_M25PX = 0x71,
     FMT_SST_25 = 0x25,
+    FMT_SST_28 = 0x28,
     FMT_WINBOND = 0x40,
     FMT_WINBOND_W25X = 0x30,
     FMT_WINBOND_3V = 0x70,
+    FMT_WINBOND_IQ = 0x60,
+    FMT_WINBOND_IM = 0x80,
     FMT_ATMEL = 0x2,
     FMT_N25QXXX = 0xba,
+    FMT_N25QUXXX = 0xbb,
     FMT_S25FLXXXP = 0x02,
     FMT_S25FL116K = 0x40,
     FMT_S25FLXXXL = 0x60,
     FMT_MT25QLXXXABA = 0xba,
     FMT_IS25LPXXX = 0x60,
-    FVT_GD25QXXX = 0x40
+    FMT_IS25WPXXX = 0x70,
+    FVT_GD25QXXX = 0x40,
+    FVT_GD25LBXXX = 0x60
+
 
 } flash_memory_type_t;
 
@@ -91,7 +102,7 @@ typedef enum flash_densities
     FD_64 = 0x17,
     FD_128 = 0x18,
     FD_256 = 0x19,
-    FD_512 = 0x1a
+    FD_512 = 0x1a // flash vendors advertise 0x20
 } flash_densities_t;
 
 #endif /* USER_MFLASH_FLASH_INT_DEFS_H_ */
