@@ -104,13 +104,18 @@ enum FlashConstant
     WRITE_STATUS_REGISTER_DELAY_MIN = 40,
 
     DUMMY_CYCLES_OFFSET_ST = 12,
+    DUMMY_CYCLES_OFFSET_MACRONIX_MX25UXXX = 5,
+    DUMMY_CYCLES_BIT_LEN_MACRONIX_MX25UXXX = 2,
 
     QUAD_EN_OFFSET_WINBOND_CYPRESS = 1,
     QUAD_EN_OFFSET_MICRON = 3,
     QUAD_EN_OFFSET_ISSI_MACRONIX = 6,
     QUAD_EN_OFFSET_GIGABYTE = 1,
+    COMPLEMENT_PROTECT_OFFSET_WINBOND = 6,
     DRIVER_STRENGTH_OFFSET_MICRON = 6,
+    DRIVER_STRENGTH_OFFSET_MACRONIX_MX25UXXX = 0,
     DRIVER_STRENGTH_BIT_LEN_MICRON = 3,
+    DRIVER_STRENGTH_BIT_LEN_MACRONIX = 3,
     DRIVER_STRENGTH_OFFSET_WINBOND = 5,
     DRIVER_STRENGTH_BIT_LEN_WINBOND = 2,
     DRIVER_STRENGTH_VAL_100_WINBOND = 0,
@@ -129,12 +134,20 @@ enum FlashConstant
     DRIVER_STRENGTH_VAL_45_ISSI = 3,
     DRIVER_STRENGTH_VAL_60_ISSI = 2,
     DRIVER_STRENGTH_VAL_90_ISSI = 1,
-    DRIVER_STRENGTH_VAL_120_MICRON_MX25K16XXX = 0,
-    DRIVER_STRENGTH_VAL_100_MICRON_MX25K16XXX = 1,
-    DRIVER_STRENGTH_VAL_85_MICRON_MX25K16XXX = 2,
-    DRIVER_STRENGTH_VAL_50_MICRON_MX25K16XXX = 3,
-    DRIVER_STRENGTH_BIT_LEN_MICRON_MX25K16XXX = 2,
-    DRIVER_STRENGTH_OFFSET_MICRON_MX25K16XXX = 5,
+    DRIVER_STRENGTH_VAL_120_MACRONIX_MX25K16XXX = 0,
+    DRIVER_STRENGTH_VAL_100_MACRONIX_MX25K16XXX = 1,
+    DRIVER_STRENGTH_VAL_85_MACRONIX_MX25K16XXX = 2,
+    DRIVER_STRENGTH_VAL_50_MACRONIX_MX25K16XXX = 3,
+    DRIVER_STRENGTH_VAL_146_MACRONIX_MX25UXXX = 0,
+    DRIVER_STRENGTH_VAL_76_MACRONIX_MX25UXXX = 1,
+    DRIVER_STRENGTH_VAL_52_MACRONIX_MX25UXXX = 2,
+    DRIVER_STRENGTH_VAL_41_MACRONIX_MX25UXXX = 3,
+    DRIVER_STRENGTH_VAL_34_MACRONIX_MX25UXXX = 4,
+    DRIVER_STRENGTH_VAL_30_MACRONIX_MX25UXXX = 5,
+    DRIVER_STRENGTH_VAL_26_MACRONIX_MX25UXXX = 6,
+    DRIVER_STRENGTH_VAL_24_MACRONIX_MX25UXXX = 7,
+    DRIVER_STRENGTH_BIT_LEN_MACRONIX_MX25K16XXX = 2,
+    DRIVER_STRENGTH_OFFSET_MACRONIX_MX25K16XXX = 5,
     TB_OFFSET_MACRONIX = 3,
     SEC_OFFSET = 6,
     TB_OFFSET = 5,
@@ -142,6 +155,7 @@ enum FlashConstant
     TB_OFFSET_CYPRESS_WINBOND_256 = 6,
     BP_OFFSET = 2,
     BP_4TH_BIT_OFFSET_MICRON = 6,
+    SRWD_OFFSET_ISSI = 7,
     BP_SIZE = 3,
     PROTECT_BITS_SIZE = 5
 };
@@ -163,6 +177,7 @@ int sx_set_driver_strength(mflash* mfl, u_int8_t driver_strength);
 int sx_get_driver_strength(mflash* mfl, u_int8_t* driver_strength);
 int sx_set_write_protect(mflash* mfl, u_int8_t bank_num, write_protect_info_t* protect_info);
 int sx_get_write_protect(mflash* mfl, u_int8_t bank_num, write_protect_info_t* protect_info);
+uint8_t sx_get_bp_val(mflash* mfl, write_protect_info_t* protect_info);
 int sx_set_dummy_cycles(mflash* mfl, u_int8_t num_of_cycles);
 int sx_get_dummy_cycles(mflash* mfl, u_int8_t* num_of_cycles);
 int gw_wait_ready(mflash* mfl, const char* msg);
