@@ -65,6 +65,8 @@ int is_four_byte_address_needed(mflash* mfl, MfError* status)
         case DeviceConnectX6:
         case DeviceConnectX7:
         case DeviceConnectX8:
+        case DeviceConnectX9:
+        case DeviceConnectX8PurePcieSwitch:
         case DeviceConnectX6DX:
         case DeviceConnectX6LX:
         case DeviceSpectrum2:
