@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2013-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -42,7 +42,8 @@
 
 #include "errmsg.h"
 
-enum {
+enum
+{
     SUCCESS = 0,
     FAILURE = 1
 };
@@ -69,12 +70,12 @@ ErrMsg::~ErrMsg()
     err_clear();
 }
 
-const char* ErrMsg::getFormatErr(const char *prefix, ...)
+const char* ErrMsg::getFormatErr(const char* prefix, ...)
 {
     va_list args;
-    char *prevFormatErr = _formatErr;
+    char* prevFormatErr = _formatErr;
     va_start(args, prefix);
-    char *preStr = vprint(prefix, args);
+    char* preStr = vprint(prefix, args);
     int formatErrSz = strlen(_err) + strlen(preStr) + 10;
     _formatErr = new char[formatErrSz];
     snprintf(_formatErr, formatErrSz, "-E- %s. %s", preStr, _err);
@@ -87,35 +88,38 @@ const char* ErrMsg::getFormatErr(const char *prefix, ...)
 const char* ErrMsg::err2Str(int errCode) const
 {
     std::map<int, std::string>::const_iterator it;
-    if ( (it = _errMap.find(errCode)) == _errMap.end()) {
+    if ((it = _errMap.find(errCode)) == _errMap.end())
+    {
         return "Unknown Error Code";
     }
     return it->second.c_str();
 }
 
-char* ErrMsg::vprint(const char *format, va_list args)
+char* ErrMsg::vprint(const char* format, va_list args)
 {
     const int INIT_VAL = 1024;
     int max_str, max_buf = INIT_VAL;
-    char      *out_buf;
+    char* out_buf;
 
-    while (1) {
+    while (1)
+    {
         out_buf = new char[max_buf];
         max_str = max_buf - 1;
 
-        if (vsnprintf(out_buf, max_str, format, args) < max_str) {
+        if (vsnprintf(out_buf, max_str, format, args) < max_str)
+        {
             return out_buf;
         }
-        delete [] out_buf;
+        delete[] out_buf;
         max_buf *= 2;
     }
 }
 
-int ErrMsg::errmsg(const char *format, ...)
+int ErrMsg::errmsg(const char* format, ...)
 {
     va_list args;
 
-    char *prev_err = _err;
+    char* prev_err = _err;
 
     va_start(args, format);
     _err = vprint(format, args);
@@ -126,10 +130,10 @@ int ErrMsg::errmsg(const char *format, ...)
     return FAILURE;
 }
 
-int ErrMsg::errmsg(int errCode, const char *format, ...)
+int ErrMsg::errmsg(int errCode, const char* format, ...)
 {
     va_list args;
-    char *prev_err = _err;
+    char* prev_err = _err;
 
     va_start(args, format);
     _err = vprint(format, args);
@@ -142,28 +146,33 @@ int ErrMsg::errmsg(int errCode, const char *format, ...)
 
 int ErrMsg::errmsg(int errCode)
 {
-    char *prevErr = _err;
+    char* prevErr = _err;
     int errSz = strlen(err2Str(errCode)) + 1;
-    char *newError = new char[errSz];
+    char* newError = new char[errSz];
     snprintf(newError, errSz, "%s", err2Str(errCode));
     _err = newError;
     delete[] prevErr;
     _lastErrCode = errCode;
     return errCode;
-
 }
-void ErrMsg::errmsgConcatCom(const char *format, va_list args, const char *suffix)
+void ErrMsg::errmsgConcatCom(const char* format, va_list args, const char* suffix)
 {
-    char *prevErr = _err;
-    char *currError = vprint(format, args);
+    char* prevErr = _err;
+    char* currError = vprint(format, args);
     int errSz = strlen(currError) + strlen(suffix) + 10;
-    char *newError = new char[errSz];
-    if (strlen(currError) == 0) {
+    char* newError = new char[errSz];
+    if (strlen(currError) == 0)
+    {
         snprintf(newError, errSz, "%s", suffix);
-    } else {
-        if (strlen(suffix) == 0) {
+    }
+    else
+    {
+        if (strlen(suffix) == 0)
+        {
             snprintf(newError, errSz, "%s", currError);
-        } else {
+        }
+        else
+        {
             snprintf(newError, errSz, "%s. %s", currError, suffix);
         }
     }
@@ -173,7 +182,7 @@ void ErrMsg::errmsgConcatCom(const char *format, va_list args, const char *suffi
     delete[] currError;
 }
 
-int ErrMsg::errmsgConcatMsg(int errCode, const ErrMsg& errMsgObj, const char *format, ...)
+int ErrMsg::errmsgConcatMsg(int errCode, const ErrMsg& errMsgObj, const char* format, ...)
 {
     va_list args;
     va_start(args, format);
@@ -183,7 +192,7 @@ int ErrMsg::errmsgConcatMsg(int errCode, const ErrMsg& errMsgObj, const char *fo
     return errCode;
 }
 
-int ErrMsg::errmsgConcatMsg(const ErrMsg& errMsgObj, const char *format, ...)
+int ErrMsg::errmsgConcatMsg(const ErrMsg& errMsgObj, const char* format, ...)
 {
     va_list args;
     va_start(args, format);
@@ -203,7 +212,7 @@ int ErrMsg::errmsgConcatMsg(const ErrMsg& errMsgObj)
     return errmsg("%s", errMsgObj.err());
 }
 
-int ErrMsg::errmsgConcatErrCd(int errCode, const ErrMsg& errMsgObj, const char *format, ...)
+int ErrMsg::errmsgConcatErrCd(int errCode, const ErrMsg& errMsgObj, const char* format, ...)
 {
     va_list args;
     va_start(args, format);
@@ -226,10 +235,8 @@ int ErrMsg::errmsgConcatErrCd(const ErrMsg& errMsgObj)
 
 void ErrMsg::err_clear()
 {
-    delete [] _err;
-    delete [] _formatErr;
+    delete[] _err;
+    delete[] _formatErr;
     _err = NULL;
     _formatErr = NULL;
 }
-
-
