@@ -1,6 +1,7 @@
 
 /*
  * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -31,29 +32,31 @@
  * SOFTWARE.
  */
 
-
 #include <iostream>
 #include <cmdparser/cmdparser.h>
+#include "common/tools_filesystem.h"
+namespace Filesystem = mstflint::common::filesystem;
 
-namespace mlxarchive {
-    class Mlxarchive : public CommandLineRequester
-    {
-    public:
-        Mlxarchive();
-        ~Mlxarchive();
-        ParseStatus HandleOption(string name, string value);
-        int run(int agc, char **argv);
+namespace mlxarchive
+{
+class Mlxarchive : public CommandLineRequester
+{
+public:
+    Mlxarchive();
+    ~Mlxarchive();
+    ParseStatus HandleOption(string name, string value);
+    int run(int agc, char** argv);
 
-    private:
-        void initCmdParser();
-        void printHelp();
-        void paramValidate();
-        CommandLineParser _cmdParser;
-        std::string _binsDir;
-        std::string _outFile;
-        std::string _date;
-        std::string _version;
-        std::string _mfa2file;
-        bool _printMiniDump;
-    };
-}
+private:
+    void initCmdParser();
+    void printHelp();
+    void paramValidate();
+    CommandLineParser _cmdParser;
+    std::string _binsDir;
+    std::string _outFile;
+    std::string _date;
+    std::string _version;
+    std::string _mfa2file;
+    bool _printMiniDump;
+};
+} // namespace mlxarchive
