@@ -135,17 +135,20 @@ public:
     std::shared_ptr<Param> findParamByName(std::string n);
     void CheckModuleAndPortMatchClass(int32_t module, u_int32_t port, std::string mlxconfigName);
     void getExprVarsValues(std::vector<std::string>&,
-                           std::vector<TLVConf*>,
+                           std::vector<std::shared_ptr<TLVConf>>,
                            std::map<std::string, u_int32_t>&,
                            std::string);
-    void evalTempVars(std::shared_ptr<Param>, std::vector<TLVConf*>, std::map<std::string, u_int32_t>&);
-    u_int32_t evalRule(std::shared_ptr<Param>, std::string, std::vector<TLVConf*>&, std::map<std::string, u_int32_t>&);
-    void checkRules(std::vector<TLVConf*> ruleTLVs);
+    void evalTempVars(std::shared_ptr<Param>, std::vector<std::shared_ptr<TLVConf>>, std::map<std::string, u_int32_t>&);
+    u_int32_t evalRule(std::shared_ptr<Param>,
+                       std::string,
+                       std::vector<std::shared_ptr<TLVConf>>&,
+                       std::map<std::string, u_int32_t>&);
+    void checkRules(std::vector<std::shared_ptr<TLVConf>>);
     void setOnDevice(mfile* mf);
     void getRuleTLVs(std::set<std::string>& result);
     void parseParamValue(std::string, std::string, u_int32_t&, std::string&, u_int32_t index);
     void unpack(u_int8_t* buff);
-    void genXMLTemplate(string& xmlTemplate, bool allAttrs, bool withVal, bool defaultAttrVal);
+    void genXMLTemplate(string& xmlTemplate, bool allAttrs, bool withVal, bool defaultAttrVal, bool confFormat = false);
     void genRaw(string& raw);
     void genBin(vector<u_int32_t>& buff, bool withHeader = true);
     bool isAStringParam(string paramName);
@@ -156,6 +159,7 @@ public:
     void setAttr(string attr, string val);
     void invalidate(mfile* mf);
     static void unpackTLVType(TLVClass tlvClass, tools_open_tlv_type& type, u_int32_t& id);
+    bool areParamsEqual(const TLVConf& rhsTLV);
 };
 
 int PriorityStrToNum(string priority);
