@@ -530,7 +530,7 @@ void MlxCfg::printConfHeader(bool showDefualt, bool showNew, bool showCurrent)
 
 void prepareSetInput(vector<QueryOutputItem>& output, vector<ParamView>& params)
 {
-    VECTOR_ITERATOR(ParamView, params, p)
+    for (std::vector<ParamView>::iterator p = params.begin(); p != params.end(); ++p)
     {
         QueryOutputItem o;
         o.mlxconfigName = p->mlxconfigName;
@@ -545,10 +545,10 @@ void prepareSetInput(vector<QueryOutputItem>& output, vector<ParamView>& params)
 
 void prepareQueryOutput(vector<QueryOutputItem>& output, vector<ParamView>& params, QueryType qT)
 {
-    VECTOR_ITERATOR(ParamView, params, p)
+    for (std::vector<ParamView>::iterator p = params.begin(); p != params.end(); ++p)
     {
         bool found = false;
-        VECTOR_ITERATOR(QueryOutputItem, output, o)
+        for (std::vector<QueryOutputItem>::iterator o = output.begin(); o != output.end(); ++o)
         {
             if (p->mlxconfigName == o->mlxconfigName)
             {
@@ -688,9 +688,10 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
     if (_mlxParams.isJsonOutputRequested)
     {
         ifstream jsonInputStream(_mlxParams.NVOutputFile);
-        mstflint::common::ReaderWrapper readerWrapper;
-        Json::Reader* reader = readerWrapper.getReader();
-        bool rc = reader->parse(jsonInputStream, oJsonValue);
+        Json::CharReaderBuilder builder;
+        builder["collectComments"] = true;
+        JSONCPP_STRING errs;
+        bool rc = parseFromStream(builder, jsonInputStream, &oJsonValue, &errs);
         jsonInputStream.close();
         if (!rc)
         {
@@ -1063,7 +1064,7 @@ mlxCfgStatus MlxCfg::devRawCfg(RawTlvMode mode)
             delete commander;
             return err(true, "Failed to open file: %s", _mlxParams.rawTlvFile.c_str());
         }
-        std::vector<std::vector<u_int32_t> > rawTlvsAsDw;
+        std::vector<std::vector<u_int32_t>> rawTlvsAsDw;
         rawTlvsAsDw.resize(0);
         // Check file Sig
         std::string startLine;
@@ -1096,7 +1097,7 @@ mlxCfgStatus MlxCfg::devRawCfg(RawTlvMode mode)
         int tlvIdx = 1;
         if (mode == SET_RAW)
         {
-            for (std::vector<std::vector<u_int32_t> >::iterator it = rawTlvsAsDw.begin(); it != rawTlvsAsDw.end();
+            for (std::vector<std::vector<u_int32_t>>::iterator it = rawTlvsAsDw.begin(); it != rawTlvsAsDw.end();
                  it++, tlvIdx++)
             {
                 commander->dumpRawCfg(*it, dumpStr);
@@ -1118,7 +1119,7 @@ mlxCfgStatus MlxCfg::devRawCfg(RawTlvMode mode)
         tlvIdx = 1;
         // set each of the raw TLVs
         std::vector<u_int32_t> queryData;
-        for (std::vector<std::vector<u_int32_t> >::iterator it = rawTlvsAsDw.begin(); it != rawTlvsAsDw.end();
+        for (std::vector<std::vector<u_int32_t>>::iterator it = rawTlvsAsDw.begin(); it != rawTlvsAsDw.end();
              it++, tlvIdx++)
         {
             if (mode == SET_RAW)
@@ -1705,6 +1706,133 @@ mlxCfgStatus MlxCfg::apply()
     return rc;
 }
 
+mlxCfgStatus MlxCfg::getChallenge()
+{
+    mlxCfgStatus rc = MLX_CFG_OK;
+    Commander* commander = nullptr;
+    try
+    {
+        commander = Commander::create(_mlxParams.device, _mlxParams.dbName, true, _mlxParams.deviceType);
+        MlxCfgToken token(commander->mf());
+
+        token.GetAndPrintChallenge(_mlxParams.tokenChallengeID, false);
+    }
+    catch (MlxcfgException& e)
+    {
+        cerr << "-E- " << e._err.c_str() << endl;
+        rc = MLX_CFG_ERROR;
+    }
+    if (commander)
+    {
+        delete commander;
+    }
+    return rc;
+}
+
+mlxCfgStatus MlxCfg::remoteTokenKeepAlive()
+{
+    mlxCfgStatus rc = MLX_CFG_OK;
+    Commander* commander = nullptr;
+    try
+    {
+        commander = Commander::create(_mlxParams.device, _mlxParams.dbName);
+
+        if (dm_is_ib_access(commander->mf()) == 0) // not IB device
+        {
+            throw MlxcfgException("specified device is not an IB device");
+        }
+
+        MlxCfgToken token(commander->mf());
+        token.RemoteTokenKeepAlive(_mlxParams.sessionId,
+                                   _mlxParams.sessionTimeInSec,
+                                   _mlxParams.isSleepTimeBetweenCommandsInput,
+                                   _mlxParams.keepAliveSleepTimeBetweenCommands,
+                                   _mlxParams.isSleepTimeOnCommandTOInput,
+                                   _mlxParams.keepAliveSleepTimeOnCommandTO);
+
+        printf("Keep alive session has ended successfully.\n");
+    }
+    catch (MlxcfgException& e)
+    {
+        cerr << "-E- " << e._err.c_str() << endl;
+        rc = MLX_CFG_ERROR;
+    }
+    if (commander)
+    {
+        delete commander;
+    }
+
+    return rc;
+}
+
+mlxCfgStatus MlxCfg::queryTokenSupport()
+{
+    mlxCfgStatus rc = MLX_CFG_OK;
+    Commander* commander = nullptr;
+    try
+    {
+        commander = Commander::create(_mlxParams.device, _mlxParams.dbName, false, _mlxParams.deviceType);
+
+        MlxCfgToken token(commander->mf());
+        token.QueryTokenSupport();
+    }
+    catch (MlxcfgException& e)
+    {
+        cerr << "-E- " << e._err.c_str() << endl;
+        rc = MLX_CFG_ERROR;
+    }
+    if (commander)
+    {
+        delete commander;
+    }
+    return rc;
+}
+
+mlxCfgStatus MlxCfg::queryTokenSession()
+{
+    mlxCfgStatus rc = MLX_CFG_OK;
+    Commander* commander = nullptr;
+    try
+    {
+        commander = Commander::create(_mlxParams.device, _mlxParams.dbName, false, _mlxParams.deviceType);
+        MlxCfgToken token(commander->mf());
+        token.QueryTokenSession(_mlxParams.tokenStatusID);
+    }
+    catch (MlxcfgException& e)
+    {
+        cerr << "-E- " << e._err.c_str() << endl;
+        rc = MLX_CFG_ERROR;
+    }
+    if (commander)
+    {
+        delete commander;
+    }
+    return rc;
+}
+
+mlxCfgStatus MlxCfg::endTokenSession()
+{
+    mlxCfgStatus rc = MLX_CFG_OK;
+    Commander* commander = nullptr;
+    try
+    {
+        commander = Commander::create(_mlxParams.device, _mlxParams.dbName, false, _mlxParams.deviceType);
+        MlxCfgToken token(commander->mf());
+        token.EndTokenSession(_mlxParams.tokenStatusID);
+    }
+    catch (MlxcfgException& e)
+    {
+        cerr << "-E- " << e._err.c_str() << endl;
+        rc = MLX_CFG_ERROR;
+    }
+    if (commander)
+    {
+        delete commander;
+    }
+
+    return rc;
+}
+
 mlxCfgStatus MlxCfg::execute(int argc, char* argv[])
 {
     mlxCfgStatus rc = parseArgs(argc, argv);
@@ -1781,7 +1909,21 @@ mlxCfgStatus MlxCfg::execute(int argc, char* argv[])
         case Mc_Apply:
             ret = apply();
             break;
-
+        case Mc_RemoteTokenKeepAlive:
+            ret = remoteTokenKeepAlive();
+            break;
+        case Mc_ChallengeRequest:
+            ret = getChallenge();
+            break;
+        case Mc_TokenSupported:
+            ret = queryTokenSupport();
+            break;
+        case Mc_QueryTokenSession:
+            ret = queryTokenSession();
+            break;
+        case Mc_EndTokenSession:
+            ret = endTokenSession();
+            break;
         default:
             // should not reach here.
             return err(true, "invalid command.");
