@@ -40,11 +40,11 @@ FsSyncEOperations::FsSyncEOperations(FImage* imageAccess) : FsCompsOperations(im
 }
 
 bool FsSyncEOperations::FwQuery(fw_info_t* fwInfo,
-                                bool readRom,
-                                bool isStripedImage,
-                                bool quickQuery,
-                                bool ignoreDToc,
-                                bool verbose)
+                                bool __attribute__ ((unused)) readRom,
+                                bool __attribute__ ((unused)) isStripedImage,
+                                bool __attribute__ ((unused)) quickQuery,
+                                bool __attribute__ ((unused)) ignoreDToc,
+                                bool __attribute__ ((unused)) verbose)
 {
     u_int8_t data[sizeof(_header)] = {0};
 
@@ -192,4 +192,4 @@ string FsSyncEOperations::ToString(ClockSyncVendorHWID hwID)
         default:
             return "Unknown";
     }
-}
\ No newline at end of file
+}
