@@ -389,8 +389,8 @@ typedef enum fs3_section
     FS4_PXIR_INI1 = 0xab,
     FS4_NVDA_ROT_CERTIFICATES = 0xad,
     FS4_EXCLKSYNC_INFO = 0xb0,
-    FS4_MAIN_HASHES_PAGES = 0xb1,
-    FS4_MAIN_LOCKED_HASHES_PAGES = 0xb2,
+    FS4_MAIN_PAGES_HASHES = 0xb1,
+    FS4_MAIN_PAGES_LOCKED_HASHES = 0xb2,
     FS4_STRN_MAIN = 0xb4,
     FS4_STRN_IRON = 0xb5,
     FS4_STRN_TILE = 0xb6,
@@ -416,6 +416,7 @@ typedef enum fs3_section
     FS4_LC_INI_NV_DATA = 0xf1,
     FS4_CERT_CHAIN_0 = 0xf2,
     FS5_SECURITY_LOG = 0xd5,
+    FS5_CPO_CALIBRATION_DATA = 0xfc,
     FS4_DIGITAL_CACERT_RW = 0xf3,
     FS4_CERTIFICATE_CHAINS_1 = 0xf4,
     FS4_CERTIFICATE_CHAINS_2 = 0xf5,
@@ -482,11 +483,11 @@ struct GPH
 
 #define MAX_SECTION_SIZE 0x400000
 
-#define REBOOT_REQUIRED_STR "To load new FW run reboot machine."
+#define REBOOT_REQUIRED_STR "To load new FW, issue system-level reset."
 #ifndef MST_UL
-#define REBOOT_OR_FWRESET_REQUIRED_STR "To load new FW run mlxfwreset or reboot machine."
+#define REBOOT_OR_FWRESET_REQUIRED_STR "To load new FW, issue system-level reset or use mlxfwreset where applicable."
 #else
-#define REBOOT_OR_FWRESET_REQUIRED_STR "To load new FW run mstfwreset or reboot machine."
+#define REBOOT_OR_FWRESET_REQUIRED_STR "To load new FW, issue system-level reset or use mstfwreset where applicable."
 #endif
 
 void report(const char* format, ...);
