@@ -41,6 +41,11 @@
 #include <tools_dev_types.h>
 #include "flint_io.h"
 
+using std::to_string;
+#include <stdexcept>
+#include <new>
+#include <iostream>
+
 extern bool _no_erase;
 extern bool _no_burn;
 
@@ -54,6 +59,48 @@ void mft_signal_set_handling(int isOn)
 }
 #endif
 
+////////////////////////////////////////////////////////////////////////
+//
+// FPldm Class Implementation
+//
+////////////////////////////////////////////////////////////////////////
+bool FPldm::open(const char* fname, bool read_only, bool advErr)
+{
+    int fsize;
+    FILE* fh;
+
+    (void)read_only; // FImage can be opened only for read so we ignore compiler warnings
+    _advErrors = advErr;
+
+    fh = fopen(fname, "rb");
+
+    if (!fh)
+    {
+        return errmsg("Can not open file \"%s\" - %s", fname, strerror(errno));
+    }
+
+    // Get the file size:
+    if (fseek(fh, 0, SEEK_END) < 0)
+    {
+        fclose(fh);
+        return errmsg("Can not get file size for \"%s\" - %s", fname, strerror(errno));
+    }
+
+    fsize = ftell(fh);
+    if (fsize < 0)
+    {
+        fclose(fh);
+        return errmsg("Can not get file size for \"%s\" - %s", fname, strerror(errno));
+    }
+    rewind(fh);
+
+    _fname = fname;
+    _len = fsize;
+    _isFile = true;
+    fclose(fh);
+    return true;
+} // FImage::open
+
 ////////////////////////////////////////////////////////////////////////
 //
 // FImage Class Implementation
@@ -916,14 +963,26 @@ bool Flash::get_attr(ext_flash_attr_t& attr)
     attr.sector_size = _attr.sector_size;
     attr.block_write = _attr.block_write;
     attr.command_set = _attr.command_set;
+    attr.cmp_support = _attr.cmp_support;
     attr.quad_en_support = _attr.quad_en_support;
+    attr.srwd_support = _attr.srwd_support;
     attr.driver_strength_support = _attr.driver_strength_support;
     attr.dummy_cycles_support = _attr.dummy_cycles_support;
+    // CMP query
+    if (_attr.cmp_support)
+    {
+        attr.mf_get_cmp_rc = (MfError)mf_get_cmp(_mfl, &attr.cmp);
+    }
     // Quad EN query
     if (_attr.quad_en_support)
     {
         attr.mf_get_quad_en_rc = (MfError)mf_get_quad_en(_mfl, &attr.quad_en);
     }
+    // SRWD query
+    if (_attr.srwd_support)
+    {
+        attr.mf_get_srwd_rc = (MfError)mf_get_srwd(_mfl, &attr.srwd);
+    }
     // Drive-strength query
     if (_attr.driver_strength_support)
     {
@@ -974,7 +1033,308 @@ const char* Flash::getFlashType()
         }                                                                                         \
     }
 
-bool Flash::set_attr(char* param_name, char* param_val_str)
+bool Flash::check_and_set_tbs_field(std::string& param_val_str,
+    std::size_t tbs_end_loc,
+    std::string& tbs,
+    std::string& err_msg,
+    const ext_flash_attr_t& attr,
+    u_int8_t bank_num)
+{
+    bool rc = true;
+    tbs = param_val_str.substr(0, tbs_end_loc);
+    if (tbs.compare(WP_BOTTOM_STR) && tbs.compare(WP_TOP_STR))
+    {
+        rc = false;
+    }
+
+    if (rc)
+    {
+        int ret_val = attr.mf_get_write_protect_rc_array[bank_num];
+        write_protect_info_t existing_protect_info = attr.protect_info_array[bank_num];
+        if (ret_val == MFE_OK)
+        {
+            if ((_attr.vendor == FV_MX25K16XXX || _attr.vendor == FV_IS25LPXXX) && existing_protect_info.is_bottom &&
+                !tbs.compare(WP_TOP_STR))
+            {
+                err_msg = "The data you are trying to write is OTP and have already been programmed.";
+                rc = false;
+            }
+        }
+        else // mf_get_write_protect_rc_array failed
+        {
+            if (ret_val != MFE_NOT_SUPPORTED_OPERATION)
+            {
+                // We ignore the read when operation is not supported!
+                err_msg = "Failed to get write_protected info: %s (%s)", errno == 0 ? "" : strerror(errno),
+                mf_err2str(ret_val);
+                rc = false;
+            }
+        }
+    }   
+
+    return rc;
+}
+
+bool Flash::check_and_set_sector_field(std::string& param_val_str,
+    std::size_t sector_or_subsector_start_loc,
+    std::string& sector_or_subsector,
+    std::string& err_msg)
+{
+    bool rc = true;
+    try
+    {
+        sector_or_subsector = param_val_str.substr(sector_or_subsector_start_loc + 1);
+    }
+    catch (const std::out_of_range& e)
+    {
+        rc = false;
+    }
+    catch (std::bad_alloc& ba)
+    {
+        err_msg = "bad_alloc caught: " + std::string(ba.what()) + '\n';
+        rc = false;
+    }
+    catch (const std::exception& e)
+    {
+        err_msg = "An error while verifying input: " + std::string(e.what()) + '\n';
+        rc = false;
+    }
+
+    if (rc && sector_or_subsector.compare(WP_SEC_STR) && sector_or_subsector.compare(WP_SUBSEC_STR))
+    {
+        rc = false;
+    }
+
+    return rc;
+}
+
+bool Flash::check_and_set_sector_num_field(std::string& param_val_str,
+    std::string& sector_num,
+    std::string& err_msg,
+    std::size_t start,
+    std::size_t end)
+{
+    bool rc = true;
+    try
+    {
+        sector_num = param_val_str.substr(start, end);
+    }
+    catch (const std::out_of_range& e)
+    {
+        rc = false;
+    }
+    catch (std::bad_alloc& ba)
+    {
+        err_msg = "bad_alloc caught: " + std::string(ba.what()) + '\n';
+        rc = false;
+    }
+    catch (const std::exception& e)
+    {
+        err_msg = "An error while verifying input: " + std::string(e.what()) + '\n';
+        rc = false;
+    }
+
+    if (rc)
+    {
+        char* endp;
+        u_int8_t sector_num_as_int = strtoul(sector_num.c_str(), &endp, 0); // convert given sectors number to integer
+        if (*endp != '\0')
+        {
+            err_msg = "bad argument (" + sector_num + "), only integer value is allowed.\n";
+            rc = false;
+        }
+        else if (!sector_num_as_int)
+        {
+            err_msg = "Invalid sectors number, Use \"Disabled\" instead.\n";
+            rc = false;
+        }
+    }
+
+    return rc;
+}
+
+bool Flash::get_data_for_protect_info(const ext_flash_attr_t& attr,
+    u_int8_t bank_num,
+    char* param_val,
+    std::string& tbs,
+    std::string& sector_num,
+    std::string& sector_or_subsector)
+{
+    bool valid = true;
+    std::string param_val_str(param_val);
+    std::size_t tbs_end_loc = param_val_str.find(",");
+    std::size_t sector_or_subsector_start_loc = param_val_str.find("-");
+
+    // checking for <tbs>,<sectorNum>-<Sector>
+    if (tbs_end_loc != std::string::npos && sector_or_subsector_start_loc != std::string::npos)
+    {
+        tbs = param_val_str.substr(0, tbs_end_loc);
+        sector_or_subsector = param_val_str.substr(sector_or_subsector_start_loc + 1);
+        sector_num = param_val_str.substr(tbs_end_loc + 1, sector_or_subsector_start_loc - tbs_end_loc - 1);
+    }
+
+    // checking for <tbs>
+    else if (tbs_end_loc == std::string::npos && sector_or_subsector_start_loc == std::string::npos)
+    {
+        tbs = param_val_str;
+    }
+
+    // checking for <secNum>-<Sectors or Subesctors>
+    else if (tbs_end_loc == std::string::npos && sector_or_subsector_start_loc != std::string::npos)
+    {
+        sector_or_subsector = param_val_str.substr(sector_or_subsector_start_loc + 1);
+        sector_num = param_val_str.substr(0, sector_or_subsector_start_loc);
+    }
+
+    if (tbs.empty() || sector_or_subsector.empty() || sector_num.empty())
+    {
+        int ret_val = attr.mf_get_write_protect_rc_array[bank_num];
+        write_protect_info_t existing_protect_info = attr.protect_info_array[bank_num];
+        if (ret_val == MFE_OK)
+        {
+            if (tbs.empty())
+            {
+                tbs = (existing_protect_info.is_bottom ? WP_BOTTOM_STR : WP_TOP_STR);
+            }
+            if (sector_or_subsector.empty())
+            {
+                sector_or_subsector = (existing_protect_info.is_subsector ? WP_SUBSEC_STR : WP_SEC_STR);
+            }
+            if (sector_num.empty())
+            {
+                sector_num = std::to_string(existing_protect_info.sectors_num);
+            }
+        }
+        else // mf_get_write_protect_rc_array failed
+        {
+            if (ret_val != MFE_NOT_SUPPORTED_OPERATION)
+            {
+                // We ignore the read when operation is not supported!
+                printf("Failed to get write_protected info: %s (%s)", errno == 0 ? "" : strerror(errno),
+                mf_err2str(ret_val));
+                valid = false;
+            }
+        }
+    }
+
+    return valid;
+}
+
+bool Flash::set_data_in_protect_info(std::string& tbs,
+    std::string& sector_num,
+    std::string& sector_or_subsector,
+    const ext_flash_attr_t& attr,
+    u_int8_t bank_num,
+    write_protect_info_t* protect_info)
+{
+    bool rc = true;
+    GET_IN_PARAM(tbs.c_str(), (*protect_info).is_bottom, WP_BOTTOM_STR, WP_TOP_STR);
+    GET_IN_PARAM(sector_or_subsector.c_str(), (*protect_info).is_subsector, WP_SUBSEC_STR, WP_SEC_STR);
+    char* endp;
+    (*protect_info).sectors_num = strtoul(sector_num.c_str(), &endp, 0); // convert given sectors number to integer
+
+    return rc;
+}
+
+bool Flash::validate_write_protect_args(char* param_val, const ext_flash_attr_t& attr, u_int8_t bank_num)
+{
+    bool valid = false;
+    std::string err_msg("bad argument of hw set command for " WRITE_PROTECT
+                        ". It should be in one of the formats: " WRITE_PROTECT
+                        "=<tb>,<sectors_num>-<Sectors or SubSectors> , " WRITE_PROTECT "=<tb> , " WRITE_PROTECT
+                        "=<sectors_num>-<Sectors or SubSectors>\n");
+    std::string param_val_str(param_val);
+    std::size_t tbs_end_loc = param_val_str.find(",");
+    std::size_t sector_or_subsector_start_loc = param_val_str.find("-");
+
+    std::string tbs("");
+    std::string sector_num("");
+    std::string sector_or_subsector("");
+
+    // checking for <tbs>,<sectorNum>-<Sector>
+    if (tbs_end_loc != std::string::npos && sector_or_subsector_start_loc != std::string::npos)
+    {
+        if (!check_and_set_tbs_field(param_val_str, tbs_end_loc, tbs, err_msg, attr, bank_num))
+        {
+            goto end;
+        }
+
+        if (!check_and_set_sector_field(param_val_str, sector_or_subsector_start_loc, sector_or_subsector, err_msg))
+        {
+            goto end;
+        }
+
+        if (!check_and_set_sector_num_field(param_val_str, sector_num, err_msg, tbs_end_loc + 1,
+                                            sector_or_subsector_start_loc - tbs_end_loc - 1))
+        {
+            goto end;
+        }
+    }
+
+    // checking for <tbs>
+    else if (tbs_end_loc == std::string::npos && sector_or_subsector_start_loc == std::string::npos)
+    {
+        if (!check_and_set_tbs_field(param_val_str, param_val_str.length(), tbs, err_msg, attr, bank_num))
+        {
+            goto end;
+        }
+    }
+
+    // checking for <secNum>-<Sectors or Subesctors>
+    else if (tbs_end_loc == std::string::npos && sector_or_subsector_start_loc != std::string::npos)
+    {
+        if (!check_and_set_sector_field(param_val_str, sector_or_subsector_start_loc, sector_or_subsector, err_msg))
+        {
+            goto end;
+        }
+
+        if (!check_and_set_sector_num_field(param_val_str, sector_num, err_msg, 0, sector_or_subsector_start_loc))
+        {
+            goto end;
+        }
+    }
+
+    valid = true;
+end:
+    if (!valid)
+    {
+        errmsg("%s", err_msg.c_str());
+    }
+    return valid;
+}
+
+bool Flash::handle_protect_info_set_for_write_protect(char* param_val_str,
+    const ext_flash_attr_t& attr,
+    write_protect_info_t* protect_info,
+    u_int8_t bank_num)
+{
+    bool rc = true;
+    if (!validate_write_protect_args(param_val_str, attr, bank_num))
+    {
+        rc = false;
+    }
+    else
+    {
+        std::string tbs("");
+        std::string sector_num("");
+        std::string sector_or_subsector("");
+        if (!get_data_for_protect_info(attr, bank_num, param_val_str, tbs, sector_num, sector_or_subsector))
+        {
+            rc = false;
+        }
+        else
+        {
+            if (!set_data_in_protect_info(tbs, sector_num, sector_or_subsector, attr, bank_num, protect_info))
+            {
+                rc = false;
+            }
+        }
+    }
+
+    return rc;
+}
+
+bool Flash::set_attr(char* param_name, char* param_val_str, const ext_flash_attr_t& attr)
 {
     int rc;
     // TODO: make generic function that sets params
@@ -993,16 +1353,37 @@ bool Flash::set_attr(char* param_name, char* param_val_str)
             return errmsg("Setting " QUAD_EN_PARAM " failed: (%s)", mf_err2str(rc));
         }
     }
+    else if (!strcmp(param_name, SRWD_PARAM))
+    {
+        char* endp;
+        u_int8_t srwd_val;
+        srwd_val = strtoul(param_val_str, &endp, 0);
+        if (*endp != '\0' || srwd_val > 1)
+        {
+            return errmsg("Bad " SRWD_PARAM " value (%s), it can be 0 or 1\n", param_val_str);
+        }
+        rc = mf_set_srwd(_mfl, srwd_val);
+        if (rc != MFE_OK)
+        {
+            return errmsg("Setting " SRWD_PARAM " failed: (%s)", mf_err2str(rc));
+        }
+    }
     else if (!strcmp(param_name, DUMMY_CYCLES_PARAM))
     {
         char* endp;
         u_int8_t dummy_cycles_val;
+        u_int8_t lower_bound =
+          is_macronix_special_case_for_dummy_cycles(_mfl) ? MIN_NUM_OF_CYCLES_FOR_MX25UXXX : MIN_NUM_OF_CYCLES;
+        u_int8_t upper_bound =
+          is_macronix_special_case_for_dummy_cycles(_mfl) ? MAX_NUM_OF_CYCLES_FOR_MX25UXXX : MAX_NUM_OF_CYCLES;
         dummy_cycles_val = strtoul(param_val_str, &endp, 0);
-        if (*endp != '\0' || dummy_cycles_val < 1 || dummy_cycles_val > 15)
+        if (*endp != '\0' || dummy_cycles_val < lower_bound || dummy_cycles_val > upper_bound)
         {
-            // value is actually [0.15] but val=0 and val=15 indicate default state (thus they are the same so no need
-            // for both values to be accepted)
-            return errmsg("Bad " DUMMY_CYCLES_PARAM " value (%s), it can be [1..15]\n", param_val_str);
+            // value is actually [0.15] but in most flashes val=0 and val=15 indicate default state (thus they are the
+            // same so no need for both values to be accepted) that is unless for macronix special case - there every
+            // configuration is different
+            return errmsg("Bad " DUMMY_CYCLES_PARAM " value (%s), it can be [%d..%d]\n", param_val_str, lower_bound,
+                          upper_bound);
         }
         rc = mf_set_dummy_cycles(_mfl, dummy_cycles_val);
         if (rc != MFE_OK)
@@ -1025,32 +1406,15 @@ bool Flash::set_attr(char* param_name, char* param_val_str)
         if (!strcmp(param_str, WRITE_PROTECT))
         {
             write_protect_info_t protect_info;
-            char *tb, *num_str, *sec;
             if (!strcmp(param_val_str, WP_DISABLED_STR))
             {
                 memset(&protect_info, 0, sizeof(protect_info));
             }
             else
             {
-                tb = strtok(param_val_str, ",");
-                num_str = strtok((char*)NULL, "-");
-                sec = strtok((char*)NULL, "");
-                if (tb == NULL || num_str == NULL || sec == NULL)
+                if (!handle_protect_info_set_for_write_protect(param_val_str, attr, &protect_info, bank_num))
                 {
-                    return errmsg("missing parameters for setting the " WRITE_PROTECT
-                                  " attribute, see help for more info.");
-                }
-                GET_IN_PARAM(tb, protect_info.is_bottom, WP_BOTTOM_STR, WP_TOP_STR);
-                GET_IN_PARAM(sec, protect_info.is_subsector, WP_SUBSEC_STR, WP_SEC_STR);
-
-                protect_info.sectors_num = strtoul(num_str, &endp, 0);
-                if (*endp != '\0')
-                {
-                    return errmsg("bad argument (%s), only integer value is allowed.", num_str);
-                }
-                if (!protect_info.sectors_num)
-                {
-                    return errmsg("Invalid sectors number, Use \"Disabled\" instead.");
+                    return false;
                 }
             }
             rc = mf_set_write_protect(_mfl, bank_num, &protect_info);
@@ -1089,10 +1453,25 @@ bool Flash::set_attr(char* param_name, char* param_val_str)
         }
         else if (_attr.vendor == FV_MX25K16XXX)
         {
-            if (*endp != '\0' || (driver_strength_val != 41 && driver_strength_val != 70 && driver_strength_val != 83 &&
-                                  driver_strength_val != 100))
+            if (_attr.type == FMT_SST_25 && (((1 << FD_256) & (1 << _attr.log2_bank_size)) != 0))
             {
-                return errmsg("Bad " DRIVER_STRENGTH_PARAM " value (%s), it can be [41,70,83,100]\n", param_val_str);
+                if (*endp != '\0' ||
+                    (driver_strength_val != 24 && driver_strength_val != 26 && driver_strength_val != 30 &&
+                     driver_strength_val != 34 && driver_strength_val != 41 && driver_strength_val != 52 &&
+                     driver_strength_val != 76 && driver_strength_val != 146))
+                {
+                    return errmsg("Bad " DRIVER_STRENGTH_PARAM " value (%s), it can be [24,26,30,34,41,52,76,146]\n",
+                                  param_val_str);
+                }
+            }
+            else
+            {
+                if (*endp != '\0' || (driver_strength_val != 41 && driver_strength_val != 70 &&
+                                      driver_strength_val != 83 && driver_strength_val != 100))
+                {
+                    return errmsg("Bad " DRIVER_STRENGTH_PARAM " value (%s), it can be [41,70,83,100]\n",
+                                  param_val_str);
+                }
             }
         }
         else
