@@ -65,7 +65,8 @@
     (chip_type == CT_CONNECT_IB || chip_type == CT_CONNECTX4 || chip_type == CT_CONNECTX4_LX || \
      chip_type == CT_CONNECTX5 || chip_type == CT_CONNECTX6 || chip_type == CT_CONNECTX6DX ||   \
      chip_type == CT_CONNECTX6LX || chip_type == CT_CONNECTX7 || chip_type == CT_CONNECTX8 ||   \
-     chip_type == CT_BLUEFIELD || chip_type == CT_BLUEFIELD2 || chip_type == CT_BLUEFIELD3 ||   \
+     chip_type == CT_CONNECTX8_PURE_PCIE_SWITCH || chip_type == CT_BLUEFIELD ||                 \
+     chip_type == CT_BLUEFIELD2 || chip_type == CT_BLUEFIELD3 ||                               \
      chip_type == CT_BLUEFIELD4)
 
 #define FAIL_NO_OCR(str)                                                                        \
@@ -159,6 +160,7 @@ public:
                           PrintCallBack printFunc = (PrintCallBack)NULL);
     virtual bool FwSetVPD(char* vpdFileStr, PrintCallBack callBackFunc = (PrintCallBack)NULL);
     virtual bool FwSetAccessKey(hw_key_t userKey, ProgressCallBack progressFunc = (ProgressCallBack)NULL);
+    virtual bool GetSecureHostState(u_int8_t& state);
     virtual bool FwResetNvData();
     virtual bool FwShiftDevData(PrintCallBack progressFunc = (PrintCallBack)NULL);
     virtual const char* FwGetResetRecommandationStr();
