@@ -65,6 +65,7 @@ protected:
     bool GetDtocAddress(u_int32_t& dTocAddress) override;
     bool GetMfgInfo(u_int8_t* buff) override;
     bool CheckAndDealWithChunkSizes(u_int32_t cntxLog2ChunkSize, u_int32_t imageCntxLog2ChunkSize) override;
+    bool IsExtracted();
     u_int32_t _ncore_bch_ptr;
 
 private:
@@ -79,6 +80,7 @@ private:
                      bool verbose = false) override;
     bool IsSecureFwUpdateSigned(bool& isSigned);
     bool NCoreQuery(fw_info_t* fwInfo);
+    bool GetNcoreData(vector<u_int8_t>& imgBuff) override;
     bool GetHashesTableSize(u_int32_t& size) override;
 
     static const u_int32_t BCH_SIZE_IN_BYTES;               
