@@ -39,6 +39,7 @@
 
 #include <tools_utils.h>
 #include <bit_slice.h>
+#include "reg_access/mcam_capabilities.h"
 
 #include <vector>
 
@@ -244,6 +245,7 @@ bool FsCtrlOperations::FsIntQuery()
     _fsCtrlImgInfo.ini_file_version = fwQuery.ini_file_version;
     _fsCtrlImgInfo.geo_address = fwQuery.geo_address;
     _fsCtrlImgInfo.geo_address_valid = fwQuery.geo_address_valid;
+    _fsCtrlImgInfo.independent_module = fwQuery.independent_module;
     std::vector<FwComponent> compsMap;
     if (!_fwCompsAccess->getFwComponents(compsMap, false))
     {
@@ -339,12 +341,12 @@ bool FsCtrlOperations::FsIntQuery()
 
     strncpy(_fsCtrlImgInfo.name, fwQuery.name, NAME_LEN);
     strncpy(_fsCtrlImgInfo.description, fwQuery.description, DESCRIPTION_LEN);
-    (strncpy(_fsCtrlImgInfo.deviceVsd, fwQuery.deviceVsd, VSD_LEN));
+    (strncpy(_fsCtrlImgInfo.deviceVsd, fwQuery.deviceVsd, sizeof(_fsCtrlImgInfo.deviceVsd)));
     if (FwType() == FIT_FS3)
     {
         memcpy(_fwImgInfo.ext_info.vsd, fwQuery.deviceVsd, VSD_LEN);
     }
-    (strncpy(_fsCtrlImgInfo.image_vsd, fwQuery.imageVsd, VSD_LEN));
+    (strncpy(_fsCtrlImgInfo.image_vsd, fwQuery.imageVsd, sizeof(_fsCtrlImgInfo.image_vsd)));
 
     bool mpir_reg_supported = false;
     rc = isRegisterValidAccordingToMcamReg(mf, REG_ID_MPIR, &mpir_reg_supported);
@@ -392,6 +394,12 @@ bool FsCtrlOperations::FsIntQuery()
         }
     }
 
+    _fsCtrlImgInfo.pci_switch_only_mode_valid = fwQuery.pci_switch_only_mode_valid;
+    if (fwQuery.pci_switch_only_mode_valid)
+    {
+        _fsCtrlImgInfo.pci_switch_only_mode = fwQuery.pci_switch_only_mode;
+    }
+
     return true;
 }
 
@@ -468,7 +476,6 @@ bool FsCtrlOperations::FwQuery(fw_info_t* fwInfo,
                                bool ignoreDToc,
                                bool verbose)
 {
-    (void)isStripedImage;
     (void)readRom;
     (void)quickQuery;
     (void)ignoreDToc;
@@ -477,6 +484,11 @@ bool FsCtrlOperations::FwQuery(fw_info_t* fwInfo,
     memcpy(&(fwInfo->fs3_info), &(_fsCtrlImgInfo), sizeof(fs3_info_t));
     fwInfo->fs3_info.fs3_uids_info.guid_format = IMAGE_LAYOUT_UIDS;
     fwInfo->fw_type = FwType();
+    if (isStripedImage)
+    {
+        SetIsStripedImage(true);
+        ignoreDToc = true;
+    }
 
     if (isMultiAsicSystemComponent())
     {
@@ -675,7 +687,73 @@ bool FsCtrlOperations::_createImageOps(unique_ptr<FwOperations>& imageOps)
     return true;
 }
 
-bool FsCtrlOperations::GetHashesTableSize(u_int32_t hashes_table_addr, u_int32_t& size)
+
+bool FsCtrlOperations::GetNcoreData(vector<u_int8_t>& ncoreData)
+{
+    u_int32_t ncoreBchAddr = 0;
+    if (!GetNcoreBCHAddr(ncoreBchAddr))
+    {
+        return errmsg("%s", err());
+    }
+
+    u_int32_t ncoreSize = 0;
+    if (!GetNcoreSize(ncoreBchAddr, ncoreSize))
+    {
+        return errmsg("%s", err());
+    }
+
+    u_int32_t ncoreAddr = ncoreBchAddr + FS5_IMAGE_LAYOUT_BOOT_COMPONENT_HEADER_SIZE;
+    if (!FwReadBlock(ncoreAddr, ncoreSize, ncoreData))
+    {
+        return errmsg("%s", err());
+    }
+
+    return true;
+}
+
+bool FsCtrlOperations::GetNcoreBCHAddr(u_int32_t& ncoreBchAddr)
+{
+    struct fs5_image_layout_hw_pointers_gilboa cx8_hw_pointers;
+    if (!GetFS5HWPointers(cx8_hw_pointers))
+    {
+        return false;
+    }
+    ncoreBchAddr = cx8_hw_pointers.ncore_bch_pointer.ptr;
+    return true;
+}
+
+bool FsCtrlOperations::GetNcoreSize(u_int32_t ncoreBchAddr, u_int32_t& size)
+{
+    vector<u_int8_t> bch(FS5_IMAGE_LAYOUT_BOOT_COMPONENT_HEADER_SIZE);
+    if (!FwReadBlock(ncoreBchAddr, bch.size(), bch))
+    {
+        return errmsg("Failed to read BCH NCORE from flash");
+    }
+    struct fs5_image_layout_boot_component_header ncoreBCH;
+    memset(&ncoreBCH, 0, sizeof(ncoreBCH));
+
+    TOCPUn(bch.data(), FS5_IMAGE_LAYOUT_BOOT_COMPONENT_HEADER_SIZE / 4);
+    fs5_image_layout_boot_component_header_unpack(&ncoreBCH, bch.data());
+    size = ncoreBCH.stage1_components[0].u32_binary_len;
+    return true;
+}
+
+bool FsCtrlOperations::GetFS5HWPointers(fs5_image_layout_hw_pointers_gilboa& hw_pointers)
+{
+    if (FwType() != FIT_FS5)
+    {
+        return errmsg("Failed. GetFS5HWPointers supported only for FS5 images/devices.");
+    }
+    vector<u_int8_t> buff(FS5_IMAGE_LAYOUT_HW_POINTERS_GILBOA_SIZE);
+    if (!FwReadBlock(FS4_HW_PTR_START, buff.size(), buff))
+    {
+        return errmsg("Failed to read HW pointers from flash");
+    }
+    fs5_image_layout_hw_pointers_gilboa_unpack(&hw_pointers, buff.data());
+    return true;
+}
+
+bool FsCtrlOperations::GetHashesTableSize(u_int32_t, u_int32_t& size)
 {
     u_int32_t htoc_size =
       IMAGE_LAYOUT_HTOC_HEADER_SIZE + MAX_HTOC_ENTRIES_NUM * (IMAGE_LAYOUT_HTOC_ENTRY_SIZE + HTOC_HASH_SIZE);
@@ -819,7 +897,7 @@ bool FsCtrlOperations::FwBurnAdvanced(FwOperations* imageOps, ExtBurnParams& bur
     }
     fw_info_t fw_query;
     memset(&fw_query, 0, sizeof(fw_info_t));
-    if (!imageOps->FwQuery(&fw_query, true))
+    if (!imageOps->FwQuery(&fw_query, true, imageOps->GetIsStripedImage()))
     {
         return errmsg(FwCompsErrToFwOpsErr(_fwCompsAccess->getLastError()), "Failed to query the image\n");
     }
@@ -866,7 +944,7 @@ bool FsCtrlOperations::burnEncryptedImage(FwOperations* imageOps, ExtBurnParams&
 
 bool FsCtrlOperations::isMultiAsicSystemComponent()
 {
-    if (_hwDevId == QUANTUM3_HW_ID || _hwDevId == CX8_HW_ID ||  _hwDevId == CX9_HW_ID)
+    if (_hwDevId == QUANTUM3_HW_ID || _hwDevId == CX8_HW_ID || _hwDevId == CX8_PURE_PCIE_SWITCH_HW_ID || _hwDevId == CX9_HW_ID)
     {
         return true;
     }
@@ -1024,13 +1102,6 @@ bool FsCtrlOperations::FwSetVPD(char* vpdFileStr, PrintCallBack callBackFunc)
     return unsupportedOperation();
 }
 
-bool FsCtrlOperations::FwSetAccessKey(hw_key_t userKey, ProgressCallBack progressFunc)
-{
-    (void)userKey;
-    (void)progressFunc;
-    return unsupportedOperation();
-}
-
 bool FsCtrlOperations::FwGetSection(u_int32_t sectType, std::vector<u_int8_t>& sectInfo, bool stripedImage)
 {
     (void)sectInfo;
@@ -1299,3 +1370,106 @@ bool FsCtrlOperations::QueryComponentData(FwComponent::comps_ids_t comp, u_int32
     }
     return true;
 }
+
+bool FsCtrlOperations::GetSecureHostState(u_int8_t& state)
+{
+    state = _fwCompsAccess->GetSecureHostState();
+    return true;
+}
+
+bool FsCtrlOperations::ChangeSecureHostState(bool disable, u_int64_t key)
+{
+    struct tools_open_mlock mlock;
+    memset(&mlock, 0, sizeof(mlock));
+    mlock.operation = disable;
+    mlock.key = key;
+    int rc = reg_access_secure_host(getMfileObj(), REG_ACCESS_METHOD_SET, &mlock);
+    if (rc)
+    {
+        return errmsg("secure host operation failed. reported error code: %d", rc);
+    }
+    return true;
+}
+
+bool FsCtrlOperations::FwSetAccessKey(hw_key_t userKey, ProgressCallBack)
+{
+    struct tools_open_mlock mlock;
+    memset(&mlock, 0, sizeof(mlock));
+    int rc = (int)reg_access_secure_host(getMfileObj(), REG_ACCESS_METHOD_GET, &mlock);
+    if (rc)
+    {
+        return errmsg("secure host operation failed. reported error code: %d", rc);
+    }
+    if (mlock.operation)
+    {
+        printf("-I- HW access already disabled\n");
+        return true;
+    }
+
+    u_int64_t key = ((u_int64_t)userKey.h << 32) | userKey.l;
+    memset(&mlock, 0, sizeof(mlock));
+    mlock.operation = 1;
+    mlock.key = key;
+    rc = reg_access_secure_host(getMfileObj(), REG_ACCESS_METHOD_SET, &mlock);
+    if (rc)
+    {
+        return errmsg("secure host operation failed. reported error code: %d", rc);
+    }
+    printf("-I- Secure Host was enabled successfully on the device.\n");
+    return true;
+}
+
+bool FsCtrlOperations::IsComponentSupported(FwComponent::comps_ids_t component)
+{
+    return _fwCompsAccess->IsDevicePresent(component);
+}
+
+
+bool FsCtrlOperations::getBFBComponentsVersions(std::map<std::string, std::string>& name_to_version, bool pending)
+{
+    DPRINTF(("Getting BFB components versions (pending=%d)...\n", pending));
+
+    const std::map<u_int32_t, std::string> MISOC_TYPE_TO_NAME = {
+      {0x0, "BF3_ATF"},
+      {0x1, "BF3_UEFI"},
+      {0x2, "BF3_BMC_FW"},
+      {0x3, "BF3_CEC_FW"},
+    };
+
+    std::string version;
+    fw_info_t fwQuery;
+    memset(&fwQuery, 0, sizeof(fwQuery));
+
+    // Get versions of all components available in MISOC
+    for (const auto& pair : MISOC_TYPE_TO_NAME)
+    {
+        version.clear(); // Clear any previous version
+        DPRINTF(("Querying MISOC type 0x%x (%s)...\n", pair.first, pair.second.c_str()));
+        if (!_fwCompsAccess->queryMISOC(version, pair.first, pending))
+        {
+            DPRINTF(("Failed to query MISOC type 0x%x\n", pair.first));
+            name_to_version[pair.second] = "Info not available";
+        }
+        else
+        {
+            DPRINTF(("Got version: %s\n", version.c_str()));
+            name_to_version[pair.second] = version;
+        }
+    }
+
+    // Get NIC FW version from MGIR
+    DPRINTF(("Querying NIC firmware version...\n"));
+    if (pending)
+    {
+        FwVersion pending_fw_version = FwOperations::createFwVersion(&_fwImgInfo.ext_info);
+        name_to_version["BF3_NIC_FW"] = pending_fw_version.get_fw_version();
+    }
+    else
+    {
+        FwVersion running_fw_version = FwOperations::createRunningFwVersion(&_fwImgInfo.ext_info);
+        name_to_version["BF3_NIC_FW"] = running_fw_version.get_fw_version();
+    }
+    DPRINTF(("Got NIC FW version: %s\n", name_to_version["BF3_NIC_FW"].c_str()));
+
+    return true;
+}
\ No newline at end of file
