@@ -80,7 +80,8 @@
 #define CX6LX_HW_ID 534
 #define CX7_HW_ID 536
 #define CX8_HW_ID 542
-#define CX9_HW_ID 549
+#define CX8_PURE_PCIE_SWITCH_HW_ID 546
+#define CX9_HW_ID 548
 #define BF_HW_ID 529
 #define BF2_HW_ID 532
 #define BF3_HW_ID 540
@@ -314,6 +315,7 @@ typedef enum chip_type
     CT_CONNECTX6LX,
     CT_CONNECTX7,
     CT_CONNECTX8,
+    CT_CONNECTX8_PURE_PCIE_SWITCH,
     CT_CONNECTX9,
     CT_SPECTRUM3,
     CT_BLUEFIELD2,
@@ -497,7 +499,11 @@ typedef struct fs3_info_ext
     bool socket_direct;
     bool aux_card_connected;
     bool is_aux_card_connected_valid;
-
+    
+    uint8_t independent_module;
+    
+    uint8_t pci_switch_only_mode;
+    uint8_t pci_switch_only_mode_valid;
 } fs3_info_t;
 
 // typedef struct fs3_info_ext fs4_info_t;
@@ -607,7 +613,8 @@ typedef enum fw_img_type
     FIT_FS4 = 3,
     FIT_FSCTRL = 4,
     FIT_FS5 = 5,
-    FIT_COMPS = 6
+    FIT_COMPS = 6,
+    FIT_PLDM_1_0 = 7
 } fw_img_type_t;
 
 enum ExpRomProto
