@@ -69,6 +69,22 @@ public:
         {
             return new ConnectX7FwOperationsSignatureManager();
         }
+        else if (deviceId == DeviceConnectX8)
+        {
+            return new ConnectX8FwOperationsSignatureManager();
+        }
+        else if (deviceId == DeviceConnectX9)
+        {
+            return new ConnectX9FwOperationsSignatureManager();
+        }
+        else if (deviceId == DeviceConnectX8PurePcieSwitch)
+        {
+            return new ConnectX8PurePCIESwitchFwOperationsSignatureManager();
+        }
+        else if (deviceId == DeviceConnectX8PurePcieSwitch)
+        {
+            return new ConnectX8PurePCIESwitchFwOperationsSignatureManager();
+        }
         else if (deviceId == DeviceBlueField2)
         {
             return new Bluefield2FwOperationsSignatureManager();
@@ -115,6 +131,10 @@ public:
         {
             return new ConnectX7FwOperationsSignatureManager();
         }
+        else if (chip == CT_CONNECTX8)
+        {
+            return new ConnectX8FwOperationsSignatureManager();
+        }
         else if (chip == CT_BLUEFIELD2)
         {
             return new Bluefield2FwOperationsSignatureManager();
