@@ -210,6 +210,12 @@ using namespace mft_utils;
 #define NO_FW_CTRL_L "no_fw_ctrl"
 #define NO_FW_CTRL_S ' '
 
+#define COMP_TYPE_L "component_type"
+#define COMP_TYPE_S ' '
+
+#define SKIP_IF_SAME_L "skip_if_same"
+#define SKIP_IF_SAME_S ' '
+
 string toolName = "";
 /************************************
  * Function: CmdLineParser
@@ -455,6 +461,10 @@ void CmdLineParser::initOptions()
 
     this->AddOptions(NO_EXTRACT_LIST_L, NO_EXTRACT_LIST_S, "", "Do not extract or list binaries",
                      true); // Hidden
+    
+    this->AddOptions(COMP_TYPE_L, COMP_TYPE_S, "componentName", "Specify the PLDM component type to extract");
+
+    this->AddOptions(SKIP_IF_SAME_L, SKIP_IF_SAME_S, "", "Skip firmware update if current and new versions match");
 }
 
 bool csvSplit(string str, vector<string>& strv)
@@ -655,6 +665,11 @@ ParseStatus CmdLineParser::HandleOption(string name, string value)
         _cmdLineParams->target_file = value;
         return PARSE_OK;
     }
+    else if (name == COMP_TYPE_L)
+    {
+        _cmdLineParams->component_type = value;
+        return PARSE_OK;
+    }
     else if (name == QUERY_L)
     {
         _cmdLineParams->query_device = true;
@@ -813,6 +828,11 @@ ParseStatus CmdLineParser::HandleOption(string name, string value)
         }
         return PARSE_OK;
     }
+    else if (name == SKIP_IF_SAME_L)
+    {
+        _cmdLineParams->skip_if_same = true;
+        return PARSE_OK;
+    }
     else
     {
         cout << "Unknown Flag: " << name << "\n";
