@@ -191,14 +191,24 @@ void MlxlinkCablesCommander::getDdmValuesFromPddr()
         _cableDdm.channels = _numOfLanes;
         _cableDdm.temperature.val = getFieldValue("temperature") / 256;
         _cableDdm.voltage.val = getFieldValue("voltage") / MILLIVOLT_UNIT;
+        float txMultiplier = 1;
+        try
+        {
+            txMultiplier = pow(2, getFieldValue("tx_bias_scaling_factor"));
+        }
+        catch (const std::exception& e)
+        {
+            // If the field does not exist, set the multiplier to 1
+            // txMultiplier = 1;
+        }
 
         string laneStr = "";
         for (int lane = 0; lane < _cableDdm.channels; lane++)
         {
-            laneStr = to_string(lane);
+            laneStr = to_string(_moduleLanesMapping[lane]);
             _cableDdm.rx_power[lane].val = getPower(getFieldValue("rx_power_lane" + laneStr));
             _cableDdm.tx_power[lane].val = getPower(getFieldValue("tx_power_lane" + laneStr));
-            _cableDdm.tx_bias[lane].val = getFieldValue("tx_bias_lane" + laneStr);
+            _cableDdm.tx_bias[lane].val = getFieldValue("tx_bias_lane" + laneStr) * txMultiplier;
         }
     }
 }
@@ -470,7 +480,7 @@ void MlxlinkCablesCommander::prepareSFPDdmInfo()
 {
     u_int32_t tempVal = 0;
     u_int8_t* sfp51Page = (u_int8_t*)malloc(sizeof(u_int8_t) * CABLE_PAGE_SIZE);
-    loadEEPRMPage(PAGE_01, LOWER_PAGE_OFFSET, sfp51Page, I2C_ADDR_HIGH);
+    loadEEPRMPage(PAGE_A2, LOWER_PAGE_OFFSET, sfp51Page, I2C_ADDR_HIGH);
 
     getDdmValuesFromPddr();
 
@@ -561,7 +571,7 @@ void MlxlinkCablesCommander::readCableDDMInfo()
         case IDENTIFIER_SFP:
         case IDENTIFIER_QSA:
             prepareSFPDdmInfo();
-            loadEEPRMPage(PAGE_01, LOWER_PAGE_OFFSET, thresholdPage, I2C_ADDR_HIGH);
+            loadEEPRMPage(PAGE_A2, LOWER_PAGE_OFFSET, thresholdPage, I2C_ADDR_HIGH);
             prepareThresholdInfo(thresholdPage);
             break;
         case IDENTIFIER_SFP_DD:
@@ -790,7 +800,7 @@ void MlxlinkCablesCommander::initValidPages()
     }
     if (_sfp51Paging)
     {
-        p = page_t{PAGE_01, LOWER_PAGE_OFFSET, I2C_ADDR_HIGH};
+        p = page_t{PAGE_A2, LOWER_PAGE_OFFSET, I2C_ADDR_HIGH};
         _validPages.push_back(p);
     }
     if (qsfpCable && !_passiveQsfp)
@@ -1082,7 +1092,7 @@ MlxlinkCmdPrint MlxlinkCablesCommander::readFromEEPRM(u_int16_t page, u_int16_t
     u_int8_t* pageH = NULL;
     u_int32_t i2cAddress = I2C_ADDR_LOW;
     // if SFP51 paging is supported, then we use i2c 0x51 to Access page 1
-    if (_sfp51Paging && page == PAGE_01)
+    if (_sfp51Paging && (page >= PAGE_01 || offset >= CABLE_PAGE_SIZE))
     {
         i2cAddress = I2C_ADDR_HIGH;
     }
@@ -1535,7 +1545,7 @@ void MlxlinkCablesCommander::showControlParams()
         rxPostEmph = getFieldValue("cable_rx_post_emphasis");
         rxAmp = getFieldValue("cable_rx_amp");
     }
-    
+
     bool isCmis = _cableIdentifier >= IDENTIFIER_SFP_DD;
 
     sendPrmReg(ACCESS_REG_PMCR, GET);
