@@ -102,12 +102,30 @@
 #define BER_MONITOR_INFO_FLAG_SHORT ' '
 #define PEPC_SHOW_FLAG "show_external_phy"
 #define PEPC_SHOW_FLAG_SHORT ' '
+#define MULTI_PORT_MODULE_INFO_FLAG "show_multi_port_module_info"
+#define MULTI_PORT_MODULE_INFO_FLAG_SHORT ' '
+#define MULTI_PORT_MODULE_INFO_ACRONYM_FLAG "smpmi"
+#define MULTI_PORT_MODULE_INFO_ACRONYM_FLAG_SHORT ' '
+#define MULTI_PORT_INFO_FLAG "show_multi_port_info"
+#define MULTI_PORT_INFO_FLAG_SHORT ' '
+#define MULTI_PORT_INFO_ACRONYM_FLAG "smpi"
+#define MULTI_PORT_INFO_ACRONYM_FLAG_SHORT ' '
+#define PLR_INFO_FLAG "show_plr"
+#define PLR_INFO_FLAG_SHORT ' '
+#define KR_INFO_FLAG "show_kr"
+#define KR_INFO_FLAG_SHORT ' '
+#define RX_RECOVERY_COUNTERS_FLAG "show_rx_recovery_counters"
+#define RX_RECOVERY_COUNTERS_FLAG_SHORT ' '
+#define PERIODIC_EQ_FLAG "show_peq"
+#define PERIODIC_EQ_FLAG_SHORT ' '
 
 //------------------------------------------------------------
 //        Mlxlink COMMANDS Flags
 
 #define PAOS_FLAG "port_state"
 #define PAOS_FLAG_SHORT 'a'
+#define PMAOS_FLAG "module_state"
+#define PMAOS_FLAG_SHORT ' '
 #define PTYS_FLAG "speeds"
 #define PTYS_FLAG_SHORT 's'
 #define PPLR_FLAG "loopback"
@@ -140,6 +158,8 @@
 #define PRBS_INVERT_TX_POL_FLAG_SHORT ' '
 #define PRBS_INVERT_RX_POL_FLAG "invert_rx_polarity"
 #define PRBS_INVERT_RX_POL_FLAG_SHORT ' '
+#define PRBS_DC_COUPLE_ALLOW_FLAG "dc_cpl_allow"
+#define PRBS_DC_COUPLE_ALLOW_FLAG_SHORT ' '
 #define PPRT_TUNING_TYPE_FLAG "tuning_type"
 #define PPRT_TUNING_TYPE_FLAG_SHORT ' '
 #define BER_COLLECT_FLAG "ber_collect"
@@ -160,6 +180,16 @@
 #define PEPC_AN_MODE_FLAG_SHORT ' '
 #define PTYS_LINK_MODE_FORCE_FLAG "link_mode_force"
 #define PTYS_LINK_MODE_FORCE_FLAG_SHORT ' '
+#define PHY_RECOVERY_FLAG "phy_recovery"
+#define PHY_RECOVERY_FLAG_SHORT ' '
+#define PHY_RECOVERY_TYPE_FLAG "recovery_type"
+#define PHY_RECOVERY_TYPE_FLAG_SHORT ' '
+#define LINK_TRAINING_FLAG "link_training"
+#define LINK_TRAINING_FLAG_SHORT ' '
+#define SET_LINK_PEQ_FLAG "set_link_peq"
+#define SET_LINK_PEQ_FLAG_SHORT ' '
+#define PLANE_FLAG "plane"
+#define PLANE_FLAG_SHORT ' '
 
 //------------------------------------------------------------
 //        Mlxlink Cable info flags
@@ -310,6 +340,7 @@ enum OPTION_TYPE
     SEND_BER_COLLECT,
     SEND_AMBER_COLLECT,
     SEND_PAOS,
+    SEND_PMAOS,
     SEND_PTYS,
     SEND_PPLM,
     SEND_PPLR,
@@ -324,18 +355,33 @@ enum OPTION_TYPE
     RS_FEC_HISTOGRAM,
     SLRG_TEST,
     PCIE_ERROR_INJ,
+    SHOW_MULTI_PORT_INFO,
+    SHOW_MULTI_PORT_MODULE_INFO,
+    SHOW_PLR,
+    SHOW_KR,
+    SHOW_RX_RECOVERY_COUNTERS,
+    SEND_PHY_RECOVERY,
+    SEND_LINK_TRAINING,
+    SHOW_PERIODIC_EQ,
+    SET_PERIODIC_EQ,
+
     // Any new function's index should be added before FUNCTION_LAST in this enum
     FUNCTION_LAST
 };
 
 ///////////
-struct MODULE_FIELD
+class ModuleField
 {
+public:
+    ModuleField(string uiName, string amberName, bool multiVal, bool perLane, bool requireDdm, bool supported = true);
+    ~ModuleField() = default;
+
     string uiName;
     string amberName;
     bool multiVal;
     bool perLane;
     bool requireDdm;
+    bool supported;
 };
 
 using namespace std;
@@ -347,6 +393,7 @@ public:
     virtual ~MlxlinkCommander();
 
     void checkRegCmd();
+    bool isBackplane();
     void validatePortToLC();
     virtual void validatePortType(const string& portTypeStr);
     void updatePortType();
@@ -360,6 +407,7 @@ public:
     void checkAllPortsStatus();
     void handlePortStr(const string& portStr);
     void labelToLocalPort();
+    void findFirstValidPort();
     void labelToHCALocalPort();
     void labeltoDSlocalPort();
     bool isDSdevice();
@@ -372,7 +420,7 @@ public:
     void checkStrLength(const string& str);
     void getActualNumOfLanes(u_int32_t linkSpeedActive, bool extended);
     u_int32_t activeSpeed2gNum(u_int32_t mask, bool extended);
-    string activeSpeed2Str(u_int32_t mask, bool extended);
+    string activeSpeed2Str(u_int32_t mask, bool extended, bool isXdrSlowActive = false);
     void getCableParams();
     bool inPrbsTestMode();
     bool checkGBPpaosDown();
@@ -384,28 +432,23 @@ public:
     void
       fillEthPortGroupMap(u_int32_t localPort, u_int32_t labelPort, u_int32_t group, u_int32_t width, bool spect2WithGb);
     bool handleIBLocalPort(u_int32_t labelPort, bool ibSplitReady);
-    bool handleEthLocalPort(u_int32_t labelPort, bool spect2WithGb);
-    bool handleQTM3LocalPort(u_int32_t labelPort);
+    void handleAllEthLocalPorts(std::vector<string> labelPortsStr, bool spect2WithGb, bool skipException);
+    void handleAllGPULocalPorts(std::vector<string> labelPortsStr, bool skipException);
+    void handleAllQTM3LocalPorts(std::vector<string> labelPortsStr, bool skipException);
     void handleLabelPorts(std::vector<string> labelPortsStr, bool skipException = false);
     vector<string> localToPortsPerGroup(vector<u_int32_t> localPorts);
     u_int32_t getPortGroup(u_int32_t localPort);
-    string getValuesOfActiveLanes(const string& row);
+    string getValuesOfActiveLanes(const string& row, bool isSnr = false);
     bool checkIfModuleExtSupported();
 
     // Mlxlink query functions
     virtual void showModuleInfo();
-    void prepareBerModuleInfo(bool valid, const vector<AmberField>& moduleInfoFields);
-    void pushSnrModuleInfoFields(bool valid);
-    void runningVersion();
     virtual void operatingInfoPage();
     virtual void supportedInfoPage();
     virtual void troubInfoPage();
     void showPddr();
     void getPtys();
     virtual void showBer();
-    void prepare40_28_16nmEyeInfo(u_int32_t numOfLanesToUse);
-    void prepare7nmEyeInfo(u_int32_t numOfLanesToUse);
-    void prepare5nmEyeInfo(u_int32_t numOfLanesToUse);
     virtual void showEye();
     virtual void showFEC();
     virtual void showSltp();
@@ -417,6 +460,11 @@ public:
     virtual void collectAMBER();
     void collectBER();
     void showTxGroupMapping();
+    void showPlr();
+    void showKr();
+    void showRxRecoveryCounters();
+    void showPeriodicEq();
+    void setPeriodicEq();
 
     // Query helper functions
     string getCableTechnologyStr(u_int32_t cableTechnology);
@@ -442,6 +490,15 @@ public:
     string fecMaskToUserInputStr(u_int32_t fecCapMask);
     string fecMaskToStr(u_int32_t mask);
     void updateSwControlStatus();
+    u_int32_t getNumberOfPorts();
+    bool checkDPNvSupport();
+    void prepareBerModuleInfo(bool valid, const vector<AmberField>& moduleInfoFields);
+    void pushSnrModuleInfoFields(bool valid);
+    void runningVersion();
+    void prepare40_28_16nmEyeInfo(u_int32_t numOfLanesToUse);
+    void prepare7nmEyeInfo(u_int32_t numOfLanesToUse);
+    void prepare5nmEyeInfo(u_int32_t numOfLanesToUse);
+    void getPddrOperInfo();
 
     void showTestMode();
     void showTestModeBer();
@@ -452,7 +509,7 @@ public:
     void checkPCIeValidity();
     virtual void prepareBerInfo();
     virtual void prepareBerInfoEDR();
-    virtual void getPcieNdrCounters();
+    virtual void getPcieNdrCounters(u_int32_t flitActive = 0);
     virtual vector<AmberField> getBerFields();
 
     std::map<std::string, std::string> getPprt();
@@ -514,10 +571,15 @@ public:
     MlxlinkCmdPrint _cableDumpRawCmd;
     MlxlinkCmdPrint _cableDDMCmd;
     MlxlinkCmdPrint _portGroupMapping;
+    MlxlinkCmdPrint _plrInfoCmd;
+    MlxlinkCmdPrint _krInfoCmd;
+    MlxlinkCmdPrint _rxRecoveryCountersCmd;
+    MlxlinkCmdPrint _periodicEqInfoCmd;
 
     // Mlxlink config functions
     void clearCounters();
     void sendPaos();
+    void sendPmaos();
     virtual void handlePrbs();
     void sendPtys();
     virtual void sendPplm();
@@ -527,21 +589,30 @@ public:
     void setTxGroupMapping();
     void handleRxErrInj();
     void handlePCIeErrInj();
+    void handlePhyRecovery();
+    void handleLinkTraining();
 
     // Config helper functions
     bool isForceDownSupported();
+    bool isPmaosResetToggleSupported();
     bool isPPHCRSupported();
     void sendGBPaosCmd(PAOS_ADMIN adminStatus, bool forceDown);
     void sendPaosCmd(PAOS_ADMIN adminStatus, bool forceDown = false);
     void sendPaosDown(bool toggleCommand = false);
     void sendPaosUP();
     void sendPaosToggle();
+    void sendPmaosDown();
+    void sendPmaosUP();
+    void sendPmaosToggle();
+    void sendPmaosCmd(PMAOS_ADMIN adminStatus);
+    bool checkPmaosDown();
     void checkPRBSModeCap(u_int32_t modeSelector, u_int32_t capMask);
     void checkPrbsRegsCap(const string& prbsReg, const string& laneRate);
     void checkPrbsPolCap(const string& prbsReg);
     void checkPprtPptt();
+    void checkDcCouple();
     void checkPplrCap();
-    void sendPrbsPpaos(bool);
+    void sendPrbsPpaos(bool testMode, bool dc_cpl_allow = false);
     void startTuning();
     void prbsConfiguration(const string& prbsReg,
                            bool enable,
@@ -570,6 +641,14 @@ public:
     void checkSltpParamsSize();
     bool isMpeinjSupported();
     u_int32_t getRateFromPptt();
+    void showMultiPortInfo();
+    void showMultiPortModuleInfo();
+    string getBerString();
+    void updateLocalPortGroup();
+    std::string getSpeedStrForTableView();
+    bool checkAllPortsDown();
+    void configurePeqForAllPorts(bool brLanesCap);
+    void setPlaneIndex(int planeIndex);
 
     // Mlxlink params
     UserInput _userInput;
@@ -581,6 +660,7 @@ public:
     u_int32_t _cableMediaType;
     u_int32_t _fecActive;
     u_int32_t _protoActive;
+    int _phyMngrFsmState;
     u_int32_t _anDisable;
     u_int32_t _speedBerCsv;
     u_int32_t _cableIdentifier;
@@ -589,6 +669,7 @@ public:
     u_int32_t _cableLen;
     u_int32_t _activeSpeed;
     u_int32_t _activeSpeedEx;
+    bool _isXdrSlowActive;
     u_int32_t _laneSpeedFromPptt;
     u_int32_t _protoCapability;
     u_int32_t _deviceCapability;
@@ -599,6 +680,7 @@ public:
     u_int32_t _slotIndex;
     u_int32_t _linkSpeed;
     u_int32_t _groupOpcode;
+    u_int32_t _loopbackMode;
     string _extAdbFile;
     string _fwVersion;
     string _speedStrG;
@@ -634,9 +716,16 @@ public:
     MlxlinkErrInjCommander* _errInjector;
     MlxlinkPortInfo* _portInfo;
     MlxlinkAmBerCollector* _amberCollector;
+    string _fomStr;
 
 protected:
     vector<AmberField> _ppcntFields;
+
+    // New helper functions for port info display
+    string getLabelPortString(const PortGroup& portInfo);
+    void updatePortModuleInfo(vector<string>& tableData, const PortGroup& portInfo, u_int32_t& posToUpdateWidthInVector);
+    void updatePortInfo(vector<string>& tableData, const PortGroup& portInfo, u_int32_t& posToUpdateWidthInVector);
+    void updatePortStatisticalInfo(vector<string>& tableData, u_int32_t& posToUpdateWidthInVector);
 };
 
 #endif /* MLXLINK_COMMANDER_H */
