@@ -34,7 +34,7 @@
 #define MLXLINK_ENUMS_H
 
 // Common definitions
-#define AMBER_VERSION "4.5"
+#define AMBER_VERSION "5.75"
 
 #define ACCESS_REG_MCIA "MCIA"
 #define ACCESS_REG_MDDQ "MDDQ"
@@ -47,6 +47,7 @@
 #define ACCESS_REG_MPIR "MPIR"
 #define ACCESS_REG_MSGI "MSGI"
 #define ACCESS_REG_MTCAP "MTCAP"
+#define ACCESS_REG_MTSR "MTSR"
 #define ACCESS_REG_MTMP "MTMP"
 #define ACCESS_REG_MVCAP "MVCAP"
 #define ACCESS_REG_MVCR "MVCR"
@@ -86,6 +87,13 @@
 #define ACCESS_REG_SPZR "SPZR"
 #define ACCESS_REG_MMCR "MMCR"
 #define ACCESS_REG_PPRM "PPRM"
+#define ACCESS_REG_MCAM "MCAM"
+#define ACCESS_REG_PMDR "PMDR"
+#define ACCESS_REG_PTASv2 "PTASv2"
+#define ACCESS_REG_SLLM "SLLM"
+#define ACCESS_REG_MTMG "MTMG"
+#define ACCESS_REG_MTMR "MTMR"
+
 // define all used regs above this line
 
 #define QSFP_CHANNELS 4
@@ -93,10 +101,11 @@
 #define NUM_OF_BINS 16
 #define MTMP_GEARBOX_SENSOR_OFFSET 256
 #define MAX_NETWORK_LANES 8
-#define MAX_IB_LANES 4
+#define MAX_IB_LANES 8
 #define MAX_PCIE_LANES 16
 #define SLRG_PCIE_7NM_SLEEP 10
 #define SLRG_PCIE_7NM_TIMEOUT SLRG_PCIE_7NM_SLEEP * 50
+#define SLTP_LANE_SPEED_SLEEP 250
 // cables parse definition
 
 #define SHIFT_0 0
@@ -115,6 +124,11 @@
 #define SHIFT_13 13
 #define SHIFT_14 14
 #define SHIFT_15 15
+#define SHIFT_16 16
+#define SHIFT_17 17
+#define SHIFT_18 18
+#define SHIFT_19 19
+#define SHIFT_20 20
 /*
  * QSFP Paging, Page 0 Low
  */
@@ -392,6 +406,7 @@
 #define MAX_LOCAL_PORT_QUANTUM3 148
 #define MAX_LOCAL_PORT_SPECTRUM2 128
 #define MAX_LOCAL_PORT_SPECTRUM4 258
+#define MAX_LOCAL_PORT_SPECTRUM5 515
 
 #define MAX_ETH_SW_SPLIT 8
 
@@ -402,6 +417,7 @@
 #define MAX_TX_GROUP_COUNT 10
 
 #define PCAM_FORCE_DOWN_CAP_MASK 0x2000
+#define PCAM_PMAOS_RESET_TOGGLE_CAP_MASK 0x4000
 
 #define OPERATIONAL_ERROR_STR "ME_ICMD_OPERATIONAL_ERROR"
 
@@ -513,12 +529,19 @@ enum FIELD_ACCESS
     FIELD_ACCESS_ADVANCED = 0x8,
 };
 // mlxlink commander enums
+
 enum PPAOS_ADMIN
 {
     PPAOS_REGULAR_OPERATION = 0,
     PPAOS_PHY_TEST_MODE = 1
 };
 
+enum PPAOS_DC_CPL_ALLOW
+{
+    PPAOS_DC_CPL_NO = 0,
+    PPAOS_DC_CPL_ALLOW = 1
+};
+
 enum TX_INDEX_SELECTOR
 {
     TX_LOCAL_PORT,
@@ -547,6 +570,26 @@ enum PAOS_ADMIN
     PAOS_DOWN = 2
 };
 
+enum PMAOS_ADMIN
+{
+    PMAOS_NO_CMD = 0,
+    PMAOS_ENABLED = 1,
+    PMAOS_DISABLED_BY_CONFIGURATION = 2,
+    PMAOS_ENABLED_ONCE = 3,
+    PMAOS_TOGGLE = 4,
+    PMAOS_DISABLED = 14
+};
+
+enum PMAOS_OPER_STATUS
+{
+    PMAOS_OPER_INITIALIZING = 0,
+    PMAOS_OPER_PLUGGED_ENABLED = 1,
+    PMAOS_OPER_UNPLUGGED = 2,
+    PMAOS_OPER_MODULE_PLUGGED_WITH_ERROR = 3,
+    PMAOS_OPER_PLUGGED_DISABLED = 4,
+    PMAOS_OPER_UNKNOWN = 5
+};
+
 enum PCIE_PORT_TYPE
 {
     PORT_TYPE_EP = 0,
@@ -554,6 +597,13 @@ enum PCIE_PORT_TYPE
     PORT_TYPE_DS = 6
 };
 
+enum MGIR_MODULE_MASTER_FW_DEFAULT
+{
+    MGIR_MODULE_MASTER_FW_DEFAULT_FW_CONTROLLED,
+    MGIR_MODULE_MASTER_FW_DEFAULT_SW_CONTROLLED,
+    MGIR_MODULE_MASTER_FW_DEFAULT_STAND_ALONE
+};
+
 enum MODULE_ID
 {
     MODULE_ID_SFP = 0x3,
@@ -571,6 +621,14 @@ typedef enum
     TG
 } PAOS_CMD;
 
+typedef enum
+{
+    PMAOS_NO,
+    PMAOS_UP,
+    PMAOS_DN,
+    PMAOS_TG
+} PMAOS_CMD;
+
 enum MPCNT_GROUPS
 {
     MPCNT_PERFORMANCE_GROUP = 0,
@@ -614,6 +672,7 @@ enum PPCNT_GROUPS
     PPCNT_PHY_GROUP = 0x12,
     PPCNT_PER_TRAFFIC_CLASS_CONGESTION_COUNTERS_GROUP = 0x13,
     PPCNT_STATISTICAL_GROUP = 0x16,
+    PPCNT_PHYSICAL_LAYER_RECOVERY_COUNTERS = 0x1A,
     PPCNT_IB_PORT_COUNTERS_GROUP = 0x20,
     PPCNT_EXT_IB_PORT_COUNTERS_GROUP = 0x21,
     PPCNT_PLR_GROUP = 0x22,
@@ -637,11 +696,15 @@ enum NETWORK_PORT_TYPE
 
 enum CABLE_TYPE
 {
-    UNIDENTIFIED,
-    ACTIVE,
-    OPTICAL_MODULE,
-    PASSIVE,
-    UNPLUGGED
+    UNIDENTIFIED = 0,
+    ACTIVE = 1,
+    OPTICAL_MODULE = 2,
+    PASSIVE = 3,
+    UNPLUGGED = 4,
+    TWISTED_PAIR = 5,
+    CPO = 6,
+    OE = 7,
+    ELS = 8
 };
 
 enum PCIE_LINK_SPEED
@@ -944,13 +1007,22 @@ enum MODULE_ERROR_TYPE
 
 enum PEMI_GROUP_CAP_EXT
 {
-    PEMI_GROUP_CAP_SNR = 0x2
+    PEMI_GROUP_CAP_MODULE_STATUS = 0x1,
+    PEMI_GROUP_CAP_SNR = 0x2,
+    PEMI_GROUP_CAP_LASER_MONITORS = 0x4,
+    PEMI_GROUP_CAP_PRE_FEC_BER = 0x10,
 };
 
 enum PEMI_GROUP_SEL_EXT
 {
+    PEMI_GROUP_SEL_MODULE_STATUS_SAMPLES = 0,
     PEMI_GROUP_SEL_SNR_SAMPLES = 1,
-    PEMI_GROUP_SEL_SNR_PROP = 17
+    PEMI_GROUP_SEL_LASER_MONITORS_SAMPLES = 2,
+    PEMI_GROUP_SEL_PRE_FEC_BER_SAMPLES = 4,
+    PEMI_GROUP_SEL_LASER_SOURCE_MODULE_ESSENTIAL_SAMPLES = 7,
+    PEMI_GROUP_SEL_LASER_SOURCE_MODULE_ADVANCED_SAMPLES = 8,
+    PEMI_GROUP_SEL_SNR_PROP = 17,
+    PEMI_GROUP_SEL_PRE_FEC_BER_PROP = 20,
 };
 
 enum ERROR_CODE_RES
@@ -1364,6 +1436,19 @@ enum IB_PHY_FSM_STATE
     IB_AN_FSM_POLLING = 8
 };
 
+enum PRO_FILE_FEC_IN_USE
+{
+    PRO_FILE_FEC_IN_USE_IB_SPEC = 1,
+    PRO_FILE_FEC_IN_USE_INTERNAL_PORTS = 2,
+    PRO_FILE_FEC_IN_USE_PASSIVE_COPPER_SHORT = 4,
+    PRO_FILE_FEC_IN_USE_PASSIVE_COPPER_MEDIUM = 8,
+    PRO_FILE_FEC_IN_USE_PASSIVE_COPPER_LONG = 16,
+    PRO_FILE_FEC_IN_USE_ACTIVE_OPTICS = 32,
+    PRO_FILE_FEC_IN_USE_OPTICS_LONG_REACH = 64,
+    PRO_FILE_FEC_IN_USE_NO_FEC = 128,
+    PRO_FILE_FEC_IN_USE_FEC_ON = 256,
+};
+
 enum TECH
 {
     TECH_NA = 0,
@@ -1856,10 +1941,47 @@ enum LOCAL_REASON_OPCODE
     LOCAL_REASON_OPCODE_FAST_RECOVERY_EFFECTIVE_BER = 0x1D,
     LOCAL_REASON_OPCODE_FAST_RECOVERY_SYMBOL_BER = 0x1E,
     LOCAL_REASON_OPCODE_FAST_RECOVERY_CREDIT_WATCHDOG = 0x1F,
-    LOCAL_REASON_OPCODE_TIMEOUT = 0x20,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_TO_SLEEP_STATE = 0x20,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_TO_DISABLE_STATE = 0x21,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_TO_DISABLE_AND_PORT_LOCK = 0x22,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_DUE_TO_THERMAL_EVENT = 0x23,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_DUE_TO_FORCE_EVENT = 0x24,
+    LOCAL_REASON_OPCODE_PEER_SIDE_DOWN_DUE_TO_RESET_EVENT = 0x25,
+    LOCAL_REASON_OPCODE_RESET_NO_POWER_CYCLE = 0x26,
+    LOCAL_REASON_OPCODE_FAST_RECOVERY_TX_PLR_TRIGGER = 0x27,
+    LOCAL_REASON_OPCODE_DOWN_DUE_TO_HW_FORCE_EVENT = 0x28,
+    LOCAL_REASON_OPCODE_L1_EXIT_FAILURE = 0x2A,
+    LOCAL_REASON_OPCODE_TOO_MANY_LINK_ERROR_RECOVERIES = 0x2B,
+    LOCAL_REASON_OPCODE_DOWN_DUE_TO_CONTAIN_MODE = 0x2C,
+    LOCAL_REASON_OPCODE_BW_LOSS_THRESHOLD_EXCEEDED = 0x2D,
+    LOCAL_REASON_OPCODE_ELS_LASER_FAULT = 0x2E,
+    LOCAL_REASON_OPCODE_TIMEOUT = 0x30,
     LOCAL_REASON_OPCODE_RESERVED = 0xE4,
 };
 
+
+enum PPTT_PARAMS
+{
+    LANE_RATE_ADMIN
+};
+enum PPTT_SPEED_MASK
+{
+    PPTT_SDR,
+    PPTT_DDR,
+    PPTT_QDR,
+    PPTT_FDR10,
+    PPTT_FDR,
+    PPTT_EDR,
+    PPTT_HDR,
+    PPTT_NDR,
+    PPTT_XDR,
+    PPTT_RESERVED,
+    PPTT_1GE,
+    PPTT_XAUI,
+    PPTT_50GE_KR4,
+    PPTT_SPEED_MASK_MAX
+};
+
 enum UP_REASON_PWR
 {
     UP_REASON_PWR_NO_DOWN_COMMAND = 0,
@@ -1896,32 +2018,58 @@ enum FAST_LINK_UP_STATUS
 
 enum PPRM_OPERATION_RECOVERY
 {
-    PPRM_OPERATION_RECOVERY_HOST_LOG = 0,
+    PPRM_OPERATION_RECOVERY_HOST_LOG = 1,
     PPRM_OPERATION_RECOVERY_HOST_SERDES = 2,
     PPRM_OPERATION_RECOVERY_MODULE_TX = 4,
     PPRM_OPERATION_RECOVERY_MODULE_DATA_PATH = 8
 };
 
-enum PPTT_PARAMS
+enum PPRM_RECOVERY_STATUS
 {
-    LANE_RATE_ADMIN
+    PPRM_RECOVERY_STATUS_FW_DEFAULT = 0,
+    PPRM_RECOVERY_STATUS_ENABLE = 1,
+    PPRM_RECOVERY_STATUS_DISABLE = 2,
+    PPRM_RECOVERY_STATUS_DISABLE_SUPPORT_IN_NEGOTIATION = 3
 };
-enum PPTT_SPEED_MASK
+
+enum MCAM_CAP_MASK
 {
-    PPTT_SDR,
-    PPTT_DDR,
-    PPTT_QDR,
-    PPTT_FDR10,
-    PPTT_FDR,
-    PPTT_EDR,
-    PPTT_HDR,
-    PPTT_NDR,
-    PPTT_XDR,
-    PPTT_RESERVED,
-    PPTT_1GE,
-    PPTT_XAUI,
-    PPTT_50GE_KR4,
-    PPTT_SPEED_MASK_MAX
+    MCAM_CAP_MASK_DPNV = 0x10
+};
+
+enum PLR_REJECT_MODE
+{
+    PLR_REJECT_MODE_PLR_MARGIN,
+    PLR_REJECT_MODE_CRC_AND_CS,
+    PLR_REJECT_MODE_CS,
+    PLR_REJECT_MODE_RESERVED
+};
+
+enum KR_EXT_OPER
+{
+    KR_EXT_OPER_LT_DISABLED,
+    KR_EXT_OPER_LT_ENABLED_REGULAR_KR,
+    KR_EXT_OPER_LT_ENABLED_EXT_KR_ASYNC,
+};
+
+enum KR_PRBS_TYPE
+{
+    KR_PRBS_TYPE_PRBS13,
+    KR_PRBS_TYPE_PRBS31,
+};
+
+enum KR_EXT_REQ
+{
+    KR_EXT_REQ_FW_DEFAULT = 0,
+    KR_EXT_REQ_KR_EXT_REGULAR_LT = 1,
+    KR_EXT_REQ_KR_EXT_ENABLED_ADVANCED_ALGO = 2
+};
+
+enum XDR_LT_C2C_EN
+{
+    XDR_LT_C2C_EN_FW_DEFAULT = 0,
+    XDR_LT_C2C_EN_XDR_LT_C2C_DISABLED_LT = 1,
+    XDR_LT_C2C_EN_XDR_LT_C2C_ENABLED_LT = 2
 };
 
 #endif /* MLXLINK_ENUMS_H */
