@@ -33,6 +33,7 @@
  */
 
 #include "mlxlink_reg_parser.h"
+#include <common/tools_utils.h>
 
 MlxlinkRegParser::MlxlinkRegParser() : RegAccessParser("", "", "", NULL, 0)
 {
@@ -47,6 +48,7 @@ MlxlinkRegParser::MlxlinkRegParser() : RegAccessParser("", "", "", NULL, 0)
 
     _isHCA = false;
     _isSwControled = false;
+    _isDPNvSupported = false;
 }
 
 MlxlinkRegParser::~MlxlinkRegParser() {}
@@ -69,7 +71,7 @@ void MlxlinkRegParser::resetParser(const string& regName)
     else
     {
         _parseMode = Pm_Known;
-        _len = (_regNode->size) >> 5;
+        _len = (_regNode->get_size()) >> 5;
     }
     _buffer.resize(_len);
     for (std::vector<u_int32_t>::size_type j = 0; j < _len; j++)
@@ -147,6 +149,18 @@ void MlxlinkRegParser::setDefaultFields(const string& regName, const string& fie
     {
         updateWithDefault("lp_gl", fieldsStr, 1);
     }
+
+    if (_isHCA && _planeInd >= 0)
+    {
+        updateWithDefault("plane_ind", fieldsStr, static_cast<u_int32_t>(_planeInd));
+    }
+
+    if (_isHCA && _isDPNvSupported &&
+        (regName == ACCESS_REG_MPIR || regName == ACCESS_REG_MPCNT || regName == ACCESS_REG_MPEIN ||
+         regName == ACCESS_REG_MPEINJ))
+    {
+        updateWithDefault("DPNv", fieldsStr, 1);
+    }
 }
 
 void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t method)
@@ -158,6 +172,39 @@ void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t me
     genBuffSendRegister(regName, method);
 }
 
+void MlxlinkRegParser::sendPrmRegWithoutReset(const string& regName,
+                                              maccess_reg_method_t method,
+                                              const char* fields,
+                                              ...)
+{
+    char fieldsCstr[MAX_FIELDS_BUFFER];
+    va_list args;
+    va_start(args, fields);
+    vsnprintf(fieldsCstr, MAX_FIELDS_BUFFER, fields, args);
+    va_end(args);
+
+    string fieldsStr = string(fieldsCstr);
+    auto vectorOffields = MlxlinkRecord::split(fieldsStr, ",");
+
+    for (std::vector<u_int32_t>::size_type j = 0; j < _buffer.size(); j++)
+    {
+        _buffer[j] = CPU_TO_BE32((_buffer[j]));
+    }
+
+    for (const auto& token : vectorOffields)
+    {
+        auto fieldToken = MlxlinkRecord::split(token, "=");
+        string fieldName = fieldToken[0];
+        u_int32_t fieldValue = stoi(fieldToken[1], nullptr, 0);
+
+        updateField(fieldName, fieldValue);
+    }
+    setDefaultFields(regName, fieldsStr);
+
+    genBuffSendRegister(regName, method);
+}
+
+
 void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t method, const char* fields, ...)
 {
     char fieldsCstr[MAX_FIELDS_BUFFER];
@@ -185,9 +232,10 @@ void MlxlinkRegParser::sendPrmReg(const string& regName, maccess_reg_method_t me
     genBuffSendRegister(regName, method);
 }
 
-string MlxlinkRegParser::getFieldStr(const string& field, const u_int32_t size)
+string
+  MlxlinkRegParser::getFieldStr(const string& field, const u_int32_t size, const u_int32_t offset, bool offsetSpecified)
 {
-    return to_string(getFieldValue(field, size));
+    return to_string(getFieldValue(field, size, offset, offsetSpecified));
 }
 
 string MlxlinkRegParser::getRawFieldValueStr(const string fieldName)
@@ -220,14 +268,16 @@ string MlxlinkRegParser::getRawFieldValueStr(const string fieldName)
     return fullStr;
 }
 
-u_int32_t MlxlinkRegParser::getFieldValue(string field_name, u_int32_t size)
+u_int32_t MlxlinkRegParser::getFieldValue(string field_name, u_int32_t size, u_int32_t offset, bool offsetSpecified)
 {
-    return RegAccessParser::getFieldValue(field_name, _buffer, size);
+    u_int32_t field_Val = RegAccessParser::getFieldValue(field_name, _buffer, size, offset, offsetSpecified);
+
+    return field_Val;
 }
 
 u_int32_t MlxlinkRegParser::getFieldSize(string field_name)
 {
-    return RegAccessParser::getField(field_name)->size;
+    return RegAccessParser::getField(field_name)->get_size();
 }
 
 string MlxlinkRegParser::getAscii(const string& name, u_int32_t size)
