@@ -76,10 +76,21 @@ void MlxlinkUi::initRegAccessLib()
     _mlxlinkCommander->_gvmiAddress = _userInput._gvmiAddress;
     _mlxlinkCommander->_devID = _mlxlinkCommander->_regLib->getDevId();
     _mlxlinkCommander->_isHCA = dm_dev_is_hca(_mlxlinkCommander->_devID);
+    if (_mlxlinkCommander->_isHCA)
+    {
+        _mlxlinkCommander->_isDPNvSupported = _mlxlinkCommander->checkDPNvSupport();
+        dynamic_cast<MlxlinkCommander*>(_mlxlinkCommander)->setPlaneIndex(_userInput.planeIndex);
+    }
 }
 
 void MlxlinkUi::initPortInfo()
 {
+    if ((!_userInput._portSpecified && _userInput._csvBer != "") ||
+        (_userInput._showMultiPortInfo || _userInput._showMultiPortModuleInfo))
+    {
+        _mlxlinkCommander->findFirstValidPort();
+    }
+
     _mlxlinkCommander->labelToLocalPort();
     _mlxlinkCommander->validatePortType(_userInput._portType);
     _mlxlinkCommander->updateSwControlStatus();
@@ -87,7 +98,10 @@ void MlxlinkUi::initPortInfo()
     {
         _mlxlinkCommander->checkValidFW();
     }
-    _mlxlinkCommander->getProductTechnology();
+    if (!(_mlxlinkCommander->_mf->tp == MST_PCICONF && (dm_is_gpu(static_cast<dm_dev_id_t>(_mlxlinkCommander->_devID)))))
+    {
+        _mlxlinkCommander->getProductTechnology();
+    }
     if (!_userInput._pcie)
     {
         _mlxlinkCommander->_prbsTestMode = _mlxlinkCommander->inPrbsTestMode();
@@ -142,11 +156,17 @@ void MlxlinkUi::printSynopsisQueries()
 {
     printf(IDENT "QUERIES:\n");
     MlxlinkRecord::printFlagLine(PCIE_LINKS_FLAG_SHORT, PCIE_LINKS_FLAG, "", "Show valid PCIe links (PCIE only)");
+    MlxlinkRecord::printFlagLine(PLR_INFO_FLAG_SHORT, PLR_INFO_FLAG, "", "Show PLR Info");
+    MlxlinkRecord::printFlagLine(KR_INFO_FLAG_SHORT, KR_INFO_FLAG, "", "Show KR Info");
+    MlxlinkRecord::printFlagLine(PERIODIC_EQ_FLAG_SHORT, PERIODIC_EQ_FLAG, "",
+                                 "Show Link PEQ (Periodic Equalization) Info");
     MlxlinkRecord::printFlagLine(MODULE_INFO_FLAG_SHORT, MODULE_INFO_FLAG, "", "Show Module Info");
     MlxlinkRecord::printFlagLine(BER_FLAG_SHORT, BER_FLAG, "", "Show Physical Counters and BER Info");
     MlxlinkRecord::printFlagLine(EYE_OPENING_FLAG_SHORT, EYE_OPENING_FLAG, "", "Show Eye Opening Info");
     MlxlinkRecord::printFlagLine(FEC_DATA_FLAG_SHORT, FEC_DATA_FLAG, "", "Show FEC Capabilities");
     MlxlinkRecord::printFlagLine(SLTP_SHOW_FLAG_SHORT, SLTP_SHOW_FLAG, "", "Show Transmitter Info");
+    MlxlinkRecord::printFlagLine(RX_RECOVERY_COUNTERS_FLAG_SHORT, RX_RECOVERY_COUNTERS_FLAG, "",
+                                 "Show Rx Recovery Counters");
     MlxlinkRecord::printFlagLine(
       SHOW_TX_GROUP_MAP_FLAG_SHORT, SHOW_TX_GROUP_MAP_FLAG, "group_num",
       "Display all label ports mapped to group <group_num> (for Spectrum-2 and Quantum devices)");
@@ -155,6 +175,12 @@ void MlxlinkUi::printSynopsisQueries()
                                  "Show BER Monitor Info (not supported for HCA)");
     MlxlinkRecord::printFlagLine(PEPC_SHOW_FLAG_SHORT, PEPC_SHOW_FLAG, "",
                                  "Show External PHY Info (for Ethernet switches only)");
+    MlxlinkRecord::printFlagLineWithAcronym(MULTI_PORT_INFO_FLAG_SHORT, MULTI_PORT_INFO_FLAG,
+                                            MULTI_PORT_INFO_ACRONYM_FLAG_SHORT, MULTI_PORT_INFO_ACRONYM_FLAG, "",
+                                            "Show Multi Port Info Table");
+    MlxlinkRecord::printFlagLineWithAcronym(
+      MULTI_PORT_MODULE_INFO_FLAG_SHORT, MULTI_PORT_MODULE_INFO_FLAG, MULTI_PORT_MODULE_INFO_ACRONYM_FLAG_SHORT,
+      MULTI_PORT_MODULE_INFO_ACRONYM_FLAG, "", "Show Multi Port Module Info Table");
 }
 
 void MlxlinkUi::printSynopsisCommands()
@@ -162,6 +188,8 @@ void MlxlinkUi::printSynopsisCommands()
     printf(IDENT "COMMANDS:\n");
     MlxlinkRecord::printFlagLine(PAOS_FLAG_SHORT, PAOS_FLAG, "port_state",
                                  "Configure Port State [UP(up)/DN(down)/TG(toggle)]");
+    MlxlinkRecord::printFlagLine(PMAOS_FLAG_SHORT, PMAOS_FLAG, "module_state",
+                                "Configure Module State [UP(up)/DN(down)/TG(toggle)]");
     MlxlinkRecord::printFlagLine(
       PTYS_FLAG_SHORT, PTYS_FLAG, "speeds",
       "Configure Speeds "
@@ -205,6 +233,18 @@ void MlxlinkUi::printSynopsisCommands()
     printf(IDENT);
     MlxlinkRecord::printFlagLine(TX_GROUP_PORTS_FLAG_SHORT, TX_GROUP_PORTS_FLAG, "ports",
                                  "Ports to be mapped [1,2,3,4,...,128]");
+    printf(IDENT);
+    MlxlinkRecord::printFlagLine(LINK_TRAINING_FLAG_SHORT, LINK_TRAINING_FLAG, "link_training",
+                                 "Link Training [EN(enable)/DS(disable)/EN_EXT(enable_extra)]");
+    printf(IDENT);
+    MlxlinkRecord::printFlagLine(SET_LINK_PEQ_FLAG_SHORT, SET_LINK_PEQ_FLAG, "",
+                                 "Set link PEQ (Periodic Equalization) interval [10-40000]uS. 0 means FW-Default");
+    printf(IDENT);
+    MlxlinkRecord::printFlagLine(PHY_RECOVERY_FLAG_SHORT, PHY_RECOVERY_FLAG, "phy_recovery",
+                                 "PHY Recovery [EN(enable)/DS(disable)]");
+    printf(IDENT);
+    MlxlinkRecord::printFlagLine(PHY_RECOVERY_TYPE_FLAG_SHORT, PHY_RECOVERY_TYPE_FLAG, "recovery_type",
+                                 "PHY Recovery Type [host_serdes_feq/host_logic_re_lock]");
     MlxlinkRecord::printFlagLine(PRBS_MODE_FLAG_SHORT, PRBS_MODE_FLAG, "prbs_mode",
                                  "Physical Test Mode Configuration [EN(enable)/DS(disable)/TU(perform tuning)]");
     printf(IDENT);
@@ -239,6 +279,9 @@ void MlxlinkUi::printSynopsisCommands()
     MlxlinkRecord::printFlagLine(PRBS_INVERT_RX_POL_FLAG_SHORT, PRBS_INVERT_RX_POL_FLAG, "",
                                  "PRBS RX polarity inversion (Optional - Default No Inversion)");
     printf(IDENT);
+    MlxlinkRecord::printFlagLine(PRBS_DC_COUPLE_ALLOW_FLAG_SHORT, PRBS_DC_COUPLE_ALLOW_FLAG, "",
+                                 "For DC coupled ports only: This flag must be set to enter test mode");
+    printf(IDENT);
     MlxlinkRecord::printFlagLine(
       PRBS_LANES_FLAG_SHORT, PRBS_LANES_FLAG, "lanes",
       "PRBS lanes to set (one or more lane separated by comma)[0,1,2,...,7] (Optional - Default all lanes)");
@@ -406,6 +449,7 @@ void MlxlinkUi::printSynopsisCommands()
 
     MlxlinkRecord::printFlagLine(FORCE_YES_FLAG_SHORT, FORCE_YES_FLAG, "",
                                  "Non-interactive mode, answer yes to all questions");
+    MlxlinkRecord::printFlagLine(PLANE_FLAG_SHORT, PLANE_FLAG, "plane", "Plane port access, starts from 1");
 }
 
 void MlxlinkUi::printSynopsis()
@@ -550,6 +594,10 @@ void MlxlinkUi::validateGeneralCmdsParams()
     {
         throw MlxRegException("Please provide a valid paos command [UP(up)/DN(down)/TG(toggle)]");
     }
+    if (isIn(SEND_PMAOS, _sendRegFuncMap) && !checkPmaosCmd(_userInput._pmaosCmd))
+    {
+        throw MlxRegException("Please provide a valid pmaos command [UP(up)/DN(down)/TG(toggle)]");
+    }
     if (!isIn(SEND_PPLM, _sendRegFuncMap) && _userInput._speedFec != "")
     {
         throw MlxRegException("The --fec_speed flag is valid only with --fec flag");
@@ -573,7 +621,7 @@ void MlxlinkUi::validatePRBSParams()
 {
     bool prbsFlags = _userInput._sendPprt || _userInput._sendPptt || _userInput._pprtRate != "" ||
                      _userInput._pprtRate != "" || _userInput._prbsTxInv || _userInput._prbsRxInv ||
-                     _userInput._prbsLanesToSet.size() > 0;
+                     _userInput._prbsDcCoupledAllow || _userInput._prbsLanesToSet.size() > 0;
     if (isIn(SEND_PRBS, _sendRegFuncMap))
     {
         if (!checkPrbsCmd(_userInput._prbsMode))
@@ -594,6 +642,85 @@ void MlxlinkUi::validatePRBSParams()
     }
 }
 
+void MlxlinkUi::validatePhyRecoveryParams()
+{
+    bool phyRecoveryFlags =
+      _userInput._phyRecovery != "" || _userInput._phyRecoveryType != "" || _userInput._wdTimerSpecified;
+    if (isIn(SEND_PHY_RECOVERY, _sendRegFuncMap))
+    {
+        if (!checkPhyRecoveryCmd(_userInput._phyRecovery))
+        {
+            throw MlxRegException("Please provide a valid phy recovery command [EN/DS]");
+        }
+        else if (_userInput._phyRecovery == "EN")
+        {
+            if (_userInput._phyRecoveryType == "")
+            {
+                throw MlxRegException("recovery_type flag should be provided for phy_recovery EN command");
+            }
+            else if (_userInput._phyRecoveryType != "host_serdes_feq" &&
+                     _userInput._phyRecoveryType != "host_logic_re_lock")
+            {
+                throw MlxRegException("Invalid Recovery Type!");
+            }
+            if (_userInput._wdTimerSpecified && _userInput._wdTimer <= 0)
+            {
+                throw MlxRegException("wd_timer flag must be greater than 0");
+            }
+        }
+        else if (_userInput._phyRecovery == "DS")
+        {
+            if (_userInput._phyRecoveryType == "")
+            {
+                throw MlxRegException("recovery_type flag should be provided for PHY Recovery DS command");
+            }
+            else if (_userInput._phyRecoveryType != "host_serdes_feq" &&
+                     _userInput._phyRecoveryType != "host_logic_re_lock")
+            {
+                throw MlxRegException("Invalid PHY Recovery Type!");
+            }
+            if (_userInput._wdTimerSpecified)
+            {
+                throw MlxRegException("WD Timer flag should not be provided for PHY Recovery DS command");
+            }
+        }
+    }
+    else if (phyRecoveryFlags)
+    {
+        throw MlxRegException("PHY Recovery flag should be provided!");
+    }
+}
+
+void MlxlinkUi::validateLinkTrainingParams()
+{
+    if (isIn(SEND_LINK_TRAINING, _sendRegFuncMap))
+    {
+        if (!checkLinkTrainingCmd(_userInput._linkTraining))
+        {
+            throw MlxRegException("Please provide a valid link training command [EN/DS/EN_EXT]");
+        }
+    }
+    else if (!_userInput._linkTraining.empty())
+    {
+        throw MlxRegException("Link Training flag should be provided!");
+    }
+}
+
+void MlxlinkUi::validatePeriodicEqParams()
+{
+    if (_userInput._periodicEqIntervalSpecified)
+    {
+        if (_userInput._setPeriodicEqInterval < 0 || _userInput._setPeriodicEqInterval > 40000)
+        {
+            throw MlxRegException("Periodic EQ interval should be in range [0-40000]");
+        }
+        if (_userInput._setPeriodicEqInterval % 10 != 0)
+        {
+            throw MlxRegException("Periodic EQ interval should be a multiple of 10");
+        }
+    }
+}
+
 void MlxlinkUi::validateModulePRBSParams()
 {
     if (!_userInput.isPrbsSelProvided &&
@@ -838,6 +965,15 @@ void MlxlinkUi::validatePortInfoParams()
     }
 }
 
+void MlxlinkUi::validateMultiPortInfoParams()
+{
+    if ((_userInput._showMultiPortInfo || _userInput._showMultiPortModuleInfo) && _userInput._portSpecified)
+    {
+        throw MlxRegException("When using " MULTI_PORT_INFO_FLAG " or " MULTI_PORT_MODULE_INFO_FLAG " flags, "
+                              "the port flag must not be specified!");
+    }
+}
+
 void MlxlinkUi::strToInt32(char* str, u_int32_t& value)
 {
     char* endp;
@@ -946,6 +1082,9 @@ void MlxlinkUi::paramValidate()
     validatePCIeParams();
     validateGeneralCmdsParams();
     validatePRBSParams();
+    validatePhyRecoveryParams();
+    validateLinkTrainingParams();
+    validatePeriodicEqParams();
     validateSpeedAndCSVBerParams();
     validateCableParams();
     validateModulePRBSParams();
@@ -974,9 +1113,21 @@ void MlxlinkUi::initCmdParser()
     AddOptions(BER_MONITOR_INFO_FLAG, BER_MONITOR_INFO_FLAG_SHORT, "", "Show BER Monitor Info");
     AddOptions(PEPC_SHOW_FLAG, PEPC_SHOW_FLAG_SHORT, "", "Show External PHY Info");
     AddOptions(PRINT_JSON_OUTPUT_FLAG, PRINT_JSON_OUTPUT_FLAG_SHORT, "", "Print the output in json format");
+    AddOptions(MULTI_PORT_INFO_FLAG, MULTI_PORT_INFO_FLAG_SHORT, "", "Show multi ports info table");
+    AddOptions(MULTI_PORT_INFO_ACRONYM_FLAG, MULTI_PORT_INFO_ACRONYM_FLAG_SHORT, "", "Show multi port info table");
+    AddOptions(MULTI_PORT_MODULE_INFO_FLAG, MULTI_PORT_MODULE_INFO_FLAG_SHORT, "", "Show multi port module info table");
+    AddOptions(MULTI_PORT_MODULE_INFO_ACRONYM_FLAG, MULTI_PORT_MODULE_INFO_ACRONYM_FLAG_SHORT, "",
+               "Show multi port module info table");
+    AddOptions(PLR_INFO_FLAG, PLR_INFO_FLAG_SHORT, "", "Show PLR Info");
+    AddOptions(KR_INFO_FLAG, KR_INFO_FLAG_SHORT, "", "Show KR Info");
+    AddOptions(PERIODIC_EQ_FLAG, PERIODIC_EQ_FLAG_SHORT, "", "Show Link PEQ (Periodic Equalization) Info");
+    AddOptions(RX_RECOVERY_COUNTERS_FLAG, RX_RECOVERY_COUNTERS_FLAG_SHORT, "", "Show Rx Recovery Counters");
+    AddOptions(LINK_TRAINING_FLAG, LINK_TRAINING_FLAG_SHORT, "Mode", "Enable/Disable/Enable_Extra Link Training");
 
+    AddOptions(SET_LINK_PEQ_FLAG, SET_LINK_PEQ_FLAG_SHORT, "PEQ_TIME", "Set Link PEQ (Periodic Equalization)");
     AddOptions(FEC_DATA_FLAG, FEC_DATA_FLAG_SHORT, "", "FEC Data");
     AddOptions(PAOS_FLAG, PAOS_FLAG_SHORT, "PAOS", "Send PAOS");
+    AddOptions(PMAOS_FLAG, PMAOS_FLAG_SHORT, "PMAOS", "Send PMAOS");
     AddOptions(PTYS_FLAG, PTYS_FLAG_SHORT, "PTYS", "Send PTYS");
     AddOptions(PTYS_LINK_MODE_FORCE_FLAG, PTYS_LINK_MODE_FORCE_FLAG_SHORT, "", "Set Link Mode Force");
     AddOptions(PPLM_FLAG, PPLM_FLAG_SHORT, "PPLM", "Send PPLM");
@@ -986,6 +1137,8 @@ void MlxlinkUi::initCmdParser()
     AddOptions(AMBER_COLLECT_FLAG, AMBER_COLLECT_FLAG_SHORT, "AMBERCollectFile", "AMBER Collection csv file");
     AddOptions(BER_LIMIT_FLAG, BER_LIMIT_FLAG_SHORT, "Mode", "Test Mode of Ber Collect (Nominal/Corner/Drift)");
     AddOptions(ITERATION_FLAG, ITERATION_FLAG_SHORT, "Iteration", "Iteration of BER Collect");
+    AddOptions(PHY_RECOVERY_FLAG, PHY_RECOVERY_FLAG_SHORT, "Recovery", "Enable/Disable PHY Recovery");
+    AddOptions(PHY_RECOVERY_TYPE_FLAG, PHY_RECOVERY_TYPE_FLAG_SHORT, "Recovery_Type", "Recovery Type");
     AddOptions(PRBS_MODE_FLAG, PRBS_MODE_FLAG_SHORT, "PRBS", "Enable/Disable PRBS Test Mode");
     AddOptions(PPRT_PRBS_FLAG, PPRT_PRBS_FLAG_SHORT, "PPRT", "PPRT Mode");
     AddOptions(PPTT_PRBS_FLAG, PPTT_PRBS_FLAG_SHORT, "PPTT", "PPTT Mode");
@@ -994,6 +1147,7 @@ void MlxlinkUi::initCmdParser()
     AddOptions(PRBS_LANES_FLAG, PRBS_LANES_FLAG_SHORT, "lanes", "PRBS lanes to set");
     AddOptions(PRBS_INVERT_TX_POL_FLAG, PRBS_INVERT_TX_POL_FLAG_SHORT, "", "PRBS TX polarity inversion");
     AddOptions(PRBS_INVERT_RX_POL_FLAG, PRBS_INVERT_RX_POL_FLAG_SHORT, "", "PRBS RX polarity inversion");
+    AddOptions(PRBS_DC_COUPLE_ALLOW_FLAG, PRBS_DC_COUPLE_ALLOW_FLAG_SHORT, "", "Allow PRBS for DC coupled ports");
 
     AddOptions(CABLE_FLAG, CABLE_FLAG_SHORT, "", "Cable operations");
     AddOptions(CABLE_DUMP_FLAG, CABLE_DUMP_FLAG_SHORT, "", "Dump cable EEPROM pages");
@@ -1061,6 +1215,7 @@ void MlxlinkUi::initCmdParser()
     AddOptions(PPHCR_FEC_HIST_FLAG, PPHCR_FEC_HIST_FLAG_SHORT, "", "Provide histogram of FEC errors");
     AddOptions(PPHCR_SHOW_FEC_HIST_FLAG, PPHCR_SHOW_FEC_HIST_FLAG_SHORT, "", "Show FEC errors histograms");
     AddOptions(PPHCR_CLEAR_HISTOGRAM_FLAG, PPHCR_CLEAR_HISTOGRAM_FLAG_SHORT, "", "Clears FEC errors histograms");
+    AddOptions(PLANE_FLAG, PLANE_FLAG_SHORT, "plane", "plane index");
 
     _cmdParser.AddRequester(this);
 }
@@ -1113,6 +1268,9 @@ void MlxlinkUi::commandsCaller()
             case SEND_PAOS:
                 _mlxlinkCommander->sendPaos();
                 break;
+            case SEND_PMAOS:
+                _mlxlinkCommander->sendPmaos();
+                break;
             case SEND_PTYS:
                 _mlxlinkCommander->sendPtys();
                 break;
@@ -1122,6 +1280,12 @@ void MlxlinkUi::commandsCaller()
             case SEND_PPLR:
                 _mlxlinkCommander->sendPplr();
                 break;
+            case SEND_PHY_RECOVERY:
+                _mlxlinkCommander->handlePhyRecovery();
+                break;
+            case SEND_LINK_TRAINING:
+                _mlxlinkCommander->handleLinkTraining();
+                break;
             case SEND_PRBS:
                 _mlxlinkCommander->handlePrbs();
                 break;
@@ -1170,6 +1334,27 @@ void MlxlinkUi::commandsCaller()
             case PCIE_ERROR_INJ:
                 _mlxlinkCommander->handlePCIeErrInj();
                 break;
+            case SHOW_MULTI_PORT_INFO:
+                _mlxlinkCommander->showMultiPortInfo();
+                break;
+            case SHOW_MULTI_PORT_MODULE_INFO:
+                _mlxlinkCommander->showMultiPortModuleInfo();
+                break;
+            case SHOW_PLR:
+                _mlxlinkCommander->showPlr();
+                break;
+            case SHOW_KR:
+                _mlxlinkCommander->showKr();
+                break;
+            case SHOW_RX_RECOVERY_COUNTERS:
+                _mlxlinkCommander->showRxRecoveryCounters();
+                break;
+            case SHOW_PERIODIC_EQ:
+                _mlxlinkCommander->showPeriodicEq();
+                break;
+            case SET_PERIODIC_EQ:
+                _mlxlinkCommander->setPeriodicEq();
+                break;
             default:
                 break;
         }
@@ -1194,6 +1379,12 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         MlxlinkRecord::stdOut = stderr;
         return PARSE_OK;
     }
+    else if (name == PLANE_FLAG)
+    {
+        checkStrLength(value);
+        RegAccessParser::strToUint32((char*)value.c_str(), (u_int32_t&)(_userInput.planeIndex));
+        return PARSE_OK;
+    }
     else if (name == HELP_FLAG)
     {
         printHelp();
@@ -1212,6 +1403,7 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
     else if (name == MODULE_INFO_FLAG)
     {
         addCmd(SHOW_MODULE);
+        _userInput._showModule = true;
         _userInput._networkCmds++;
         return PARSE_OK;
     }
@@ -1233,6 +1425,38 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         _userInput._showEyeInfo = true;
         return PARSE_OK;
     }
+    else if (name == PLR_INFO_FLAG)
+    {
+        addCmd(SHOW_PLR);
+        _userInput._showPlr = true;
+        return PARSE_OK;
+    }
+    else if (name == KR_INFO_FLAG)
+    {
+        addCmd(SHOW_KR);
+        _userInput._showKr = true;
+        return PARSE_OK;
+    }
+    else if (name == RX_RECOVERY_COUNTERS_FLAG)
+    {
+        addCmd(SHOW_RX_RECOVERY_COUNTERS);
+        _userInput._showRxRecoveryCounters = true;
+        return PARSE_OK;
+    }
+    else if (name == PERIODIC_EQ_FLAG)
+    {
+        addCmd(SHOW_PERIODIC_EQ);
+        _userInput._showPeriodicEq = true;
+        return PARSE_OK;
+    }
+    else if (name == SET_LINK_PEQ_FLAG)
+    {
+        addCmd(SET_PERIODIC_EQ);
+        _userInput._periodicEqIntervalSpecified = true;
+        _userInput._setPeriodicEqInterval = stoi(value, nullptr, 0);
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
     else if (name == SLTP_SHOW_FLAG)
     {
         addCmd(SHOW_SLTP);
@@ -1325,6 +1549,13 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         _userInput._uniqueCmds++;
         return PARSE_OK;
     }
+    else if (name == PMAOS_FLAG)
+    {
+        addCmd(SEND_PMAOS);
+        _userInput._pmaosCmd = toUpperCase(value);
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
     else if (name == PTYS_FLAG)
     {
         addCmd(SEND_PTYS);
@@ -1351,6 +1582,25 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         _userInput._uniqueCmds++;
         return PARSE_OK;
     }
+    else if (name == PHY_RECOVERY_FLAG)
+    {
+        addCmd(SEND_PHY_RECOVERY);
+        _userInput._phyRecovery = toUpperCase(value);
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
+    else if (name == PHY_RECOVERY_TYPE_FLAG)
+    {
+        _userInput._phyRecoveryType = value;
+        return PARSE_OK;
+    }
+    else if (name == LINK_TRAINING_FLAG)
+    {
+        addCmd(SEND_LINK_TRAINING);
+        _userInput._linkTraining = toUpperCase(value);
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
     else if (name == PRBS_MODE_FLAG)
     {
         addCmd(SEND_PRBS);
@@ -1395,6 +1645,11 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         _userInput._prbsRxInv = true;
         return PARSE_OK;
     }
+    else if (name == PRBS_DC_COUPLE_ALLOW_FLAG)
+    {
+        _userInput._prbsDcCoupledAllow = true;
+        return PARSE_OK;
+    }
     else if (name == BER_COLLECT_FLAG)
     {
         addCmd(SEND_BER_COLLECT);
@@ -1733,6 +1988,20 @@ ParseStatus MlxlinkUi::HandleOption(string name, string value)
         _userInput.dbdf = value;
         return PARSE_OK;
     }
+    else if (name == MULTI_PORT_INFO_ACRONYM_FLAG || name == MULTI_PORT_INFO_FLAG)
+    {
+        addCmd(SHOW_MULTI_PORT_INFO);
+        _userInput._showMultiPortInfo = true;
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
+    else if (name == MULTI_PORT_MODULE_INFO_ACRONYM_FLAG || name == MULTI_PORT_MODULE_INFO_FLAG)
+    {
+        addCmd(SHOW_MULTI_PORT_MODULE_INFO);
+        _userInput._showMultiPortModuleInfo = true;
+        _userInput._uniqueCmds++;
+        return PARSE_OK;
+    }
     return PARSE_ERROR;
 }
 
@@ -1753,6 +2022,12 @@ int MlxlinkUi::run(int argc, char** argv)
         throw MlxRegException("failed to parse arguments. " + string(_cmdParser.GetErrDesc()));
     }
 
+    if (_userInput._forceSplit && !_userInput._secondSplitProvided)
+    {
+        _userInput._secondSplitProvided = _userInput._forceSplit;
+        _userInput._secondSplitPort = _userInput._forceSplitValue;
+    }
+
     paramValidate();
 
     _mf = mopen(_userInput._device.c_str());
