@@ -66,6 +66,10 @@ protected:
     virtual void validateGradeScanParams();
     virtual void validateErrInjParams();
     virtual void validatePortInfoParams();
+    virtual void validatePhyRecoveryParams();
+    virtual void validateLinkTrainingParams();
+    virtual void validatePeriodicEqParams();
+    virtual void validateMultiPortInfoParams();
     virtual void paramValidate();
     virtual void createMlxlinkCommander();
     virtual void initRegAccessLib();
