@@ -42,6 +42,7 @@ UserInput::UserInput()
     _labelPort = 1;
     _splitPort = 1;
     _secondSplitPort = 1;
+    _forceSplitValue = -1;
     _depth = 0;
     _pcieIndex = 0;
     _node = 0;
@@ -51,12 +52,15 @@ UserInput::UserInput()
     _networkCmds = 0;
     _uniqueCableCmds = 0;
     _uniquePcieCmds = 0;
+    _pciSltpPort = -1;
+    _showModule = false;
     _sendPrbs = false;
     _sendPprt = false;
     _sendPptt = false;
     _sendPepc = false;
     _prbsTxInv = false;
     _prbsRxInv = false;
+    _prbsDcCoupledAllow = false;
     _sendPepcForceMode = false;
     _sendPepcANMode = false;
     _pprtTuningTypeFlag = false;
@@ -79,17 +83,24 @@ UserInput::UserInput()
     _portSpecified = false;
     _splitProvided = false;
     _secondSplitProvided = false;
+    _forceSplit = false;
     _cable = false;
     _dump = false;
     _ddm = false;
     _write = false;
     _read = false;
+    _showMultiPortInfo = false;
+    _showMultiPortModuleInfo = false;
+    _showPlr = false;
+    _showKr = false;
+    _showRxRecoveryCounters = false;
 
     _device = "";
     _extAdbFile = "";
     _logFile = "";
     _portType = "NETWORK";
     _paosCmd = "";
+    _pmaosCmd = "";
     _pplmFec = "";
     _speedFec = "";
     _pplrLB = "";
@@ -114,6 +125,14 @@ UserInput::UserInput()
     _setGroup = -1;
     _showGroup = -1;
     _slrgTestIterations = -1;
+    _linkTraining = "";
+    _phyRecovery = "";
+    _phyRecoveryType = "";
+    _showPeriodicEq = false;
+    _periodicEqIntervalSpecified = false;
+    _setPeriodicEqInterval = -1; // 10uS granularity
+    _wdTimer = 10;               // 10msec intervals, default WD timer value is 100msec (10 * 10msec)
+    _wdTimerSpecified = false;
 
     autoCsvName = false;
     eyeSelect = "";
