@@ -52,6 +52,7 @@ public:
     u_int32_t _labelPort;
     u_int32_t _splitPort;
     u_int32_t _secondSplitPort;
+    u_int32_t _forceSplitValue;
     u_int32_t _depth;
     u_int32_t _pcieIndex;
     u_int32_t _node;
@@ -59,11 +60,14 @@ public:
     u_int32_t _uniqueCableCmds;
     u_int32_t _uniquePcieCmds;
     u_int32_t _networkCmds;
+    int _pciSltpPort;
+    bool _showModule;
     bool _sendPrbs;
     bool _sendPprt;
     bool _sendPptt;
     bool _prbsTxInv;
     bool _prbsRxInv;
+    bool _prbsDcCoupledAllow;
     bool _sendPepc;
     bool _sendPepcForceMode;
     bool _sendPepcANMode;
@@ -83,6 +87,7 @@ public:
     bool _portSpecified;
     bool _splitProvided;
     bool _secondSplitProvided;
+    bool _forceSplit;
     bool _showSltp;
     bool _showSlrp;
     bool _showCounters;
@@ -94,11 +99,17 @@ public:
     bool _read;
     bool gradeScanPerLane;
     bool autoCsvName;
+    bool _showMultiPortInfo;
+    bool _showMultiPortModuleInfo;
+    bool _showPlr;
+    bool _showKr;
+    bool _showRxRecoveryCounters;
 
     string _device;
     string _extAdbFile;
     string _portType;
     string _paosCmd;
+    string _pmaosCmd;
     string _pplmFec;
     string _speedFec;
     string _pplrLB;
@@ -113,6 +124,14 @@ public:
     string _forceMode;
     string _anMode;
     string _logFile;
+    string _linkTraining;
+    string _phyRecovery;
+    string _phyRecoveryType;
+    bool _showPeriodicEq;
+    bool _periodicEqIntervalSpecified;
+    int _setPeriodicEqInterval;
+    int _wdTimer;
+    bool _wdTimerSpecified;
     double _testTime;
     u_int32_t _feedbackIndex;
     u_int32_t _feedbackData;
