@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * Copyright (c) 2013-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -83,15 +83,20 @@ string getAnDisableColor(u_int32_t anDisable);
 string IBSupportedSpeeds2Str(u_int32_t mask);
 string EthSupportedSpeeds2Str(u_int32_t int_mask);
 string EthExtSupportedSpeeds2Str(u_int32_t int_mask);
-string SupportedSpeeds2Str(u_int32_t proto_active, u_int32_t mask, bool extended = false);
+string SupportedSpeeds2Str(u_int32_t proto_active, u_int32_t mask, bool extended = false, bool isXdrSlowActive = false);
 string getOui(u_int32_t oui);
 int getBitvalue(u_int32_t mask, int idx);
+string getMaxPowerStr(u_int32_t maxPower);
+string getPowerClassStringValue(u_int32_t cableIdentifier, u_int32_t powerClass, MlxlinkMaps* mlxlinkMaps);
+float getPowerClassValue(u_int32_t cableIdentifier, u_int32_t powerClass, MlxlinkMaps* mlxlinkMaps);
+string getPowerClassStr(MlxlinkMaps* mlxlinkMaps, u_int32_t cableIdentifier, u_int32_t powerClass);
 string getPowerClass(MlxlinkMaps* mlxlinkMaps, u_int32_t cableIdentifier, u_int32_t powerClass, u_int32_t maxPower);
 int ptysSpeedToExtMaskETH(const string& speed);
 int ptysSpeedToMaskETH(const string& speed);
 int ptysSpeedToMaskIB(const string& speed);
 bool isPAM4Speed(u_int32_t speedMask, u_int32_t protoActive, bool extended = false);
 bool checkPaosCmd(const string& paosCmd);
+bool checkPmaosCmd(const string& pmaosCmd);
 bool checkPepcForceMode(const string& forceMode);
 bool checkPepcANMode(const string& anMode);
 bool checkPplmCmd(const string& pplmCmd);
@@ -100,9 +105,12 @@ u_int32_t prbsMaskToRateNum(u_int32_t mask);
 string prbsMaskToLockStatus(u_int32_t mask, u_int32_t numOfLanesToUse);
 bool checkPrbsCmd(const string& prbsCmd);
 bool checkTestMode(const string& testMode);
+bool checkPhyRecoveryCmd(const string& phyRecoveryCmd);
+bool checkLinkTrainingCmd(const string& linkTrainingCmd);
 string FEC2Str(const string& fecShort, const string& speedStrG);
 string speedToFecSpeedStr(const string& speed, u_int32_t numOfLanes);
 PAOS_CMD paos_to_int(const string& cmd);
+PMAOS_CMD pmaos_to_int(const string& cmd);
 int pepc_force_mode_to_int(const string& forceMode);
 int pepc_an_mode_to_int(const string& anMode);
 bool endsWith(const std::string& value, const std::string& ending);
@@ -113,7 +121,7 @@ bool isQsfpCable(u_int32_t identifier);
 string getCmisCableType(u_int32_t cableType, u_int32_t cableLength);
 string getCableType(u_int32_t cableType);
 string getTemp(u_int32_t temp, int celsParam = 256);
-float getPower(u_int16_t power, bool isModuleExtSupported = false);
+float getPower(u_int16_t power);
 int getHeight(u_int16_t height);
 int getPhase(u_int8_t phase);
 int getVersion(u_int8_t version);
@@ -156,4 +164,20 @@ string getStrByMaskFromPair(u_int32_t bitmask,
                             map<u_int32_t, pair<string, string>> maskMap,
                             const string& fieldSeparator = ",",
                             u_int32_t pairIndex = 0);
+
+std::string centerString(const std::string& str, int width, char fillChar = ' ');
+std::string generateTableRow(const std::vector<std::pair<std::string, u_int32_t>>& columns,
+                             const std::string& delimiter);
+int getStringLengthWOColorCodes(const std::string& s);
+void printMlxlinkTable(const std::vector<std::string>& tableData,
+                       const std::vector<std::pair<std::string, u_int32_t>>& tableHeader);
+void updateColumnWidthPopulateTable(std::vector<std::pair<std::string, u_int32_t>>& vectorToAmend,
+                                    const u_int32_t locationInVector,
+                                    std::vector<std::string>& tableData,
+                                    const std::string& valToAdd,
+                                    u_int32_t unformattedStrLen,
+                                    bool isActive = true);
+void printProgressBar(int completion, const std::string& preStr, const std::string& endStr);
+std::string string_format(const char* format, ...);
+
 #endif
