@@ -43,7 +43,8 @@
 #include <common/compatibility.h>
 #include <json/json.h>
 
-#define PDDR_LINE_LEN 34
+#define PDDR_LINE_LEN 37
+#define RX_RECOVERY_COUNTERS_LINE_LEN 46
 
 /*
  * Json output objects name
@@ -63,6 +64,10 @@
  */
 #define HEADER_SUPPORTED_INFO "Supported Info"
 #define HEADER_FEC_INFO "FEC Capability Info"
+#define HEADER_PLR_INFO "PLR Info"
+#define HEADER_KR_INFO "KR Info"
+#define HEADER_RX_RECOVERY_COUNTERS "Rx Recovery Counters"
+#define HEADER_PERIODIC_EQ "PEQ info"
 
 #define PRINT_UNDER_TITLE(len)    \
     for (int i = 0; i < len; i++) \
@@ -124,6 +129,10 @@ enum STATUS_DDM_FLAGS_TYPE
 #define LINK_DOWN_BLAME_INFO_LAST 2
 #define MODULE_PMPT_INFO_LAST 8
 #define MODULE_PMPD_INFO_LAST 6
+#define PLR_INFO_LAST 2
+#define KR_INFO_LAST 5
+#define RX_RECOVERY_COUNTERS_LAST 10
+#define PERIODIC_EQ_INFO_LAST 2
 
 class MlxlinkRecord
 {
@@ -139,6 +148,12 @@ public:
     static short unsigned int getWinColor(const std::string& color);
     static void
       printFlagLine(const char sflag_s, const std::string& flag_l, const std::string& param, const std::string& desc);
+    static void printFlagLineWithAcronym(const char flag_s,
+                                         const std::string& flag_l,
+                                         const char flag_acr_s,
+                                         const std::string& flag_acr_l,
+                                         const std::string& param,
+                                         const std::string& desc);
     static std::string addSpace(const std::string& str, u_int32_t size, bool right = true);
     static std::string addSpaceForDDM(const std::string& str);
     static std::string addSpaceForSlrg(const std::string& str);
@@ -156,6 +171,7 @@ public:
     bool visible;
     bool arrayValue;
     bool colorKey;
+    int lineLen;
     static bool jsonFormat;
     static std::ostream* cOut;
     static FILE* stdOut;
