@@ -68,11 +68,6 @@ enum ErrorCode
     MLX_SIGN_RSA_KEY_DIGEST_FINAL_OPENSSL_ERROR,
     MLX_SIGN_RSA_KEY_MEMORY_ALLOC_OPENSSL_ERROR,
     MLX_SIGN_HMAC_ERROR,
-
-    MLX_SIGN_AWS_INIT_ERROR = 0x200,
-    MLX_SIGN_AWS_SIGN_ERROR,
-    MLX_SIGN_AWS_GET_KEY_ERROR
-
 };
 
 } // namespace MlxSign
