@@ -180,7 +180,6 @@ int read_device_id(mfile* mf, u_int32_t* device_id)
         return -1;
     }
 
-    int      rc = 0;
     unsigned hw_id_address = mf->cr_space_offset + HW_ID_ADDR;
 
     mf->rev_id = EXTRACT(*device_id, 16, 4);
@@ -335,12 +334,6 @@ enum {
     SEM_MAX_RETRIES = 0x1000
 };
 
-/* PCI operation enum(read or write)*/
-enum {
-    READ_OP  = 0,
-    WRITE_OP = 1,
-};
-
 int read_config(mfile* mf, unsigned int reg, uint32_t* data, int width)
 {
     struct pci_io pi = {};
@@ -1443,6 +1436,12 @@ int mwrite_i2cblock(mfile       * mf,
     return 0;
 }
 
+int force_i2c_address = -1;
+void set_force_i2c_address(int i2c_address)
+{
+    (void)i2c_address;
+}
+
 /* TODO: Introduce a module to keep platform-independent routines like this one below */
 void mtcr_fix_endianness(u_int32_t* buf, int len)
 {
@@ -1492,23 +1491,23 @@ int mget_mdevs_type(mfile* mf, u_int32_t* mtype)
     return 0;
 }
 
-unsigned char mset_i2c_slave(mfile* mf, unsigned char new_i2c_slave)
+unsigned char mset_i2c_secondary(mfile* mf, unsigned char new_i2c_slave)
 {
     unsigned char ret;
 
     if (mf) {
-        ret = mf->i2c_slave;
-        mf->i2c_slave = new_i2c_slave;
+        ret = mf->i2c_secondary;
+        mf->i2c_secondary = new_i2c_slave;
     } else {
         ret = 0xff;
     }
     return ret;
 }
 
-int mget_i2c_slave(mfile* mf, unsigned char* new_i2c_slave_p)
+int mget_i2c_secondary(mfile* mf, unsigned char* new_i2c_slave_p)
 {
     if (mf) {
-        *new_i2c_slave_p = mf->i2c_slave;
+        *new_i2c_slave_p = mf->i2c_secondary;
         return 0;
     }
     return -1;
@@ -2475,185 +2474,6 @@ int mget_max_reg_size(mfile* mf, maccess_reg_method_t reg_method)
     return mf->acc_reg_params.max_reg_size[reg_method];
 }
 
-/************************************
-* Function: m_err2str
-************************************/
-const char* m_err2str(MError status)
-{
-    switch (status) {
-    case ME_OK:
-        return "ME_OK";
-
-    case ME_ERROR:
-        return "General error";
-
-    case ME_BAD_PARAMS:
-        return "ME_BAD_PARAMS";
-
-    case ME_CR_ERROR:
-        return "ME_CR_ERROR";
-
-    case ME_NOT_IMPLEMENTED:
-        return "ME_NOT_IMPLEMENTED";
-
-    case ME_SEM_LOCKED:
-        return "Semaphore locked";
-
-    case ME_MEM_ERROR:
-        return "ME_MEM_ERROR";
-
-    case ME_UNSUPPORTED_OPERATION:
-        return "ME_UNSUPPORTED_OPERATION";
-
-    case ME_MAD_SEND_FAILED:
-        return "ME_MAD_SEND_FAILED";
-
-    case ME_UNKOWN_ACCESS_TYPE:
-        return "ME_UNKOWN_ACCESS_TYPE";
-
-    case ME_UNSUPPORTED_ACCESS_TYPE:
-        return "ME_UNSUPPORTED_ACCESS_TYPE";
-
-    case ME_UNSUPPORTED_DEVICE:
-        return "ME_UNSUPPORTED_DEVICE";
-
-    /* Reg access errors */
-    case ME_REG_ACCESS_BAD_STATUS_ERR:
-        return "ME_REG_ACCESS_BAD_STATUS_ERR";
-
-    case ME_REG_ACCESS_BAD_METHOD:
-        return "Bad method";
-
-    case ME_REG_ACCESS_NOT_SUPPORTED:
-        return "The Register access is not supported by the device";
-
-    case ME_REG_ACCESS_DEV_BUSY:
-        return "Device is busy";
-
-    case ME_REG_ACCESS_VER_NOT_SUPP:
-        return "Version not supported";
-
-    case ME_REG_ACCESS_UNKNOWN_TLV:
-        return "Unknown TLV";
-
-    case ME_REG_ACCESS_REG_NOT_SUPP:
-        return "Register not supported";
-
-    case ME_REG_ACCESS_CLASS_NOT_SUPP:
-        return "Class not supported";
-
-    case ME_REG_ACCESS_METHOD_NOT_SUPP:
-        return "Method not supported";
-
-    case ME_REG_ACCESS_BAD_PARAM:
-        return "Bad parameter";
-
-    case ME_REG_ACCESS_RES_NOT_AVLBL:
-        return "Resource unavailable";
-
-    case ME_REG_ACCESS_MSG_RECPT_ACK:
-        return "Message receipt ack";
-
-    case ME_REG_ACCESS_UNKNOWN_ERR:
-        return "Unknown register error";
-
-    case ME_REG_ACCESS_SIZE_EXCEEDS_LIMIT:
-        return "Register is too large";
-
-    case ME_REG_ACCESS_CONF_CORRUPT:
-        return "Config Section Corrupted";
-
-    case ME_REG_ACCESS_LEN_TOO_SMALL:
-        return "The given Register length is too small for the Tlv";
-
-    case ME_REG_ACCESS_BAD_CONFIG:
-        return "The configuration is rejected";
-
-    case ME_REG_ACCESS_ERASE_EXCEEDED:
-        return "The erase count exceeds its limit";
-
-    case ME_REG_ACCESS_INTERNAL_ERROR:
-        return "Firmware internal error";
-
-    case ME_REG_ACCESS_NOT_SUPPORTED_BY_SECONDARY:
-        return "Not supported by secondary";
-
-    /* ICMD access errors */
-    case ME_ICMD_STATUS_CR_FAIL:
-        return "ME_ICMD_STATUS_CR_FAIL";
-
-    case ME_ICMD_STATUS_SEMAPHORE_TO:
-        return "ME_ICMD_STATUS_SEMAPHORE_TO";
-
-    case ME_ICMD_STATUS_EXECUTE_TO:
-        return "ME_ICMD_STATUS_EXECUTE_TO";
-
-    case ME_ICMD_STATUS_IFC_BUSY:
-        return "ME_ICMD_STATUS_IFC_BUSY";
-
-    case ME_ICMD_STATUS_ICMD_NOT_READY:
-        return "ME_ICMD_STATUS_ICMD_NOT_READY";
-
-    case ME_ICMD_UNSUPPORTED_ICMD_VERSION:
-        return "ME_ICMD_UNSUPPORTED_ICMD_VERSION";
-
-    case ME_ICMD_NOT_SUPPORTED:
-        return "ME_REG_ACCESS_ICMD_NOT_SUPPORTED";
-
-    case ME_ICMD_INVALID_OPCODE:
-        return "ME_ICMD_INVALID_OPCODE";
-
-    case ME_ICMD_INVALID_CMD:
-        return "ME_ICMD_INVALID_CMD";
-
-    case ME_ICMD_OPERATIONAL_ERROR:
-        return "ME_ICMD_OPERATIONAL_ERROR";
-
-    case ME_ICMD_BAD_PARAM:
-        return "ME_ICMD_BAD_PARAM";
-
-    case ME_ICMD_BUSY:
-        return "ME_ICMD_BUSY";
-
-    case ME_ICMD_ICM_NOT_AVAIL:
-        return "ME_ICMD_ICM_NOT_AVAIL";
-
-    case ME_ICMD_WRITE_PROTECT:
-        return "ME_ICMD_WRITE_PROTECT";
-
-    case ME_ICMD_UNKNOWN_STATUS:
-        return "ME_ICMD_UNKNOWN_STATUS";
-
-    case ME_ICMD_SIZE_EXCEEDS_LIMIT:
-        return "ME_ICMD_SIZE_EXCEEDS_LIMIT";
-
-    /* MAD IFC errors */
-    case ME_MAD_BUSY:
-        return "Temporarily busy. MAD discarded. This is not an error";
-
-    case ME_MAD_REDIRECT:
-        return "Redirection. This is not an error";
-
-    case ME_MAD_BAD_VER:
-        return "Bad version";
-
-    case ME_MAD_METHOD_NOT_SUPP:
-        return "Method not supported";
-
-    case ME_MAD_METHOD_ATTR_COMB_NOT_SUPP:
-        return "Method and attribute combination isn't supported";
-
-    case ME_MAD_BAD_DATA:
-        return "Bad attribute modifer or field";
-
-    case ME_MAD_GENERAL_ERR:
-        return "Unknown MAD error";
-
-    default:
-        return "Unknown error code";
-    }
-}
-
 void mpci_change(mfile* mf)
 {
     (void)mf;
@@ -2687,8 +2507,11 @@ int mset_cr_access(mfile* mf, int access)
     return -1;
 }
 
-int mget_vsec_supp(mfile* mf)
+int is_gw_access(mfile* mf)
 {
+    if (mf->tp == MST_BAR0_GW_PCI) {
+        return 1;
+    }
     return mf->functional_vsec_supp;
 }
 
@@ -3147,9 +2970,10 @@ int is_zombiefish_device(mfile* mf)
     if (read_device_id(mf, &dev_id) != 4) {
         return 0;
     }
-    if ((mf->device_hw_id != DeviceConnectX8_HwId) && (mf->device_hw_id != DeviceQuantum3_HwId) &&
-        (mf->device_hw_id != DeviceConnectX9_HwId) && (mf->device_hw_id != DeviceQuantum4_HwId) &&
-        (mf->device_hw_id != DeviceConnectX7_HwId) && (mf->device_hw_id != DeviceBlueField3_HwId)) {
+    if ((mf->device_hw_id != DeviceConnectX8_HwId) && (mf->device_hw_id != DeviceConnectX8PurePcieSwitch_HwId) &&
+        (mf->device_hw_id != DeviceQuantum3_HwId) && (mf->device_hw_id != DeviceConnectX9_HwId) &&
+        (mf->device_hw_id != DeviceQuantum4_HwId) && (mf->device_hw_id != DeviceConnectX7_HwId) &&
+        (mf->device_hw_id != DeviceBlueField3_HwId)) {
         return 0;
     }
 
