@@ -1,6 +1,6 @@
 
 /*
- * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2013-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -38,33 +38,34 @@
 #include <errno.h>
 
 #define CMTCR_UNUSED(var) ((void)(var))
-static PyObject *mtcrModule = 0;
-static PyObject *mtcrExceptionType = 0;
+static PyObject* mtcrModule = 0;
+static PyObject* mtcrExceptionType = 0;
 
 /**********************************************
  * mtcr_init
  * @return
  *********************************************/
-PyObject* mtcr_init(PyObject *self, PyObject *args)
+PyObject* mtcr_init(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
-    const char *dev;
-    mfile *mf;
-
+    PyObject* mfileObj;
+    const char* dev;
+    mfile* mf;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev)) {
+    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev))
+    {
         return NULL;
     }
 
     mf = mopen(dev);
-    if (!mf) {
+    if (!mf)
+    {
         PyErr_SetString(mtcrExceptionType, strerror(errno));
         return NULL;
     }
 
-    PyObject *mfLong = PyLong_FromVoidPtr(mf);
+    PyObject* mfLong = PyLong_FromVoidPtr(mf);
     PyObject_SetAttrString(mfileObj, "mf", mfLong);
     Py_DecRef(mfLong);
 
@@ -74,21 +75,23 @@ PyObject* mtcr_init(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_close
  *********************************************/
-PyObject* mtcr_close(PyObject *self, PyObject *args)
+PyObject* mtcr_close(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
-    const char *dev;
-    mfile *mf;
+    PyObject* mfileObj;
+    const char* dev;
+    mfile* mf;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev)) {
+    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev))
+    {
         return NULL;
     }
 
-    PyObject *mfLong = PyObject_GetAttrString(mfileObj, "mf");
-    mf = (mfile*) PyLong_AsVoidPtr(mfLong);
-    if (mf) {
+    PyObject* mfLong = PyObject_GetAttrString(mfileObj, "mf");
+    mf = (mfile*)PyLong_AsVoidPtr(mfLong);
+    if (mf)
+    {
         mclose(mf);
     }
     Py_DecRef(mfLong);
@@ -99,19 +102,20 @@ PyObject* mtcr_close(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_del
  *********************************************/
-PyObject* mtcr_del(PyObject *self, PyObject *args)
+PyObject* mtcr_del(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
-    const char *dev;
+    PyObject* mfileObj;
+    const char* dev;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev)) {
+    if (!PyArg_ParseTuple(args, "Os", &mfileObj, &dev))
+    {
         return NULL;
     }
 
     mtcr_close(self, args);
-    PyObject *mfLong = PyLong_FromLong(0);
+    PyObject* mfLong = PyLong_FromLong(0);
     PyObject_SetAttrString(mfLong, "mf", mfLong);
     Py_DecRef(mfLong);
 
@@ -121,25 +125,27 @@ PyObject* mtcr_del(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_read4
  *********************************************/
-PyObject* mtcr_read4(PyObject *self, PyObject *args)
+PyObject* mtcr_read4(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
+    PyObject* mfileObj;
     int addr;
-    mfile *mf;
+    mfile* mf;
     u_int32_t value;
-    PyObject *valueObj;
+    PyObject* valueObj;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Oi", &mfileObj, &addr)) {
+    if (!PyArg_ParseTuple(args, "Oi", &mfileObj, &addr))
+    {
         return NULL;
     }
 
-    PyObject *mfLong = PyObject_GetAttrString(mfileObj, "mf");
-    mf = (mfile*) PyLong_AsVoidPtr(mfLong);
+    PyObject* mfLong = PyObject_GetAttrString(mfileObj, "mf");
+    mf = (mfile*)PyLong_AsVoidPtr(mfLong);
     Py_DecRef(mfLong);
 
-    if (mread4(mf, addr, &value) != 4) {
+    if (mread4(mf, addr, &value) != 4)
+    {
         PyErr_SetString(mtcrExceptionType, strerror(errno));
         return NULL;
     }
@@ -151,40 +157,44 @@ PyObject* mtcr_read4(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_read4
  *********************************************/
-PyObject* mtcr_read4block(PyObject *self, PyObject *args)
+PyObject* mtcr_read4block(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
+    PyObject* mfileObj;
     int addr;
     int i;
-    mfile *mf;
+    mfile* mf;
     int dword_len;
-    PyObject *data_list;
-    u_int32_t *data_buf;
-    PyObject *mfLong;
+    PyObject* data_list;
+    u_int32_t* data_buf;
+    PyObject* mfLong;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Oii", &mfileObj, &addr, &dword_len)) {
+    if (!PyArg_ParseTuple(args, "Oii", &mfileObj, &addr, &dword_len))
+    {
         return NULL;
     }
 
     mfLong = PyObject_GetAttrString(mfileObj, "mf");
-    mf = (mfile*) PyLong_AsVoidPtr(mfLong);
+    mf = (mfile*)PyLong_AsVoidPtr(mfLong);
     Py_DecRef(mfLong);
 
     data_buf = malloc(sizeof(u_int32_t) * dword_len);
-    if (!data_buf) {
+    if (!data_buf)
+    {
         PyErr_SetString(mtcrExceptionType, "Out read of memory");
         return NULL;
     }
 
-    if (mread4_block(mf, addr, data_buf, dword_len * 4) != (dword_len * 4)) {
+    if (mread4_block(mf, addr, data_buf, dword_len * 4) != (dword_len * 4))
+    {
         PyErr_SetString(mtcrExceptionType, strerror(errno));
         return NULL;
     }
 
     data_list = PyList_New(dword_len);
-    for (i = 0; i < dword_len; i++) {
+    for (i = 0; i < dword_len; i++)
+    {
         PyList_SET_ITEM(data_list, i, PyInt_FromLong((long)data_buf[i]));
     }
 
@@ -194,24 +204,26 @@ PyObject* mtcr_read4block(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_write4
  *********************************************/
-PyObject* mtcr_write4(PyObject *self, PyObject *args)
+PyObject* mtcr_write4(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
+    PyObject* mfileObj;
     int addr;
-    mfile *mf;
+    mfile* mf;
     u_int32_t value;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "Oii", &mfileObj, &addr, &value)) {
+    if (!PyArg_ParseTuple(args, "Oii", &mfileObj, &addr, &value))
+    {
         return NULL;
     }
 
-    PyObject *mfLong = PyObject_GetAttrString(mfileObj, "mf");
-    mf = (mfile*) PyLong_AsVoidPtr(mfLong);
+    PyObject* mfLong = PyObject_GetAttrString(mfileObj, "mf");
+    mf = (mfile*)PyLong_AsVoidPtr(mfLong);
     Py_DecRef(mfLong);
 
-    if (mwrite4(mf, addr, value) != 4) {
+    if (mwrite4(mf, addr, value) != 4)
+    {
         PyErr_SetString(mtcrExceptionType, strerror(errno));
         return NULL;
     }
@@ -222,39 +234,43 @@ PyObject* mtcr_write4(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_write4block
  *********************************************/
-PyObject* mtcr_write4block(PyObject *self, PyObject *args)
+PyObject* mtcr_write4block(PyObject* self, PyObject* args)
 {
-    PyObject *mfileObj;
+    PyObject* mfileObj;
     int addr;
     int i;
-    mfile *mf;
+    mfile* mf;
     int dword_len;
-    PyObject *data_list;
-    u_int32_t *data_buf;
-    PyObject *mfLong;
+    PyObject* data_list;
+    u_int32_t* data_buf;
+    PyObject* mfLong;
 
     CMTCR_UNUSED(self);
     // Parse args
-    if (!PyArg_ParseTuple(args, "OiO", &mfileObj, &addr, &data_list)) {
+    if (!PyArg_ParseTuple(args, "OiO", &mfileObj, &addr, &data_list))
+    {
         return NULL;
     }
 
     mfLong = PyObject_GetAttrString(mfileObj, "mf");
-    mf = (mfile*) PyLong_AsVoidPtr(mfLong);
+    mf = (mfile*)PyLong_AsVoidPtr(mfLong);
     Py_DecRef(mfLong);
 
     dword_len = PyList_Size(data_list);
     data_buf = malloc(sizeof(u_int32_t) * dword_len);
-    if (!data_buf) {
+    if (!data_buf)
+    {
         PyErr_SetString(mtcrExceptionType, "Write Out of memory");
         return NULL;
     }
 
-    for (i = 0; i < dword_len; i++) {
+    for (i = 0; i < dword_len; i++)
+    {
         data_buf[i] = PyLong_AsUnsignedLong(PyList_GET_ITEM(data_list, i));
     }
 
-    if (mwrite4_block(mf, addr, data_buf, dword_len * 4) != (dword_len * 4)) {
+    if (mwrite4_block(mf, addr, data_buf, dword_len * 4) != (dword_len * 4))
+    {
         PyErr_SetString(mtcrExceptionType, strerror(errno));
         return NULL;
     }
@@ -265,14 +281,15 @@ PyObject* mtcr_write4block(PyObject *self, PyObject *args)
 /**********************************************
  * mtcr_funcs static db
  *********************************************/
-static PyMethodDef mtcr_funcs [] = { {"mtcr_init", (PyCFunction)mtcr_init, METH_VARARGS,  "Init mfile object"},
-                                     {"mtcr_close", (PyCFunction)mtcr_close, METH_VARARGS, "Close internal mfile"},
-                                     {"mtcr_del", (PyCFunction)mtcr_del, METH_VARARGS, "Free resources"},
-                                     {"mtcr_read4", (PyCFunction)mtcr_read4, METH_VARARGS, "Read dword"},
-                                     {"mtcr_write4", (PyCFunction)mtcr_write4, METH_VARARGS, "Write dword"},
-                                     {"mtcr_read4block", (PyCFunction)mtcr_read4block, METH_VARARGS, "Read block of dwords"},
-                                     {"mtcr_write4block", (PyCFunction)mtcr_write4block, METH_VARARGS, "Write block of dwords"},
-                                     {NULL, NULL, 0, NULL} };
+static PyMethodDef mtcr_funcs[] = {
+  {"mtcr_init", (PyCFunction)mtcr_init, METH_VARARGS, "Init mfile object"},
+  {"mtcr_close", (PyCFunction)mtcr_close, METH_VARARGS, "Close internal mfile"},
+  {"mtcr_del", (PyCFunction)mtcr_del, METH_VARARGS, "Free resources"},
+  {"mtcr_read4", (PyCFunction)mtcr_read4, METH_VARARGS, "Read dword"},
+  {"mtcr_write4", (PyCFunction)mtcr_write4, METH_VARARGS, "Write dword"},
+  {"mtcr_read4block", (PyCFunction)mtcr_read4block, METH_VARARGS, "Read block of dwords"},
+  {"mtcr_write4block", (PyCFunction)mtcr_write4block, METH_VARARGS, "Write block of dwords"},
+  {NULL, NULL, 0, NULL}};
 
 #define STR_EXPAND(tok) #tok
 #define STR(tok) STR_EXPAND(tok)
@@ -287,20 +304,22 @@ static PyMethodDef mtcr_funcs [] = { {"mtcr_init", (PyCFunction)mtcr_init, METH_
  * initcmtcr
  * @return
  *********************************************/
-#ifndef PyMODINIT_FUNC  /* declarations for DLL import/export */
+#ifndef PyMODINIT_FUNC /* declarations for DLL import/export */
 #define PyMODINIT_FUNC void
 #endif
 PyMODINIT_FUNC INIT_FUNC()
 {
     Py_InitModule(MODULE_NAME, mtcr_funcs);
     mtcrModule = PyImport_ImportModule("mtcr");
-    if (!mtcrModule) {
+    if (!mtcrModule)
+    {
         PyErr_SetString(mtcrExceptionType, "Failed to import module");
         return;
     }
 
-    mtcrExceptionType =  PyObject_GetAttrString(mtcrModule, "MtcrException");
-    if (!mtcrExceptionType) {
+    mtcrExceptionType = PyObject_GetAttrString(mtcrModule, "MtcrException");
+    if (!mtcrExceptionType)
+    {
         PyErr_SetString(PyExc_ImportError, "Failed to import MtcrException class");
         return;
     }
