@@ -214,13 +214,6 @@ void get_pci_dev_rdma(mfile* mf, char* buf)
     }
 }
 
-unsigned char mset_i2c_slave(mfile* mf, unsigned char new_i2c_slave)
-{
-    (void)mf;
-    (void)new_i2c_slave; /* compiler warning */
-    fprintf(stderr, "Warning: libmtcr: mset_i2c_slave() is not implemented and has no effect.\n");
-    return 0;
-}
 
 int maccess_reg_mad(mfile* mf, u_int8_t* data)
 {
@@ -279,8 +272,12 @@ int supports_reg_access_gmp(mfile* mf, maccess_reg_method_t reg_method)
     return supports_reg_access_gmp_ul(mf, reg_method);
 }
 
-int mget_vsec_supp(mfile* mf)
+int is_gw_access(mfile* mf)
 {
+    if (mf->tp == MST_BAR0_GW_PCI)
+    {
+        return 1;
+    }
     return mf->functional_vsec_supp;
 }
 
@@ -341,4 +338,4 @@ int mvpd_write4(mfile* mf, unsigned int offset, u_int8_t value[4])
     (void)offset;
     (void)value;
     return ME_UNSUPPORTED_OPERATION;
-}
+}
\ No newline at end of file
