@@ -31,13 +31,13 @@
  *
  */
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
-#if !defined(_MSC_VER)
 #include <unistd.h>
-#endif
+
 #include "common/bit_slice.h"
 #include "common/tools_time.h"
 #include "mtcr_icmd_cif.h"
@@ -54,6 +54,8 @@
 #define ICMD_QUERY_CAP_CMD_ID        0x8400
 #define ICMD_QUERY_CAP_CMD_SZ        0x8
 #define ICMD_QUERY_CAP_EXMB_ICMD_OFF 0x8
+#define SEMAPHORE_62_LOCKED_INDICATOR 0x1
+
 
 /* _DEBUG_MODE   // un-comment this to enable debug prints */
 
@@ -65,6 +67,7 @@
 #define STAT_CFG_NOT_DONE_ADDR_CX5     0xb5e04
 #define STAT_CFG_NOT_DONE_ADDR_CX6     0xb5f04
 #define STAT_CFG_NOT_DONE_ADDR_CX7     0xb5f04
+#define STAT_CFG_NOT_DONE_ADDR_CX8     656132
 #define STAT_CFG_NOT_DONE_ADDR_GPU     0x3100010
 #define STAT_CFG_NOT_DONE_BITOFF_CIB   31
 #define STAT_CFG_NOT_DONE_BITOFF_CX4   31
@@ -80,6 +83,7 @@
 #define SEMAPHORE_ADDR_GB100           0xa52f8
 #define SEMAPHORE_ADDR_CX5             0xe74e0
 #define SEMAPHORE_ADDR_CX7             0xe5660
+#define SEMAPHORE_ADDR_CX8             358016
 #define SEMAPHORE_ADDR_GPU             0x308F4F8
 #define HCR_ADDR_CIB                   0x0
 #define HCR_ADDR_CX4                   HCR_ADDR_CIB
@@ -91,15 +95,18 @@
 #define ICMD_VERSION_BITOFF            24
 #define ICMD_VERSION_BITOFF_GPU        0
 #define ICMD_VERSION_BITLEN            8
+#define ICMD_VERSION_BITLEN_CX8        4
 #define CMD_PTR_ADDR_CIB               0x0
 #define CMD_PTR_ADDR_SW_IB             0x80000
 #define CMD_PTR_ADDR_QUANTUM           0x100000
 #define CMD_PTR_ADDR_CX4               CMD_PTR_ADDR_CIB
 #define CMD_PTR_ADDR_CX5               CMD_PTR_ADDR_CIB
 #define CMD_PTR_ADDR_CX7               CMD_PTR_ADDR_CIB
+#define CMD_PTR_ADDR_CX8               27262976
 #define CMD_PTR_ADDR_GPU               0x3100000
 #define CMD_PTR_BITOFF                 0
 #define CMD_PTR_BITLEN                 24
+#define CMD_PTR_BITLEN_CX8             28
 #define CMD_PTR_BITLEN_GPU             32
 #define CTRL_OFFSET                    0x3fc
 #define BUSY_BITOFF                    0
@@ -260,6 +267,14 @@ int MREAD4_SEMAPHORE(mfile* mf, int offset, u_int32_t* ptr)
         return ME_ICMD_STATUS_CR_FAIL;
     }
     RESTORE_SPACE(mf);
+
+    // When accessing directly to the device configuration space, the semaphore lock is the last bit in the DWORD.
+    // When accessing via VSC GW or BAR0 GW, the semaphore lock is the whole dword.
+    if (!is_gw_access(mf))
+    {
+        *ptr = EXTRACT(*ptr, 31, 1);
+    }
+
     return ME_OK;
 }
 
@@ -284,7 +299,7 @@ enum {
 #define CX6LX_HW_ID     534
 #define CX7_HW_ID       536
 #define CX8_HW_ID       542
-#define CX9_HW_ID       549
+#define CX9_HW_ID       548
 #define BF_HW_ID        529
 #define BF2_HW_ID       532
 #define BF3_HW_ID       540
@@ -301,6 +316,7 @@ enum {
 #define GR100_HW_ID     0x3000
 #define SPECTRUM4_HW_ID 596
 #define AMOS_GBOX_HW_ID 594
+#define CX8_PURE_PCIE_SWITCH_HW_ID       0x222
 
 /***** GLOBALS *****/
 int increase_poll_time = 0;
@@ -593,12 +609,38 @@ int icmd_clear_semaphore(mfile* mf)
     return icmd_clear_semaphore_com(mf);
 }
 
-/*
- * icmd_take_semaphore
- */
-/*
- * icmd_take_semaphore
- */
+bool device_supports_sem_lock_verify(unsigned int hw_dev_id)
+{
+    switch (hw_dev_id)
+    {
+        case DeviceConnectX3_HwId:
+        case DeviceConnectIB_HwId:
+        case DeviceConnectX3Pro_HwId:
+        case DeviceSwitchIB_HwId:
+        case DeviceSpectrum_HwId:
+        case DeviceConnectX4_HwId:
+        case DeviceConnectX4LX_HwId:
+        case DeviceConnectX5_HwId:
+        case DeviceConnectX6_HwId:
+        case DeviceConnectX6DX_HwId:
+        case DeviceConnectX6LX_HwId:
+        case DeviceConnectX7_HwId:
+        case DeviceBlueField_HwId:
+        case DeviceBlueField2_HwId:
+        case DeviceBlueField3_HwId:
+        case DeviceSwitchIB2_HwId:
+        case DeviceQuantum_HwId:
+        case DeviceQuantum2_HwId:
+        case DeviceQuantum3_HwId:
+        case DeviceGB100_HwId:
+        case DeviceSpectrum2_HwId:
+        case DeviceSpectrum3_HwId:
+        case DeviceSpectrum4_HwId:
+        case DeviceArcusE_HwId:
+            return false;
+    }
+    return true;
+}
 
 static int icmd_take_semaphore_com(mfile* mf, u_int32_t expected_read_val)
 {
@@ -630,12 +672,31 @@ static int icmd_take_semaphore_com(mfile* mf, u_int32_t expected_read_val)
         } else
 #endif
         {
-            if (mf->functional_vsec_supp) {
-                /* write expected val before reading it */
-                MWRITE4_SEMAPHORE(mf, mf->icmd.semaphore_addr, expected_read_val);
+            if (mf->functional_vsec_supp)
+            {
+                DBG_PRINTF("ICMD_SEMAPHORE: Writing expected_read_val=0x%x to semaphore\n", expected_read_val);
+                MWRITE4_SEMAPHORE(mf, mf->icmd.semaphore_addr,
+                                  expected_read_val); // Attempt to take the semaphore by writing the PID
             }
             MREAD4_SEMAPHORE(mf, mf->icmd.semaphore_addr, &read_val);
-            if (read_val == expected_read_val) {
+            DBG_PRINTF("ICMD_SEMAPHORE: read_val=0x%x expected_read_val=0x%x\n", read_val, expected_read_val);
+            if (read_val == expected_read_val) // Semaphore was free (PID if VSC, 0 if non-VSC)
+            {
+                if (!is_gw_access(mf))
+                {
+                    // Verify HW has set the semaphore to locked state
+                    MREAD4_SEMAPHORE(mf, mf->icmd.semaphore_addr, &read_val);
+                    if (read_val != SEMAPHORE_62_LOCKED_INDICATOR)
+                    {
+                        DBG_PRINTF("Failed to take ICMD semaphore (semaphore 62). "
+                                   "Semaphore was free (0) but HW failed to set it to locked state when we took it."
+                                   "This might indicate a FW or HW issue.\n");
+                        if (device_supports_sem_lock_verify(mf->hw_dev_id))
+                        {
+                            return ME_ICMD_UNABLE_TO_TAKE_SEMAOHORE;
+                        }
+                    }
+                }
                 break;
             }
         }
@@ -922,6 +983,7 @@ static int icmd_init_cr(mfile* mf)
 
     /* get device specific addresses */
     if (read_device_id(mf, &hw_id) != 4) {
+        DBG_PRINTF("icmd_init_cr: failed to read device ID.\n");
         return ME_ICMD_NOT_SUPPORTED;
     }
 
@@ -1015,7 +1077,6 @@ static int icmd_init_cr(mfile* mf)
 
     case (CX7_HW_ID):
     case (BF3_HW_ID):
-    case (CX8_HW_ID):
     case (BF4_HW_ID):
         cmd_ptr_addr = CMD_PTR_ADDR_CX7;
         hcr_address = HCR_ADDR_CX7;
@@ -1024,6 +1085,19 @@ static int icmd_init_cr(mfile* mf)
         mf->icmd.static_cfg_not_done_offs = STAT_CFG_NOT_DONE_BITOFF_CX7;
         break;
 
+    case (CX8_HW_ID):
+    case (CX9_HW_ID):
+    case (CX8_PURE_PCIE_SWITCH_HW_ID):
+        cmd_ptr_addr = CMD_PTR_ADDR_CX8;
+        mf->icmd.cmd_ptr_bitlen = CMD_PTR_BITLEN_CX8;
+        mf->icmd.semaphore_addr = SEMAPHORE_ADDR_CX8;
+        mf->icmd.static_cfg_not_done_addr = STAT_CFG_NOT_DONE_ADDR_CX8;
+        mf->icmd.static_cfg_not_done_offs = STAT_CFG_NOT_DONE_BITOFF_CX7;
+        mf->icmd.version_bit_offset = CMD_PTR_BITLEN_CX8;
+        mf->icmd.version_bitlen = ICMD_VERSION_BITLEN_CX8;
+        hcr_address = CMD_PTR_ADDR_CX8; /* hcr_address is "version address" */
+        break;
+
     case (AMOS_GBOX_HW_ID):
         mf->icmd.ctrl_addr = GBOX_MAX_DATA_SIZE;
 
@@ -1134,12 +1208,17 @@ static int icmd_init_vcr_crspace_addr(mfile* mf)
     case (BF3_HW_ID):
     case (CX7_HW_ID):
     case (BF4_HW_ID):
-    case (CX8_HW_ID):
-    case (CX9_HW_ID):
         mf->icmd.static_cfg_not_done_addr = STAT_CFG_NOT_DONE_ADDR_CX6;
         mf->icmd.static_cfg_not_done_offs = STAT_CFG_NOT_DONE_BITOFF_CX5;     /* same bit offset as CX5 */
         break;
 
+    case (CX8_HW_ID):
+    case (CX8_PURE_PCIE_SWITCH_HW_ID):
+    case (CX9_HW_ID):
+        mf->icmd.static_cfg_not_done_addr = STAT_CFG_NOT_DONE_ADDR_CX8;
+        mf->icmd.static_cfg_not_done_offs = STAT_CFG_NOT_DONE_BITOFF_CX7;
+        break;
+
     case (AMOS_GBOX_HW_ID):
         mf->icmd.static_cfg_not_done_addr = STAT_CFG_NOT_DONE_ADDR_CX6;
         mf->icmd.static_cfg_not_done_offs = STAT_CFG_NOT_DONE_BITOFF_CX5;     /* same bit offset as CX5 */
@@ -1261,6 +1340,13 @@ int icmd_open(mfile* mf)
     if (mf->functional_vsec_supp) {
         return icmd_init_vcr(mf);
     }
+
+#ifdef ENABLE_MST_DEV_I2C
+    if (mf->tp == MST_DEV_I2C) {
+        return icmd_init_cr(mf);
+    }
+#endif
+
     if ((mf->tp == MST_IB) || is_gpu_pci_device(mf->dinfo->pci.dev_id)) {
         return icmd_init_cr(mf);
     }
@@ -1296,4 +1382,3 @@ void icmd_close(mfile* mf)
         mf->icmd.icmd_opened = 0;
     }
 }
-
