@@ -51,6 +51,7 @@ public:
     u_int16_t getDescriptorLength() const { return descriptorLength; }
     const u_int8_t* getDescriptorData() const { return descriptorData; }
     std::string getDescription() const;
+    u_int16_t getDescriptorType() const { return descriptorType; }
 
 private:
     u_int16_t descriptorType;
@@ -58,8 +59,9 @@ private:
     u_int8_t* descriptorData;
 
     std::string psid;
+    u_int32_t apsku;
 
-    void extractPsid();
+    bool extractVendorDefined();
     enum
     {
         PCI_Vendor_ID = 0x0000,
