@@ -41,6 +41,7 @@
 
 #include <string>
 #include <exception>
+#include "dev_mgt/tools_dev_types.h"
 
 class PrmAdbDB
 {
@@ -48,13 +49,13 @@ public:
     static std::string prm_adb_db_trim(const std::string& s);
     static std::string prm_adb_db_rtrim(const std::string& s);
     static std::string prm_adb_db_ltrim(const std::string& s);
-    static std::string getDefaultDBName(bool isSwitch);
+    static std::string getDefaultDBName(dm_dev_id_t devID);
 };
 
-class PrmDBException : public std::exception
+class PrmDBException: public std::exception
 {
 public:
-    // Methods
+    /* Methods */
     PrmDBException();
     PrmDBException(const char* msg, ...) __attribute__((format(__printf__, 2, 3)));
     PrmDBException(std::string msg);
