@@ -174,6 +174,11 @@ static struct device_sem_info g_dev_sem_info_db[] = {
     {0x54a80},       // hw_sem_addr
     1,               // vsec_sem_supported
   },
+  {
+    DeviceConnectX8PurePcieSwitch, // dev_id
+    {0x54a80},                     // hw_sem_addr
+    1,                             // vsec_sem_supported
+  },
   {
     DeviceConnectX9, // dev_id
     {0x57680},       // hw_sem_addr
@@ -215,7 +220,7 @@ static struct device_sem_info g_dev_sem_info_db[] = {
     0,            // vsec_sem_supported
   },
   {
-    DeviceBW00, // dev_id
+    DeviceGB100, // dev_id
     {0xe74e0},   // hw_sem_addr find correct one for 0x2900
     1,           // vsec_sem_supported
   },
@@ -561,7 +566,7 @@ trm_sts trm_lock(trm_ctx trm, trm_resourse res, unsigned int max_retries)
     switch ((int)res)
     {
         case TRM_RES_ICMD:
-            if (trm->dev_sem_info->vsec_sem_supported && mget_vsec_supp(trm->mf))
+            if (trm->dev_sem_info->vsec_sem_supported && is_gw_access(trm->mf))
             {
                 return lock_icommand_gateway_semaphore(trm->mf, g_vsec_sem_addr[TRM_RES_ICMD], max_retries);
 #if !defined(__FreeBSD__) && !defined(UEFI_BUILD)
@@ -579,7 +584,7 @@ trm_sts trm_lock(trm_ctx trm, trm_resourse res, unsigned int max_retries)
             break;
 
         case TRM_RES_FLASH_PROGRAMING:
-            if (trm->dev_sem_info->vsec_sem_supported && mget_vsec_supp(trm->mf))
+            if (trm->dev_sem_info->vsec_sem_supported && is_gw_access(trm->mf))
             {
                 return lock_icommand_gateway_semaphore(trm->mf, g_vsec_sem_addr[TRM_RES_FLASH_PROGRAMING], max_retries);
 #if !defined(__FreeBSD__) && !defined(UEFI_BUILD)
@@ -637,7 +642,7 @@ trm_sts trm_unlock(trm_ctx trm, trm_resourse res)
     switch ((int)res)
     {
         case TRM_RES_ICMD:
-            if (trm->dev_sem_info->vsec_sem_supported && mget_vsec_supp(trm->mf))
+            if (trm->dev_sem_info->vsec_sem_supported && is_gw_access(trm->mf))
             {
                 return unlock_icommand_gateway_semaphore(trm->mf, g_vsec_sem_addr[TRM_RES_ICMD]);
 #if !defined(__FreeBSD__) && !defined(UEFI_BUILD)
@@ -655,7 +660,7 @@ trm_sts trm_unlock(trm_ctx trm, trm_resourse res)
             break;
 
         case TRM_RES_FLASH_PROGRAMING:
-            if (trm->dev_sem_info->vsec_sem_supported && mget_vsec_supp(trm->mf))
+            if (trm->dev_sem_info->vsec_sem_supported && is_gw_access(trm->mf))
             {
                 return unlock_icommand_gateway_semaphore(trm->mf, g_vsec_sem_addr[TRM_RES_FLASH_PROGRAMING]);
 #if !defined(__FreeBSD__) && !defined(UEFI_BUILD)
