@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2013-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -37,11 +37,10 @@
 
 #include "tools_time.h"
 
-
-
-void tt_get_time(tt_ctx_t *tt)
+void tt_get_time(tt_ctx_t* tt)
 {
-    if (!tt) {
+    if (!tt)
+    {
         return;
     }
     time(&(tt->now));
@@ -52,6 +51,3 @@ double tt_diff_in_ms(tt_ctx_t t1, tt_ctx_t t2)
 {
     return difftime(t2.now, t1.now) * 1000;
 }
-
-
-
